/****************************************************************************
** Meta object code from reading C++ file 'kgamewin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirk/kgamewin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgamewin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Ksirk__KGameWindow_t {
    QByteArrayData data[103];
    char stringdata0[1620];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Ksirk__KGameWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Ksirk__KGameWindow_t qt_meta_stringdata_Ksirk__KGameWindow = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Ksirk::KGameWindow"
QT_MOC_LITERAL(1, 19, 13), // "newJabberGame"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 14), // "mouseMoveEvent"
QT_MOC_LITERAL(4, 49, 12), // "QMouseEvent*"
QT_MOC_LITERAL(5, 62, 5), // "event"
QT_MOC_LITERAL(6, 68, 14), // "slotJabberGame"
QT_MOC_LITERAL(7, 83, 11), // "slotNewGame"
QT_MOC_LITERAL(8, 95, 17), // "slotNewJabberGame"
QT_MOC_LITERAL(9, 113, 17), // "slotNewSocketGame"
QT_MOC_LITERAL(10, 131, 19), // "slotJoinNetworkGame"
QT_MOC_LITERAL(11, 151, 12), // "slotOpenGame"
QT_MOC_LITERAL(12, 164, 12), // "slotSaveGame"
QT_MOC_LITERAL(13, 177, 13), // "slotRecycling"
QT_MOC_LITERAL(14, 191, 21), // "slotRecyclingFinished"
QT_MOC_LITERAL(15, 213, 14), // "slotNextPlayer"
QT_MOC_LITERAL(16, 228, 11), // "slotAttack1"
QT_MOC_LITERAL(17, 240, 11), // "slotAttack2"
QT_MOC_LITERAL(18, 252, 11), // "slotAttack3"
QT_MOC_LITERAL(19, 264, 12), // "slotDefense1"
QT_MOC_LITERAL(20, 277, 12), // "slotDefense2"
QT_MOC_LITERAL(21, 290, 11), // "slotDefAuto"
QT_MOC_LITERAL(22, 302, 14), // "slotWindowDef1"
QT_MOC_LITERAL(23, 317, 14), // "slotWindowDef2"
QT_MOC_LITERAL(24, 332, 11), // "slotInvade1"
QT_MOC_LITERAL(25, 344, 11), // "slotInvade5"
QT_MOC_LITERAL(26, 356, 12), // "slotInvade10"
QT_MOC_LITERAL(27, 369, 20), // "slotInvasionFinished"
QT_MOC_LITERAL(28, 390, 12), // "slotRetreat1"
QT_MOC_LITERAL(29, 403, 12), // "slotRetreat5"
QT_MOC_LITERAL(30, 416, 13), // "slotRetreat10"
QT_MOC_LITERAL(31, 430, 8), // "slotMove"
QT_MOC_LITERAL(32, 439, 10), // "slotCancel"
QT_MOC_LITERAL(33, 450, 24), // "slotDumpGameInformations"
QT_MOC_LITERAL(34, 475, 15), // "slotFinishMoves"
QT_MOC_LITERAL(35, 491, 9), // "slotArena"
QT_MOC_LITERAL(36, 501, 18), // "slotContextualHelp"
QT_MOC_LITERAL(37, 520, 24), // "slotShowAboutApplication"
QT_MOC_LITERAL(38, 545, 18), // "slotLeftButtonDown"
QT_MOC_LITERAL(39, 564, 16), // "slotLeftButtonUp"
QT_MOC_LITERAL(40, 581, 19), // "slotRightButtonDown"
QT_MOC_LITERAL(41, 601, 17), // "slotRightButtonUp"
QT_MOC_LITERAL(42, 619, 12), // "slotShowGoal"
QT_MOC_LITERAL(43, 632, 15), // "slotChatMessage"
QT_MOC_LITERAL(44, 648, 20), // "slotChatReduceButton"
QT_MOC_LITERAL(45, 669, 26), // "slotChatFloatButtonPressed"
QT_MOC_LITERAL(46, 696, 20), // "slotChatFloatChanged"
QT_MOC_LITERAL(47, 717, 5), // "value"
QT_MOC_LITERAL(48, 723, 25), // "slotMovingFightersArrived"
QT_MOC_LITERAL(49, 749, 17), // "AnimSpritesGroup*"
QT_MOC_LITERAL(50, 767, 7), // "sprites"
QT_MOC_LITERAL(51, 775, 18), // "slotFiringFinished"
QT_MOC_LITERAL(52, 794, 21), // "slotExplosionFinished"
QT_MOC_LITERAL(53, 816, 23), // "slotMovingArmiesArrived"
QT_MOC_LITERAL(54, 840, 9), // "slotBring"
QT_MOC_LITERAL(55, 850, 11), // "AnimSprite*"
QT_MOC_LITERAL(56, 862, 21), // "slotMovingArmyArrived"
QT_MOC_LITERAL(57, 884, 10), // "slotZoomIn"
QT_MOC_LITERAL(58, 895, 11), // "slotZoomOut"
QT_MOC_LITERAL(59, 907, 15), // "slotNewGameNext"
QT_MOC_LITERAL(60, 923, 13), // "slotNewGameKO"
QT_MOC_LITERAL(61, 937, 22), // "slotJabberGameCanceled"
QT_MOC_LITERAL(62, 960, 13), // "previousIndex"
QT_MOC_LITERAL(63, 974, 17), // "slotNewPlayerNext"
QT_MOC_LITERAL(64, 992, 21), // "slotNewPlayerPrevious"
QT_MOC_LITERAL(65, 1014, 19), // "slotNewPlayerCancel"
QT_MOC_LITERAL(66, 1034, 16), // "slotStartNewGame"
QT_MOC_LITERAL(67, 1051, 20), // "slotTcpConnectCancel"
QT_MOC_LITERAL(68, 1072, 22), // "slotTcpConnectPrevious"
QT_MOC_LITERAL(69, 1095, 16), // "optionsConfigure"
QT_MOC_LITERAL(70, 1112, 14), // "evenementTimer"
QT_MOC_LITERAL(71, 1127, 17), // "slotRemoveMessage"
QT_MOC_LITERAL(72, 1145, 15), // "slotDisableHelp"
QT_MOC_LITERAL(73, 1161, 23), // "slotArmiesNumberChanged"
QT_MOC_LITERAL(74, 1185, 20), // "slotHandleTLSWarning"
QT_MOC_LITERAL(75, 1206, 24), // "QCA::TLS::IdentityResult"
QT_MOC_LITERAL(76, 1231, 14), // "identityResult"
QT_MOC_LITERAL(77, 1246, 13), // "QCA::Validity"
QT_MOC_LITERAL(78, 1260, 14), // "validityResult"
QT_MOC_LITERAL(79, 1275, 15), // "slotClientError"
QT_MOC_LITERAL(80, 1291, 23), // "JabberClient::ErrorCode"
QT_MOC_LITERAL(81, 1315, 9), // "errorCode"
QT_MOC_LITERAL(82, 1325, 13), // "slotConnected"
QT_MOC_LITERAL(83, 1339, 18), // "slotCSDisconnected"
QT_MOC_LITERAL(84, 1358, 11), // "slotCSError"
QT_MOC_LITERAL(85, 1370, 25), // "slotRosterRequestFinished"
QT_MOC_LITERAL(86, 1396, 7), // "success"
QT_MOC_LITERAL(87, 1404, 22), // "slotClientDebugMessage"
QT_MOC_LITERAL(88, 1427, 3), // "msg"
QT_MOC_LITERAL(89, 1431, 19), // "slotGroupChatJoined"
QT_MOC_LITERAL(90, 1451, 9), // "XMPP::Jid"
QT_MOC_LITERAL(91, 1461, 3), // "jid"
QT_MOC_LITERAL(92, 1465, 17), // "slotGroupChatLeft"
QT_MOC_LITERAL(93, 1483, 21), // "slotGroupChatPresence"
QT_MOC_LITERAL(94, 1505, 12), // "XMPP::Status"
QT_MOC_LITERAL(95, 1518, 6), // "status"
QT_MOC_LITERAL(96, 1525, 18), // "slotGroupChatError"
QT_MOC_LITERAL(97, 1544, 5), // "error"
QT_MOC_LITERAL(98, 1550, 6), // "reason"
QT_MOC_LITERAL(99, 1557, 19), // "slotReceivedMessage"
QT_MOC_LITERAL(100, 1577, 13), // "XMPP::Message"
QT_MOC_LITERAL(101, 1591, 8), // "slotExit"
QT_MOC_LITERAL(102, 1600, 19) // "slotConnectToServer"

    },
    "Ksirk::KGameWindow\0newJabberGame\0\0"
    "mouseMoveEvent\0QMouseEvent*\0event\0"
    "slotJabberGame\0slotNewGame\0slotNewJabberGame\0"
    "slotNewSocketGame\0slotJoinNetworkGame\0"
    "slotOpenGame\0slotSaveGame\0slotRecycling\0"
    "slotRecyclingFinished\0slotNextPlayer\0"
    "slotAttack1\0slotAttack2\0slotAttack3\0"
    "slotDefense1\0slotDefense2\0slotDefAuto\0"
    "slotWindowDef1\0slotWindowDef2\0slotInvade1\0"
    "slotInvade5\0slotInvade10\0slotInvasionFinished\0"
    "slotRetreat1\0slotRetreat5\0slotRetreat10\0"
    "slotMove\0slotCancel\0slotDumpGameInformations\0"
    "slotFinishMoves\0slotArena\0slotContextualHelp\0"
    "slotShowAboutApplication\0slotLeftButtonDown\0"
    "slotLeftButtonUp\0slotRightButtonDown\0"
    "slotRightButtonUp\0slotShowGoal\0"
    "slotChatMessage\0slotChatReduceButton\0"
    "slotChatFloatButtonPressed\0"
    "slotChatFloatChanged\0value\0"
    "slotMovingFightersArrived\0AnimSpritesGroup*\0"
    "sprites\0slotFiringFinished\0"
    "slotExplosionFinished\0slotMovingArmiesArrived\0"
    "slotBring\0AnimSprite*\0slotMovingArmyArrived\0"
    "slotZoomIn\0slotZoomOut\0slotNewGameNext\0"
    "slotNewGameKO\0slotJabberGameCanceled\0"
    "previousIndex\0slotNewPlayerNext\0"
    "slotNewPlayerPrevious\0slotNewPlayerCancel\0"
    "slotStartNewGame\0slotTcpConnectCancel\0"
    "slotTcpConnectPrevious\0optionsConfigure\0"
    "evenementTimer\0slotRemoveMessage\0"
    "slotDisableHelp\0slotArmiesNumberChanged\0"
    "slotHandleTLSWarning\0QCA::TLS::IdentityResult\0"
    "identityResult\0QCA::Validity\0"
    "validityResult\0slotClientError\0"
    "JabberClient::ErrorCode\0errorCode\0"
    "slotConnected\0slotCSDisconnected\0"
    "slotCSError\0slotRosterRequestFinished\0"
    "success\0slotClientDebugMessage\0msg\0"
    "slotGroupChatJoined\0XMPP::Jid\0jid\0"
    "slotGroupChatLeft\0slotGroupChatPresence\0"
    "XMPP::Status\0status\0slotGroupChatError\0"
    "error\0reason\0slotReceivedMessage\0"
    "XMPP::Message\0slotExit\0slotConnectToServer"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Ksirk__KGameWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      80,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,  414,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  421,    2, 0x0a /* Public */,
       6,    0,  424,    2, 0x0a /* Public */,
       7,    0,  425,    2, 0x0a /* Public */,
       8,    0,  426,    2, 0x0a /* Public */,
       9,    0,  427,    2, 0x0a /* Public */,
      10,    0,  428,    2, 0x0a /* Public */,
      11,    0,  429,    2, 0x0a /* Public */,
      12,    0,  430,    2, 0x0a /* Public */,
      13,    0,  431,    2, 0x0a /* Public */,
      14,    0,  432,    2, 0x0a /* Public */,
      15,    0,  433,    2, 0x0a /* Public */,
      16,    0,  434,    2, 0x0a /* Public */,
      17,    0,  435,    2, 0x0a /* Public */,
      18,    0,  436,    2, 0x0a /* Public */,
      19,    0,  437,    2, 0x0a /* Public */,
      20,    0,  438,    2, 0x0a /* Public */,
      21,    0,  439,    2, 0x0a /* Public */,
      22,    0,  440,    2, 0x0a /* Public */,
      23,    0,  441,    2, 0x0a /* Public */,
      24,    0,  442,    2, 0x0a /* Public */,
      25,    0,  443,    2, 0x0a /* Public */,
      26,    0,  444,    2, 0x0a /* Public */,
      27,    0,  445,    2, 0x0a /* Public */,
      28,    0,  446,    2, 0x0a /* Public */,
      29,    0,  447,    2, 0x0a /* Public */,
      30,    0,  448,    2, 0x0a /* Public */,
      31,    0,  449,    2, 0x0a /* Public */,
      32,    0,  450,    2, 0x0a /* Public */,
      33,    0,  451,    2, 0x0a /* Public */,
      34,    0,  452,    2, 0x0a /* Public */,
      35,    1,  453,    2, 0x0a /* Public */,
      36,    0,  456,    2, 0x0a /* Public */,
      37,    0,  457,    2, 0x0a /* Public */,
      38,    1,  458,    2, 0x0a /* Public */,
      39,    1,  461,    2, 0x0a /* Public */,
      40,    1,  464,    2, 0x0a /* Public */,
      41,    1,  467,    2, 0x0a /* Public */,
      42,    0,  470,    2, 0x0a /* Public */,
      43,    0,  471,    2, 0x0a /* Public */,
      44,    0,  472,    2, 0x0a /* Public */,
      45,    0,  473,    2, 0x0a /* Public */,
      46,    1,  474,    2, 0x0a /* Public */,
      46,    0,  477,    2, 0x2a /* Public | MethodCloned */,
      48,    1,  478,    2, 0x0a /* Public */,
      51,    1,  481,    2, 0x0a /* Public */,
      52,    1,  484,    2, 0x0a /* Public */,
      53,    1,  487,    2, 0x0a /* Public */,
      54,    1,  490,    2, 0x0a /* Public */,
      56,    1,  493,    2, 0x0a /* Public */,
      57,    0,  496,    2, 0x0a /* Public */,
      58,    0,  497,    2, 0x0a /* Public */,
      59,    0,  498,    2, 0x0a /* Public */,
      60,    0,  499,    2, 0x0a /* Public */,
      61,    1,  500,    2, 0x0a /* Public */,
      63,    0,  503,    2, 0x0a /* Public */,
      64,    0,  504,    2, 0x0a /* Public */,
      65,    0,  505,    2, 0x0a /* Public */,
      66,    0,  506,    2, 0x0a /* Public */,
      67,    0,  507,    2, 0x0a /* Public */,
      68,    0,  508,    2, 0x0a /* Public */,
      69,    0,  509,    2, 0x08 /* Private */,
      70,    0,  510,    2, 0x08 /* Private */,
      71,    0,  511,    2, 0x08 /* Private */,
      72,    1,  512,    2, 0x08 /* Private */,
      73,    1,  515,    2, 0x08 /* Private */,
      74,    2,  518,    2, 0x08 /* Private */,
      79,    1,  523,    2, 0x08 /* Private */,
      82,    0,  526,    2, 0x08 /* Private */,
      83,    0,  527,    2, 0x08 /* Private */,
      84,    1,  528,    2, 0x08 /* Private */,
      85,    1,  531,    2, 0x08 /* Private */,
      87,    1,  534,    2, 0x08 /* Private */,
      89,    1,  537,    2, 0x08 /* Private */,
      92,    1,  540,    2, 0x08 /* Private */,
      93,    2,  543,    2, 0x08 /* Private */,
      96,    3,  548,    2, 0x08 /* Private */,
      99,    1,  555,    2, 0x08 /* Private */,
     101,    0,  558,    2, 0x08 /* Private */,
     102,    0,  559,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    2,    2,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 49,   50,
    QMetaType::Void, 0x80000000 | 49,    2,
    QMetaType::Void, 0x80000000 | 49,    2,
    QMetaType::Void, 0x80000000 | 49,    2,
    QMetaType::Void, 0x80000000 | 55,    2,
    QMetaType::Void, 0x80000000 | 55,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   62,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 75, 0x80000000 | 77,   76,   78,
    QMetaType::Void, 0x80000000 | 80,   81,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,   86,
    QMetaType::Void, QMetaType::QString,   88,
    QMetaType::Void, 0x80000000 | 90,   91,
    QMetaType::Void, 0x80000000 | 90,   91,
    QMetaType::Void, 0x80000000 | 90, 0x80000000 | 94,   91,   95,
    QMetaType::Void, 0x80000000 | 90, QMetaType::Int, QMetaType::QString,   91,   97,   98,
    QMetaType::Void, 0x80000000 | 100,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Ksirk::KGameWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KGameWindow *_t = static_cast<KGameWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newJabberGame((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 1: _t->mouseMoveEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 2: _t->slotJabberGame(); break;
        case 3: _t->slotNewGame(); break;
        case 4: _t->slotNewJabberGame(); break;
        case 5: _t->slotNewSocketGame(); break;
        case 6: _t->slotJoinNetworkGame(); break;
        case 7: _t->slotOpenGame(); break;
        case 8: _t->slotSaveGame(); break;
        case 9: _t->slotRecycling(); break;
        case 10: _t->slotRecyclingFinished(); break;
        case 11: _t->slotNextPlayer(); break;
        case 12: _t->slotAttack1(); break;
        case 13: _t->slotAttack2(); break;
        case 14: _t->slotAttack3(); break;
        case 15: _t->slotDefense1(); break;
        case 16: _t->slotDefense2(); break;
        case 17: _t->slotDefAuto(); break;
        case 18: _t->slotWindowDef1(); break;
        case 19: _t->slotWindowDef2(); break;
        case 20: _t->slotInvade1(); break;
        case 21: _t->slotInvade5(); break;
        case 22: _t->slotInvade10(); break;
        case 23: _t->slotInvasionFinished(); break;
        case 24: _t->slotRetreat1(); break;
        case 25: _t->slotRetreat5(); break;
        case 26: _t->slotRetreat10(); break;
        case 27: _t->slotMove(); break;
        case 28: _t->slotCancel(); break;
        case 29: _t->slotDumpGameInformations(); break;
        case 30: _t->slotFinishMoves(); break;
        case 31: _t->slotArena((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->slotContextualHelp(); break;
        case 33: _t->slotShowAboutApplication(); break;
        case 34: _t->slotLeftButtonDown((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 35: _t->slotLeftButtonUp((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 36: _t->slotRightButtonDown((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 37: _t->slotRightButtonUp((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 38: _t->slotShowGoal(); break;
        case 39: _t->slotChatMessage(); break;
        case 40: _t->slotChatReduceButton(); break;
        case 41: _t->slotChatFloatButtonPressed(); break;
        case 42: _t->slotChatFloatChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 43: _t->slotChatFloatChanged(); break;
        case 44: _t->slotMovingFightersArrived((*reinterpret_cast< AnimSpritesGroup*(*)>(_a[1]))); break;
        case 45: _t->slotFiringFinished((*reinterpret_cast< AnimSpritesGroup*(*)>(_a[1]))); break;
        case 46: _t->slotExplosionFinished((*reinterpret_cast< AnimSpritesGroup*(*)>(_a[1]))); break;
        case 47: _t->slotMovingArmiesArrived((*reinterpret_cast< AnimSpritesGroup*(*)>(_a[1]))); break;
        case 48: _t->slotBring((*reinterpret_cast< AnimSprite*(*)>(_a[1]))); break;
        case 49: _t->slotMovingArmyArrived((*reinterpret_cast< AnimSprite*(*)>(_a[1]))); break;
        case 50: _t->slotZoomIn(); break;
        case 51: _t->slotZoomOut(); break;
        case 52: _t->slotNewGameNext(); break;
        case 53: _t->slotNewGameKO(); break;
        case 54: _t->slotJabberGameCanceled((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 55: _t->slotNewPlayerNext(); break;
        case 56: _t->slotNewPlayerPrevious(); break;
        case 57: _t->slotNewPlayerCancel(); break;
        case 58: _t->slotStartNewGame(); break;
        case 59: _t->slotTcpConnectCancel(); break;
        case 60: _t->slotTcpConnectPrevious(); break;
        case 61: _t->optionsConfigure(); break;
        case 62: _t->evenementTimer(); break;
        case 63: _t->slotRemoveMessage(); break;
        case 64: _t->slotDisableHelp((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 65: _t->slotArmiesNumberChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 66: _t->slotHandleTLSWarning((*reinterpret_cast< QCA::TLS::IdentityResult(*)>(_a[1])),(*reinterpret_cast< QCA::Validity(*)>(_a[2]))); break;
        case 67: _t->slotClientError((*reinterpret_cast< JabberClient::ErrorCode(*)>(_a[1]))); break;
        case 68: _t->slotConnected(); break;
        case 69: _t->slotCSDisconnected(); break;
        case 70: _t->slotCSError((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 71: _t->slotRosterRequestFinished((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 72: _t->slotClientDebugMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 73: _t->slotGroupChatJoined((*reinterpret_cast< const XMPP::Jid(*)>(_a[1]))); break;
        case 74: _t->slotGroupChatLeft((*reinterpret_cast< const XMPP::Jid(*)>(_a[1]))); break;
        case 75: _t->slotGroupChatPresence((*reinterpret_cast< const XMPP::Jid(*)>(_a[1])),(*reinterpret_cast< const XMPP::Status(*)>(_a[2]))); break;
        case 76: _t->slotGroupChatError((*reinterpret_cast< const XMPP::Jid(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 77: _t->slotReceivedMessage((*reinterpret_cast< const XMPP::Message(*)>(_a[1]))); break;
        case 78: _t->slotExit(); break;
        case 79: _t->slotConnectToServer(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 48:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AnimSprite* >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AnimSprite* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KGameWindow::*_t)(const QString & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGameWindow::newJabberGame)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Ksirk::KGameWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_Ksirk__KGameWindow.data,
      qt_meta_data_Ksirk__KGameWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Ksirk::KGameWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::KGameWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Ksirk__KGameWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Ksirk::KGameWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 80)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 80;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 80)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 80;
    }
    return _id;
}

// SIGNAL 0
void Ksirk::KGameWindow::newJabberGame(const QString & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
