#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'ksirkskindefinition.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKSKINDEFINITION_H
#define UI_KSIRKSKINDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_skindefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_7;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QLineEdit *skinNameLineEdit;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *widthLineEdit;
    QLabel *label_2;
    QSpinBox *heightLineEdit;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_5;
    KFontRequester *fontrequester;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_5;
    KColorButton *fgcolorbutton;
    QLabel *label_6;
    KColorButton *bgcolorbutton;
    QLabel *label_4;
    QTextEdit *descriptionTextEdit;
    QTabWidget *qtabwidget;
    QWidget *tabSprites;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_7;
    QWidget *tabNationalities;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_8;
    QPushButton *newNationalityButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *deleteNationalityButton;
    QListWidget *nationalitieslist;
    QWidget *tabCountries;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_5;
    QPushButton *newCountryButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *deleteCountryButton;
    QListWidget *countrieslist;
    QWidget *tabContinents;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_6;
    QPushButton *newContinentButton;
    QSpacerItem *horizontalSpacer1;
    QPushButton *deleteContinentButton;
    QListWidget *continentslist;
    QWidget *tabGoals;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_7;
    QPushButton *newGoalButton;
    QSpacerItem *horizontalSpacer2;
    QPushButton *deleteGoalButton;
    QListWidget *goalslist;

    void setupUi(QDockWidget *skindefinition)
    {
        if (skindefinition->objectName().isEmpty())
            skindefinition->setObjectName(QStringLiteral("skindefinition"));
        skindefinition->resize(328, 841);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName(QStringLiteral("dockWidgetContents"));
        verticalLayout_7 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_7->setObjectName(QStringLiteral("verticalLayout_7"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        label_3 = new QLabel(dockWidgetContents);
        label_3->setObjectName(QStringLiteral("label_3"));

        horizontalLayout_2->addWidget(label_3);

        skinNameLineEdit = new QLineEdit(dockWidgetContents);
        skinNameLineEdit->setObjectName(QStringLiteral("skinNameLineEdit"));

        horizontalLayout_2->addWidget(skinNameLineEdit);


        verticalLayout_7->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(dockWidgetContents);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        widthLineEdit = new QSpinBox(dockWidgetContents);
        widthLineEdit->setObjectName(QStringLiteral("widthLineEdit"));

        horizontalLayout->addWidget(widthLineEdit);

        label_2 = new QLabel(dockWidgetContents);
        label_2->setObjectName(QStringLiteral("label_2"));

        horizontalLayout->addWidget(label_2);

        heightLineEdit = new QSpinBox(dockWidgetContents);
        heightLineEdit->setObjectName(QStringLiteral("heightLineEdit"));

        horizontalLayout->addWidget(heightLineEdit);


        verticalLayout_7->addLayout(horizontalLayout);

        groupBox = new QGroupBox(dockWidgetContents);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        verticalLayout_5 = new QVBoxLayout(groupBox);
        verticalLayout_5->setObjectName(QStringLiteral("verticalLayout_5"));
        fontrequester = new KFontRequester(groupBox);
        fontrequester->setObjectName(QStringLiteral("fontrequester"));

        verticalLayout_5->addWidget(fontrequester);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        label_5 = new QLabel(groupBox);
        label_5->setObjectName(QStringLiteral("label_5"));

        horizontalLayout_3->addWidget(label_5);

        fgcolorbutton = new KColorButton(groupBox);
        fgcolorbutton->setObjectName(QStringLiteral("fgcolorbutton"));

        horizontalLayout_3->addWidget(fgcolorbutton);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName(QStringLiteral("label_6"));

        horizontalLayout_3->addWidget(label_6);

        bgcolorbutton = new KColorButton(groupBox);
        bgcolorbutton->setObjectName(QStringLiteral("bgcolorbutton"));

        horizontalLayout_3->addWidget(bgcolorbutton);


        verticalLayout_5->addLayout(horizontalLayout_3);


        verticalLayout_7->addWidget(groupBox);

        label_4 = new QLabel(dockWidgetContents);
        label_4->setObjectName(QStringLiteral("label_4"));

        verticalLayout_7->addWidget(label_4);

        descriptionTextEdit = new QTextEdit(dockWidgetContents);
        descriptionTextEdit->setObjectName(QStringLiteral("descriptionTextEdit"));
        sizePolicy.setHeightForWidth(descriptionTextEdit->sizePolicy().hasHeightForWidth());
        descriptionTextEdit->setSizePolicy(sizePolicy);

        verticalLayout_7->addWidget(descriptionTextEdit);

        qtabwidget = new QTabWidget(dockWidgetContents);
        qtabwidget->setObjectName(QStringLiteral("qtabwidget"));
        tabSprites = new QWidget();
        tabSprites->setObjectName(QStringLiteral("tabSprites"));
        verticalLayout_2 = new QVBoxLayout(tabSprites);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        label_7 = new QLabel(tabSprites);
        label_7->setObjectName(QStringLiteral("label_7"));

        verticalLayout_2->addWidget(label_7);

        qtabwidget->addTab(tabSprites, QString());
        tabNationalities = new QWidget();
        tabNationalities->setObjectName(QStringLiteral("tabNationalities"));
        verticalLayout_6 = new QVBoxLayout(tabNationalities);
        verticalLayout_6->setObjectName(QStringLiteral("verticalLayout_6"));
        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QStringLiteral("horizontalLayout_8"));
        newNationalityButton = new QPushButton(tabNationalities);
        newNationalityButton->setObjectName(QStringLiteral("newNationalityButton"));

        horizontalLayout_8->addWidget(newNationalityButton);

        horizontalSpacer_2 = new QSpacerItem(148, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_2);

        deleteNationalityButton = new QPushButton(tabNationalities);
        deleteNationalityButton->setObjectName(QStringLiteral("deleteNationalityButton"));

        horizontalLayout_8->addWidget(deleteNationalityButton);


        verticalLayout_6->addLayout(horizontalLayout_8);

        nationalitieslist = new QListWidget(tabNationalities);
        nationalitieslist->setObjectName(QStringLiteral("nationalitieslist"));

        verticalLayout_6->addWidget(nationalitieslist);

        qtabwidget->addTab(tabNationalities, QString());
        tabCountries = new QWidget();
        tabCountries->setObjectName(QStringLiteral("tabCountries"));
        verticalLayout = new QVBoxLayout(tabCountries);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        newCountryButton = new QPushButton(tabCountries);
        newCountryButton->setObjectName(QStringLiteral("newCountryButton"));

        horizontalLayout_5->addWidget(newCountryButton);

        horizontalSpacer = new QSpacerItem(148, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);

        deleteCountryButton = new QPushButton(tabCountries);
        deleteCountryButton->setObjectName(QStringLiteral("deleteCountryButton"));

        horizontalLayout_5->addWidget(deleteCountryButton);


        verticalLayout->addLayout(horizontalLayout_5);

        countrieslist = new QListWidget(tabCountries);
        countrieslist->setObjectName(QStringLiteral("countrieslist"));

        verticalLayout->addWidget(countrieslist);

        qtabwidget->addTab(tabCountries, QString());
        tabContinents = new QWidget();
        tabContinents->setObjectName(QStringLiteral("tabContinents"));
        verticalLayout_3 = new QVBoxLayout(tabContinents);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        newContinentButton = new QPushButton(tabContinents);
        newContinentButton->setObjectName(QStringLiteral("newContinentButton"));

        horizontalLayout_6->addWidget(newContinentButton);

        horizontalSpacer1 = new QSpacerItem(148, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer1);

        deleteContinentButton = new QPushButton(tabContinents);
        deleteContinentButton->setObjectName(QStringLiteral("deleteContinentButton"));

        horizontalLayout_6->addWidget(deleteContinentButton);


        verticalLayout_3->addLayout(horizontalLayout_6);

        continentslist = new QListWidget(tabContinents);
        continentslist->setObjectName(QStringLiteral("continentslist"));

        verticalLayout_3->addWidget(continentslist);

        qtabwidget->addTab(tabContinents, QString());
        tabGoals = new QWidget();
        tabGoals->setObjectName(QStringLiteral("tabGoals"));
        verticalLayout_4 = new QVBoxLayout(tabGoals);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QStringLiteral("horizontalLayout_7"));
        newGoalButton = new QPushButton(tabGoals);
        newGoalButton->setObjectName(QStringLiteral("newGoalButton"));

        horizontalLayout_7->addWidget(newGoalButton);

        horizontalSpacer2 = new QSpacerItem(148, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer2);

        deleteGoalButton = new QPushButton(tabGoals);
        deleteGoalButton->setObjectName(QStringLiteral("deleteGoalButton"));

        horizontalLayout_7->addWidget(deleteGoalButton);


        verticalLayout_4->addLayout(horizontalLayout_7);

        goalslist = new QListWidget(tabGoals);
        goalslist->setObjectName(QStringLiteral("goalslist"));

        verticalLayout_4->addWidget(goalslist);

        qtabwidget->addTab(tabGoals, QString());

        verticalLayout_7->addWidget(qtabwidget);

        skindefinition->setWidget(dockWidgetContents);

        retranslateUi(skindefinition);

        qtabwidget->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(skindefinition);
    } // setupUi

    void retranslateUi(QDockWidget *skindefinition)
    {
        skindefinition->setWindowTitle(tr2i18n("Skin Definition", Q_NULLPTR));
        label_3->setText(tr2i18n("Skin name:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        skinNameLineEdit->setToolTip(tr2i18n("The skin's short name", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_STATUSTIP
        skinNameLineEdit->setStatusTip(QString());
#endif // QT_NO_STATUSTIP
#ifndef UI_QT_NO_WHATSTHIS
        skinNameLineEdit->setWhatsThis(tr2i18n("Type here the skin's short name. This should be an identifier-like string", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label->setText(tr2i18n("Width x Height", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        widthLineEdit->setToolTip(tr2i18n("Map's width", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        widthLineEdit->setWhatsThis(tr2i18n("This is the map's width. The map SVG element will be by default drawn on an image of this width. All positions on the map are expressed relatively to this dimension.\n"
"", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_2->setText(tr2i18n("x", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        heightLineEdit->setToolTip(tr2i18n("Map's height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        heightLineEdit->setWhatsThis(tr2i18n("This is the map's height. The map SVG element will be by default drawn on an image of this height All positions on the map are expressed relatively to this dimension.\n"
"", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        groupBox->setTitle(tr2i18n("Map Font", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        fontrequester->setToolTip(tr2i18n("Font used to draw country names", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        fontrequester->setWhatsThis(tr2i18n("This font will be used to draw the country names on the map", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_5->setText(tr2i18n("Fg:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        fgcolorbutton->setToolTip(tr2i18n("Foreground color for country names", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        fgcolorbutton->setWhatsThis(tr2i18n("This color will be used to draw the foreground of the country names on the map", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_6->setText(tr2i18n("Bg:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        bgcolorbutton->setToolTip(tr2i18n("Background color for country names", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        bgcolorbutton->setWhatsThis(tr2i18n("This color will be used to draw the background of the country names on the map", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_4->setText(tr2i18n("Description:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        descriptionTextEdit->setToolTip(tr2i18n("Human readable description of the skin", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        descriptionTextEdit->setWhatsThis(tr2i18n("Describe here the skin, its style, its story, the intent of its author(s), etc.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        qtabwidget->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        label_7->setText(tr2i18n("Edit the sprite definitions\n"
"in the right dock", Q_NULLPTR));
        qtabwidget->setTabText(qtabwidget->indexOf(tabSprites), tr2i18n("Sprites", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        newNationalityButton->setToolTip(tr2i18n("Creates a new Nationality", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        newNationalityButton->setWhatsThis(tr2i18n("Click here to add a new nationality. You will be prompted for its name.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        newNationalityButton->setText(tr2i18n("New Nationality", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        deleteNationalityButton->setToolTip(tr2i18n("Removes the currently selected nationality", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        deleteNationalityButton->setWhatsThis(tr2i18n("Click here to remove the currently selected nationality. You will be asked for confirmation.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        deleteNationalityButton->setText(tr2i18n("X", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        nationalitieslist->setToolTip(tr2i18n("Nationality list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        nationalitieslist->setWhatsThis(tr2i18n("This list shows the nationalities defined.\n"
"\n"
"Each nationality name should be unique. Select a nationality and edit its details in the right dock.\n"
"\n"
"During the game, each player must choose a nationality. As such, you should add at least as many nationalities as the maximum number of players for this skin.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        qtabwidget->setTabText(qtabwidget->indexOf(tabNationalities), tr2i18n("Nationalities", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        newCountryButton->setToolTip(tr2i18n("Creates a new country", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        newCountryButton->setWhatsThis(tr2i18n("Click here to add a new country. You will be prompted for its name.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        newCountryButton->setText(tr2i18n("New Country", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        deleteCountryButton->setToolTip(tr2i18n("Removes the currently selected country", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        deleteCountryButton->setWhatsThis(tr2i18n("Click here to remove the currently selected country. You will be asked for confirmation.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        deleteCountryButton->setText(tr2i18n("X", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        countrieslist->setToolTip(tr2i18n("Country list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        countrieslist->setWhatsThis(tr2i18n("This list shows the countries defined.\n"
"\n"
"Each country name should be unique. Select a country and edit its details in the right dock.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        qtabwidget->setTabText(qtabwidget->indexOf(tabCountries), tr2i18n("Countries", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        newContinentButton->setToolTip(tr2i18n("Creates a new continent", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        newContinentButton->setWhatsThis(tr2i18n("Click here to add a new continent. You will be prompted for its name.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        newContinentButton->setText(tr2i18n("New Continent", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        deleteContinentButton->setToolTip(tr2i18n("Removes the currently selected continent", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        deleteContinentButton->setWhatsThis(tr2i18n("Click here to remove the currently selected continent. You will be asked for confirmation.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        deleteContinentButton->setText(tr2i18n("X", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        continentslist->setToolTip(tr2i18n("Continent list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        continentslist->setWhatsThis(tr2i18n("This list shows the continents defined.\n"
"\n"
"Each continent name should be unique. Select a continent and edit its details in the right dock.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        qtabwidget->setTabText(qtabwidget->indexOf(tabContinents), tr2i18n("Continents", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        newGoalButton->setToolTip(tr2i18n("Creates a new goal", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        newGoalButton->setWhatsThis(tr2i18n("Click here to add a new goal. It will be named automatically.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        newGoalButton->setText(tr2i18n("New Goal", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        deleteGoalButton->setToolTip(tr2i18n("Removes the currently selected goal", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        deleteGoalButton->setWhatsThis(tr2i18n("Click here to remove the currently selected goal. You will be asked for confirmation.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        deleteGoalButton->setText(tr2i18n("X", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        goalslist->setToolTip(tr2i18n("Goal list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        goalslist->setWhatsThis(tr2i18n("This list shows the goals defined.\n"
"\n"
"Each goal name should be unique. Select a goal and edit its details in the right dock.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        qtabwidget->setTabText(qtabwidget->indexOf(tabGoals), tr2i18n("Goals", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class skindefinition: public Ui_skindefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKSKINDEFINITION_H

