/****************************************************************************
** Meta object code from reading C++ file 'xmpp_tasks.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/xmpp-im/xmpp_tasks.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xmpp_tasks.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__JT_Register_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_Register_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_Register_t qt_meta_stringdata_XMPP__JT_Register = {
    {
QT_MOC_LITERAL(0, 0, 17) // "XMPP::JT_Register"

    },
    "XMPP::JT_Register"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_Register[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_Register::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_Register::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_Register.data,
      qt_meta_data_XMPP__JT_Register,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_Register::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_Register::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_Register.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_Register::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_UnRegister_t {
    QByteArrayData data[4];
    char stringdata0[51];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_UnRegister_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_UnRegister_t qt_meta_stringdata_XMPP__JT_UnRegister = {
    {
QT_MOC_LITERAL(0, 0, 19), // "XMPP::JT_UnRegister"
QT_MOC_LITERAL(1, 20, 15), // "getFormFinished"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 13) // "unregFinished"

    },
    "XMPP::JT_UnRegister\0getFormFinished\0"
    "\0unregFinished"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_UnRegister[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    0,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::JT_UnRegister::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_UnRegister *_t = static_cast<JT_UnRegister *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->getFormFinished(); break;
        case 1: _t->unregFinished(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_UnRegister::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_UnRegister.data,
      qt_meta_data_XMPP__JT_UnRegister,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_UnRegister::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_UnRegister::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_UnRegister.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_UnRegister::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_Roster_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_Roster_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_Roster_t qt_meta_stringdata_XMPP__JT_Roster = {
    {
QT_MOC_LITERAL(0, 0, 15) // "XMPP::JT_Roster"

    },
    "XMPP::JT_Roster"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_Roster[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_Roster::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_Roster::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_Roster.data,
      qt_meta_data_XMPP__JT_Roster,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_Roster::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_Roster::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_Roster.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_Roster::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_PushRoster_t {
    QByteArrayData data[4];
    char stringdata0[35];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_PushRoster_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_PushRoster_t qt_meta_stringdata_XMPP__JT_PushRoster = {
    {
QT_MOC_LITERAL(0, 0, 19), // "XMPP::JT_PushRoster"
QT_MOC_LITERAL(1, 20, 6), // "roster"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 6) // "Roster"

    },
    "XMPP::JT_PushRoster\0roster\0\0Roster"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_PushRoster[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

       0        // eod
};

void XMPP::JT_PushRoster::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_PushRoster *_t = static_cast<JT_PushRoster *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->roster((*reinterpret_cast< const Roster(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JT_PushRoster::*_t)(const Roster & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushRoster::roster)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject XMPP::JT_PushRoster::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_PushRoster.data,
      qt_meta_data_XMPP__JT_PushRoster,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_PushRoster::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_PushRoster::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_PushRoster.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_PushRoster::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void XMPP::JT_PushRoster::roster(const Roster & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_XMPP__JT_Presence_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_Presence_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_Presence_t qt_meta_stringdata_XMPP__JT_Presence = {
    {
QT_MOC_LITERAL(0, 0, 17) // "XMPP::JT_Presence"

    },
    "XMPP::JT_Presence"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_Presence[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_Presence::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_Presence::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_Presence.data,
      qt_meta_data_XMPP__JT_Presence,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_Presence::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_Presence::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_Presence.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_Presence::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_PushPresence_t {
    QByteArrayData data[6];
    char stringdata0[56];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_PushPresence_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_PushPresence_t qt_meta_stringdata_XMPP__JT_PushPresence = {
    {
QT_MOC_LITERAL(0, 0, 21), // "XMPP::JT_PushPresence"
QT_MOC_LITERAL(1, 22, 8), // "presence"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 3), // "Jid"
QT_MOC_LITERAL(4, 36, 6), // "Status"
QT_MOC_LITERAL(5, 43, 12) // "subscription"

    },
    "XMPP::JT_PushPresence\0presence\0\0Jid\0"
    "Status\0subscription"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_PushPresence[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,
       5,    3,   29,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    2,    2,    2,

       0        // eod
};

void XMPP::JT_PushPresence::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_PushPresence *_t = static_cast<JT_PushPresence *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->presence((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Status(*)>(_a[2]))); break;
        case 1: _t->subscription((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JT_PushPresence::*_t)(const Jid & , const Status & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushPresence::presence)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (JT_PushPresence::*_t)(const Jid & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushPresence::subscription)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject XMPP::JT_PushPresence::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_PushPresence.data,
      qt_meta_data_XMPP__JT_PushPresence,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_PushPresence::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_PushPresence::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_PushPresence.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_PushPresence::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void XMPP::JT_PushPresence::presence(const Jid & _t1, const Status & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::JT_PushPresence::subscription(const Jid & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_XMPP__JT_Message_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_Message_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_Message_t qt_meta_stringdata_XMPP__JT_Message = {
    {
QT_MOC_LITERAL(0, 0, 16) // "XMPP::JT_Message"

    },
    "XMPP::JT_Message"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_Message[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_Message::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_Message::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_Message.data,
      qt_meta_data_XMPP__JT_Message,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_Message::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_Message::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_Message.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_Message::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_PushMessage_t {
    QByteArrayData data[4];
    char stringdata0[38];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_PushMessage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_PushMessage_t qt_meta_stringdata_XMPP__JT_PushMessage = {
    {
QT_MOC_LITERAL(0, 0, 20), // "XMPP::JT_PushMessage"
QT_MOC_LITERAL(1, 21, 7), // "message"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 7) // "Message"

    },
    "XMPP::JT_PushMessage\0message\0\0Message"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_PushMessage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

       0        // eod
};

void XMPP::JT_PushMessage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_PushMessage *_t = static_cast<JT_PushMessage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->message((*reinterpret_cast< const Message(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JT_PushMessage::*_t)(const Message & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushMessage::message)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject XMPP::JT_PushMessage::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_PushMessage.data,
      qt_meta_data_XMPP__JT_PushMessage,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_PushMessage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_PushMessage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_PushMessage.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_PushMessage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void XMPP::JT_PushMessage::message(const Message & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_XMPP__JT_GetServices_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_GetServices_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_GetServices_t qt_meta_stringdata_XMPP__JT_GetServices = {
    {
QT_MOC_LITERAL(0, 0, 20) // "XMPP::JT_GetServices"

    },
    "XMPP::JT_GetServices"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_GetServices[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_GetServices::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_GetServices::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_GetServices.data,
      qt_meta_data_XMPP__JT_GetServices,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_GetServices::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_GetServices::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_GetServices.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_GetServices::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_VCard_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_VCard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_VCard_t qt_meta_stringdata_XMPP__JT_VCard = {
    {
QT_MOC_LITERAL(0, 0, 14) // "XMPP::JT_VCard"

    },
    "XMPP::JT_VCard"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_VCard[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_VCard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_VCard::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_VCard.data,
      qt_meta_data_XMPP__JT_VCard,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_VCard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_VCard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_VCard.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_VCard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_Search_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_Search_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_Search_t qt_meta_stringdata_XMPP__JT_Search = {
    {
QT_MOC_LITERAL(0, 0, 15) // "XMPP::JT_Search"

    },
    "XMPP::JT_Search"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_Search[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_Search::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_Search::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_Search.data,
      qt_meta_data_XMPP__JT_Search,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_Search::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_Search::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_Search.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_Search::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_ClientVersion_t {
    QByteArrayData data[1];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_ClientVersion_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_ClientVersion_t qt_meta_stringdata_XMPP__JT_ClientVersion = {
    {
QT_MOC_LITERAL(0, 0, 22) // "XMPP::JT_ClientVersion"

    },
    "XMPP::JT_ClientVersion"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_ClientVersion[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_ClientVersion::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_ClientVersion::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_ClientVersion.data,
      qt_meta_data_XMPP__JT_ClientVersion,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_ClientVersion::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_ClientVersion::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_ClientVersion.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_ClientVersion::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_ServInfo_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_ServInfo_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_ServInfo_t qt_meta_stringdata_XMPP__JT_ServInfo = {
    {
QT_MOC_LITERAL(0, 0, 17) // "XMPP::JT_ServInfo"

    },
    "XMPP::JT_ServInfo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_ServInfo[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_ServInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_ServInfo::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_ServInfo.data,
      qt_meta_data_XMPP__JT_ServInfo,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_ServInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_ServInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_ServInfo.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_ServInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_Gateway_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_Gateway_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_Gateway_t qt_meta_stringdata_XMPP__JT_Gateway = {
    {
QT_MOC_LITERAL(0, 0, 16) // "XMPP::JT_Gateway"

    },
    "XMPP::JT_Gateway"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_Gateway[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_Gateway::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_Gateway::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_Gateway.data,
      qt_meta_data_XMPP__JT_Gateway,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_Gateway::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_Gateway::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_Gateway.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_Gateway::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_Browse_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_Browse_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_Browse_t qt_meta_stringdata_XMPP__JT_Browse = {
    {
QT_MOC_LITERAL(0, 0, 15) // "XMPP::JT_Browse"

    },
    "XMPP::JT_Browse"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_Browse[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_Browse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_Browse::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_Browse.data,
      qt_meta_data_XMPP__JT_Browse,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_Browse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_Browse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_Browse.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_Browse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_DiscoItems_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_DiscoItems_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_DiscoItems_t qt_meta_stringdata_XMPP__JT_DiscoItems = {
    {
QT_MOC_LITERAL(0, 0, 19) // "XMPP::JT_DiscoItems"

    },
    "XMPP::JT_DiscoItems"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_DiscoItems[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_DiscoItems::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_DiscoItems::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_DiscoItems.data,
      qt_meta_data_XMPP__JT_DiscoItems,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_DiscoItems::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_DiscoItems::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_DiscoItems.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_DiscoItems::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_DiscoPublish_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_DiscoPublish_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_DiscoPublish_t qt_meta_stringdata_XMPP__JT_DiscoPublish = {
    {
QT_MOC_LITERAL(0, 0, 21) // "XMPP::JT_DiscoPublish"

    },
    "XMPP::JT_DiscoPublish"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_DiscoPublish[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_DiscoPublish::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_DiscoPublish::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_DiscoPublish.data,
      qt_meta_data_XMPP__JT_DiscoPublish,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_DiscoPublish::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_DiscoPublish::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_DiscoPublish.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_DiscoPublish::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
