#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'ksirkskineditorcountriesselectiondialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKSKINEDITORCOUNTRIESSELECTIONDIALOG_H
#define UI_KSIRKSKINEDITORCOUNTRIESSELECTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CountriesSelectionDialog
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *countriesList;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CountriesSelectionDialog)
    {
        if (CountriesSelectionDialog->objectName().isEmpty())
            CountriesSelectionDialog->setObjectName(QStringLiteral("CountriesSelectionDialog"));
        CountriesSelectionDialog->resize(415, 609);
        verticalLayout = new QVBoxLayout(CountriesSelectionDialog);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        countriesList = new QListWidget(CountriesSelectionDialog);
        countriesList->setObjectName(QStringLiteral("countriesList"));

        verticalLayout->addWidget(countriesList);

        buttonBox = new QDialogButtonBox(CountriesSelectionDialog);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CountriesSelectionDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), CountriesSelectionDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), CountriesSelectionDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(CountriesSelectionDialog);
    } // setupUi

    void retranslateUi(QDialog *CountriesSelectionDialog)
    {
        CountriesSelectionDialog->setWindowTitle(tr2i18n("Country Selection Dialog", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        countriesList->setToolTip(tr2i18n("Country list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        countriesList->setWhatsThis(tr2i18n("List of all the countries defined in the world. Currently selected countries are highlighted. You can modify the selection using the mouse and Ctrl and Shift keys.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
    } // retranslateUi

};

namespace Ui {
    class CountriesSelectionDialog: public Ui_CountriesSelectionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKSKINEDITORCOUNTRIESSELECTIONDIALOG_H

