/****************************************************************************
** Meta object code from reading C++ file 'netnames.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/irisnet/corelib/netnames.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'netnames.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__NameResolver_t {
    QByteArrayData data[8];
    char stringdata0[99];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__NameResolver_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__NameResolver_t qt_meta_stringdata_XMPP__NameResolver = {
    {
QT_MOC_LITERAL(0, 0, 18), // "XMPP::NameResolver"
QT_MOC_LITERAL(1, 19, 12), // "resultsReady"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 23), // "QList<XMPP::NameRecord>"
QT_MOC_LITERAL(4, 57, 7), // "results"
QT_MOC_LITERAL(5, 65, 5), // "error"
QT_MOC_LITERAL(6, 71, 25), // "XMPP::NameResolver::Error"
QT_MOC_LITERAL(7, 97, 1) // "e"

    },
    "XMPP::NameResolver\0resultsReady\0\0"
    "QList<XMPP::NameRecord>\0results\0error\0"
    "XMPP::NameResolver::Error\0e"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__NameResolver[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x06 /* Public */,
       5,    1,   27,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,

       0        // eod
};

void XMPP::NameResolver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NameResolver *_t = static_cast<NameResolver *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->resultsReady((*reinterpret_cast< const QList<XMPP::NameRecord>(*)>(_a[1]))); break;
        case 1: _t->error((*reinterpret_cast< XMPP::NameResolver::Error(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (NameResolver::*_t)(const QList<XMPP::NameRecord> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NameResolver::resultsReady)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (NameResolver::*_t)(XMPP::NameResolver::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NameResolver::error)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject XMPP::NameResolver::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__NameResolver.data,
      qt_meta_data_XMPP__NameResolver,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::NameResolver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::NameResolver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__NameResolver.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::NameResolver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void XMPP::NameResolver::resultsReady(const QList<XMPP::NameRecord> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::NameResolver::error(XMPP::NameResolver::Error _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_XMPP__ServiceBrowser_t {
    QByteArrayData data[7];
    char stringdata0[97];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__ServiceBrowser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__ServiceBrowser_t qt_meta_stringdata_XMPP__ServiceBrowser = {
    {
QT_MOC_LITERAL(0, 0, 20), // "XMPP::ServiceBrowser"
QT_MOC_LITERAL(1, 21, 17), // "instanceAvailable"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 21), // "XMPP::ServiceInstance"
QT_MOC_LITERAL(4, 62, 8), // "instance"
QT_MOC_LITERAL(5, 71, 19), // "instanceUnavailable"
QT_MOC_LITERAL(6, 91, 5) // "error"

    },
    "XMPP::ServiceBrowser\0instanceAvailable\0"
    "\0XMPP::ServiceInstance\0instance\0"
    "instanceUnavailable\0error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__ServiceBrowser[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       5,    1,   32,    2, 0x06 /* Public */,
       6,    0,   35,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

       0        // eod
};

void XMPP::ServiceBrowser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServiceBrowser *_t = static_cast<ServiceBrowser *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->instanceAvailable((*reinterpret_cast< const XMPP::ServiceInstance(*)>(_a[1]))); break;
        case 1: _t->instanceUnavailable((*reinterpret_cast< const XMPP::ServiceInstance(*)>(_a[1]))); break;
        case 2: _t->error(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ServiceBrowser::*_t)(const XMPP::ServiceInstance & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceBrowser::instanceAvailable)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ServiceBrowser::*_t)(const XMPP::ServiceInstance & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceBrowser::instanceUnavailable)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ServiceBrowser::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceBrowser::error)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject XMPP::ServiceBrowser::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__ServiceBrowser.data,
      qt_meta_data_XMPP__ServiceBrowser,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::ServiceBrowser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::ServiceBrowser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__ServiceBrowser.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::ServiceBrowser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void XMPP::ServiceBrowser::instanceAvailable(const XMPP::ServiceInstance & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::ServiceBrowser::instanceUnavailable(const XMPP::ServiceInstance & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void XMPP::ServiceBrowser::error()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
struct qt_meta_stringdata_XMPP__ServiceResolver_t {
    QByteArrayData data[8];
    char stringdata0[77];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__ServiceResolver_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__ServiceResolver_t qt_meta_stringdata_XMPP__ServiceResolver = {
    {
QT_MOC_LITERAL(0, 0, 21), // "XMPP::ServiceResolver"
QT_MOC_LITERAL(1, 22, 12), // "resultsReady"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 12), // "QHostAddress"
QT_MOC_LITERAL(4, 49, 7), // "address"
QT_MOC_LITERAL(5, 57, 4), // "port"
QT_MOC_LITERAL(6, 62, 8), // "finished"
QT_MOC_LITERAL(7, 71, 5) // "error"

    },
    "XMPP::ServiceResolver\0resultsReady\0\0"
    "QHostAddress\0address\0port\0finished\0"
    "error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__ServiceResolver[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x06 /* Public */,
       6,    0,   34,    2, 0x06 /* Public */,
       7,    0,   35,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::ServiceResolver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServiceResolver *_t = static_cast<ServiceResolver *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->resultsReady((*reinterpret_cast< const QHostAddress(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->finished(); break;
        case 2: _t->error(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ServiceResolver::*_t)(const QHostAddress & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceResolver::resultsReady)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ServiceResolver::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceResolver::finished)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ServiceResolver::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceResolver::error)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject XMPP::ServiceResolver::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__ServiceResolver.data,
      qt_meta_data_XMPP__ServiceResolver,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::ServiceResolver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::ServiceResolver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__ServiceResolver.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::ServiceResolver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void XMPP::ServiceResolver::resultsReady(const QHostAddress & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::ServiceResolver::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XMPP::ServiceResolver::error()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
struct qt_meta_stringdata_XMPP__ServiceLocalPublisher_t {
    QByteArrayData data[6];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__ServiceLocalPublisher_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__ServiceLocalPublisher_t qt_meta_stringdata_XMPP__ServiceLocalPublisher = {
    {
QT_MOC_LITERAL(0, 0, 27), // "XMPP::ServiceLocalPublisher"
QT_MOC_LITERAL(1, 28, 9), // "published"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 5), // "error"
QT_MOC_LITERAL(4, 45, 34), // "XMPP::ServiceLocalPublisher::..."
QT_MOC_LITERAL(5, 80, 1) // "e"

    },
    "XMPP::ServiceLocalPublisher\0published\0"
    "\0error\0XMPP::ServiceLocalPublisher::Error\0"
    "e"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__ServiceLocalPublisher[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    1,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,

       0        // eod
};

void XMPP::ServiceLocalPublisher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServiceLocalPublisher *_t = static_cast<ServiceLocalPublisher *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->published(); break;
        case 1: _t->error((*reinterpret_cast< XMPP::ServiceLocalPublisher::Error(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ServiceLocalPublisher::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceLocalPublisher::published)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ServiceLocalPublisher::*_t)(XMPP::ServiceLocalPublisher::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceLocalPublisher::error)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject XMPP::ServiceLocalPublisher::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__ServiceLocalPublisher.data,
      qt_meta_data_XMPP__ServiceLocalPublisher,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::ServiceLocalPublisher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::ServiceLocalPublisher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__ServiceLocalPublisher.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::ServiceLocalPublisher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void XMPP::ServiceLocalPublisher::published()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XMPP::ServiceLocalPublisher::error(XMPP::ServiceLocalPublisher::Error _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
