/****************************************************************************
** Meta object code from reading C++ file 'kmessagejabber.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirk/Jabber/kmessagejabber.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmessagejabber.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMessageJabber_t {
    QByteArrayData data[12];
    char stringdata0[158];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMessageJabber_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMessageJabber_t qt_meta_stringdata_KMessageJabber = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KMessageJabber"
QT_MOC_LITERAL(1, 15, 19), // "slotMessageReceived"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 13), // "XMPP::Message"
QT_MOC_LITERAL(4, 50, 7), // "message"
QT_MOC_LITERAL(5, 58, 17), // "slotGroupChatLeft"
QT_MOC_LITERAL(6, 76, 23), // "slotResourceUnavailable"
QT_MOC_LITERAL(7, 100, 3), // "Jid"
QT_MOC_LITERAL(8, 104, 8), // "Resource"
QT_MOC_LITERAL(9, 113, 21), // "slotGroupChatPresence"
QT_MOC_LITERAL(10, 135, 9), // "XMPP::Jid"
QT_MOC_LITERAL(11, 145, 12) // "XMPP::Status"

    },
    "KMessageJabber\0slotMessageReceived\0\0"
    "XMPP::Message\0message\0slotGroupChatLeft\0"
    "slotResourceUnavailable\0Jid\0Resource\0"
    "slotGroupChatPresence\0XMPP::Jid\0"
    "XMPP::Status"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMessageJabber[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x09 /* Protected */,
       5,    1,   37,    2, 0x09 /* Protected */,
       6,    2,   40,    2, 0x09 /* Protected */,
       9,    2,   45,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 8,    2,    2,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 11,    2,    2,

       0        // eod
};

void KMessageJabber::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMessageJabber *_t = static_cast<KMessageJabber *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotMessageReceived((*reinterpret_cast< const XMPP::Message(*)>(_a[1]))); break;
        case 1: _t->slotGroupChatLeft((*reinterpret_cast< const XMPP::Message(*)>(_a[1]))); break;
        case 2: _t->slotResourceUnavailable((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Resource(*)>(_a[2]))); break;
        case 3: _t->slotGroupChatPresence((*reinterpret_cast< const XMPP::Jid(*)>(_a[1])),(*reinterpret_cast< const XMPP::Status(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject KMessageJabber::staticMetaObject = {
    { &KMessageIO::staticMetaObject, qt_meta_stringdata_KMessageJabber.data,
      qt_meta_data_KMessageJabber,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMessageJabber::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMessageJabber::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMessageJabber.stringdata0))
        return static_cast<void*>(this);
    return KMessageIO::qt_metacast(_clname);
}

int KMessageJabber::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMessageIO::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
