/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirkskineditor/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KsirkSkinEditor__MainWindow_t {
    QByteArrayData data[98];
    char stringdata0[2084];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KsirkSkinEditor__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KsirkSkinEditor__MainWindow_t qt_meta_stringdata_KsirkSkinEditor__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KsirkSkinEditor::MainWindow"
QT_MOC_LITERAL(1, 28, 24), // "slotShowAboutApplication"
QT_MOC_LITERAL(2, 53, 0), // ""
QT_MOC_LITERAL(3, 54, 16), // "optionsConfigure"
QT_MOC_LITERAL(4, 71, 21), // "slotFlagButtonClicked"
QT_MOC_LITERAL(5, 93, 25), // "slotInfantryButtonClicked"
QT_MOC_LITERAL(6, 119, 24), // "slotCavalryButtonClicked"
QT_MOC_LITERAL(7, 144, 23), // "slotCannonButtonClicked"
QT_MOC_LITERAL(8, 168, 23), // "slotAnchorButtonClicked"
QT_MOC_LITERAL(9, 192, 23), // "slotCenterButtonClicked"
QT_MOC_LITERAL(10, 216, 12), // "slotPosition"
QT_MOC_LITERAL(11, 229, 17), // "slotPressPosition"
QT_MOC_LITERAL(12, 247, 19), // "slotCountrySelected"
QT_MOC_LITERAL(13, 267, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(14, 284, 4), // "item"
QT_MOC_LITERAL(15, 289, 21), // "slotContinentSelected"
QT_MOC_LITERAL(16, 311, 15), // "slotItemPressed"
QT_MOC_LITERAL(17, 327, 14), // "QGraphicsItem*"
QT_MOC_LITERAL(18, 342, 14), // "slotItemPlaced"
QT_MOC_LITERAL(19, 357, 12), // "slotOpenSkin"
QT_MOC_LITERAL(20, 370, 3), // "dir"
QT_MOC_LITERAL(21, 374, 12), // "slotSaveSkin"
QT_MOC_LITERAL(22, 387, 15), // "slotURLSelected"
QT_MOC_LITERAL(23, 403, 18), // "slotSkinNameEdited"
QT_MOC_LITERAL(24, 422, 19), // "slotSkinWidthEdited"
QT_MOC_LITERAL(25, 442, 20), // "slotSkinHeightEdited"
QT_MOC_LITERAL(26, 463, 25), // "slotSkinDescriptionEdited"
QT_MOC_LITERAL(27, 489, 23), // "slotSkinWidthDiffEdited"
QT_MOC_LITERAL(28, 513, 14), // "slotNewCountry"
QT_MOC_LITERAL(29, 528, 17), // "slotDeleteCountry"
QT_MOC_LITERAL(30, 546, 14), // "slotNeighbours"
QT_MOC_LITERAL(31, 561, 22), // "slotSkinPartTabChanged"
QT_MOC_LITERAL(32, 584, 5), // "index"
QT_MOC_LITERAL(33, 590, 22), // "slotContinentCountries"
QT_MOC_LITERAL(34, 613, 24), // "slotContinentBonusEdited"
QT_MOC_LITERAL(35, 638, 20), // "slotFlagWidthChanged"
QT_MOC_LITERAL(36, 659, 21), // "slotFlagHeightChanged"
QT_MOC_LITERAL(37, 681, 21), // "slotFlagFramesChanged"
QT_MOC_LITERAL(38, 703, 23), // "slotFlagVersionsChanged"
QT_MOC_LITERAL(39, 727, 24), // "slotInfantryWidthChanged"
QT_MOC_LITERAL(40, 752, 25), // "slotInfantryHeightChanged"
QT_MOC_LITERAL(41, 778, 25), // "slotInfantryFramesChanged"
QT_MOC_LITERAL(42, 804, 27), // "slotInfantryVersionsChanged"
QT_MOC_LITERAL(43, 832, 23), // "slotCavalryWidthChanged"
QT_MOC_LITERAL(44, 856, 24), // "slotCavalryHeightChanged"
QT_MOC_LITERAL(45, 881, 24), // "slotCavalryFramesChanged"
QT_MOC_LITERAL(46, 906, 26), // "slotCavalryVersionsChanged"
QT_MOC_LITERAL(47, 933, 22), // "slotCannonWidthChanged"
QT_MOC_LITERAL(48, 956, 23), // "slotCannonHeightChanged"
QT_MOC_LITERAL(49, 980, 23), // "slotCannonFramesChanged"
QT_MOC_LITERAL(50, 1004, 25), // "slotCannonVersionsChanged"
QT_MOC_LITERAL(51, 1030, 22), // "slotFiringWidthChanged"
QT_MOC_LITERAL(52, 1053, 23), // "slotFiringHeightChanged"
QT_MOC_LITERAL(53, 1077, 23), // "slotFiringFramesChanged"
QT_MOC_LITERAL(54, 1101, 25), // "slotFiringVersionsChanged"
QT_MOC_LITERAL(55, 1127, 25), // "slotExplodingWidthChanged"
QT_MOC_LITERAL(56, 1153, 26), // "slotExplodingHeightChanged"
QT_MOC_LITERAL(57, 1180, 26), // "slotExplodingFramesChanged"
QT_MOC_LITERAL(58, 1207, 28), // "slotExplodingVersionsChanged"
QT_MOC_LITERAL(59, 1236, 16), // "slotNewContinent"
QT_MOC_LITERAL(60, 1253, 19), // "slotDeleteContinent"
QT_MOC_LITERAL(61, 1273, 16), // "slotGoalSelected"
QT_MOC_LITERAL(62, 1290, 24), // "slotGoalTypeWorldClicked"
QT_MOC_LITERAL(63, 1315, 25), // "slotGoalTypePlayerClicked"
QT_MOC_LITERAL(64, 1341, 28), // "slotGoalTypeCountriesClicked"
QT_MOC_LITERAL(65, 1370, 29), // "slotGoalTypeContinentsClicked"
QT_MOC_LITERAL(66, 1400, 25), // "slotGoalDescriptionEdited"
QT_MOC_LITERAL(67, 1426, 26), // "slotGoalNbCountriesChanged"
QT_MOC_LITERAL(68, 1453, 32), // "slotGoalNbArmiesByCountryChanged"
QT_MOC_LITERAL(69, 1486, 27), // "slotGoalAnyContinentChanged"
QT_MOC_LITERAL(70, 1514, 18), // "slotGoalContinents"
QT_MOC_LITERAL(71, 1533, 11), // "slotNewGoal"
QT_MOC_LITERAL(72, 1545, 14), // "slotDeleteGoal"
QT_MOC_LITERAL(73, 1560, 23), // "slotNationalitySelected"
QT_MOC_LITERAL(74, 1584, 25), // "slotNationalityNameEdited"
QT_MOC_LITERAL(75, 1610, 31), // "slotNationalityLeaderNameEdited"
QT_MOC_LITERAL(76, 1642, 25), // "slotNationalityFlagEdited"
QT_MOC_LITERAL(77, 1668, 18), // "slotNewNationality"
QT_MOC_LITERAL(78, 1687, 21), // "slotDeleteNationality"
QT_MOC_LITERAL(79, 1709, 16), // "slotFontSelected"
QT_MOC_LITERAL(80, 1726, 4), // "font"
QT_MOC_LITERAL(81, 1731, 14), // "slotFgSelected"
QT_MOC_LITERAL(82, 1746, 5), // "color"
QT_MOC_LITERAL(83, 1752, 19), // "slotBgColorSelected"
QT_MOC_LITERAL(84, 1772, 19), // "slotReleasePosition"
QT_MOC_LITERAL(85, 1792, 21), // "slotFLagxValueChanged"
QT_MOC_LITERAL(86, 1814, 21), // "slotFLagyValueChanged"
QT_MOC_LITERAL(87, 1836, 1), // "v"
QT_MOC_LITERAL(88, 1838, 23), // "slotCenterxValueChanged"
QT_MOC_LITERAL(89, 1862, 23), // "slotCenteryValueChanged"
QT_MOC_LITERAL(90, 1886, 23), // "slotAnchorxValueChanged"
QT_MOC_LITERAL(91, 1910, 23), // "slotAnchoryValueChanged"
QT_MOC_LITERAL(92, 1934, 24), // "slotCavalryxValueChanged"
QT_MOC_LITERAL(93, 1959, 24), // "slotCavalryyValueChanged"
QT_MOC_LITERAL(94, 1984, 23), // "slotCannonxValueChanged"
QT_MOC_LITERAL(95, 2008, 23), // "slotCannonyValueChanged"
QT_MOC_LITERAL(96, 2032, 25), // "slotInfantryxValueChanged"
QT_MOC_LITERAL(97, 2058, 25) // "slotInfantryyValueChanged"

    },
    "KsirkSkinEditor::MainWindow\0"
    "slotShowAboutApplication\0\0optionsConfigure\0"
    "slotFlagButtonClicked\0slotInfantryButtonClicked\0"
    "slotCavalryButtonClicked\0"
    "slotCannonButtonClicked\0slotAnchorButtonClicked\0"
    "slotCenterButtonClicked\0slotPosition\0"
    "slotPressPosition\0slotCountrySelected\0"
    "QListWidgetItem*\0item\0slotContinentSelected\0"
    "slotItemPressed\0QGraphicsItem*\0"
    "slotItemPlaced\0slotOpenSkin\0dir\0"
    "slotSaveSkin\0slotURLSelected\0"
    "slotSkinNameEdited\0slotSkinWidthEdited\0"
    "slotSkinHeightEdited\0slotSkinDescriptionEdited\0"
    "slotSkinWidthDiffEdited\0slotNewCountry\0"
    "slotDeleteCountry\0slotNeighbours\0"
    "slotSkinPartTabChanged\0index\0"
    "slotContinentCountries\0slotContinentBonusEdited\0"
    "slotFlagWidthChanged\0slotFlagHeightChanged\0"
    "slotFlagFramesChanged\0slotFlagVersionsChanged\0"
    "slotInfantryWidthChanged\0"
    "slotInfantryHeightChanged\0"
    "slotInfantryFramesChanged\0"
    "slotInfantryVersionsChanged\0"
    "slotCavalryWidthChanged\0"
    "slotCavalryHeightChanged\0"
    "slotCavalryFramesChanged\0"
    "slotCavalryVersionsChanged\0"
    "slotCannonWidthChanged\0slotCannonHeightChanged\0"
    "slotCannonFramesChanged\0"
    "slotCannonVersionsChanged\0"
    "slotFiringWidthChanged\0slotFiringHeightChanged\0"
    "slotFiringFramesChanged\0"
    "slotFiringVersionsChanged\0"
    "slotExplodingWidthChanged\0"
    "slotExplodingHeightChanged\0"
    "slotExplodingFramesChanged\0"
    "slotExplodingVersionsChanged\0"
    "slotNewContinent\0slotDeleteContinent\0"
    "slotGoalSelected\0slotGoalTypeWorldClicked\0"
    "slotGoalTypePlayerClicked\0"
    "slotGoalTypeCountriesClicked\0"
    "slotGoalTypeContinentsClicked\0"
    "slotGoalDescriptionEdited\0"
    "slotGoalNbCountriesChanged\0"
    "slotGoalNbArmiesByCountryChanged\0"
    "slotGoalAnyContinentChanged\0"
    "slotGoalContinents\0slotNewGoal\0"
    "slotDeleteGoal\0slotNationalitySelected\0"
    "slotNationalityNameEdited\0"
    "slotNationalityLeaderNameEdited\0"
    "slotNationalityFlagEdited\0slotNewNationality\0"
    "slotDeleteNationality\0slotFontSelected\0"
    "font\0slotFgSelected\0color\0slotBgColorSelected\0"
    "slotReleasePosition\0slotFLagxValueChanged\0"
    "slotFLagyValueChanged\0v\0slotCenterxValueChanged\0"
    "slotCenteryValueChanged\0slotAnchorxValueChanged\0"
    "slotAnchoryValueChanged\0"
    "slotCavalryxValueChanged\0"
    "slotCavalryyValueChanged\0"
    "slotCannonxValueChanged\0slotCannonyValueChanged\0"
    "slotInfantryxValueChanged\0"
    "slotInfantryyValueChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KsirkSkinEditor__MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      89,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  459,    2, 0x0a /* Public */,
       3,    0,  460,    2, 0x08 /* Private */,
       4,    0,  461,    2, 0x08 /* Private */,
       5,    0,  462,    2, 0x08 /* Private */,
       6,    0,  463,    2, 0x08 /* Private */,
       7,    0,  464,    2, 0x08 /* Private */,
       8,    0,  465,    2, 0x08 /* Private */,
       9,    0,  466,    2, 0x08 /* Private */,
      10,    1,  467,    2, 0x08 /* Private */,
      11,    1,  470,    2, 0x08 /* Private */,
      12,    1,  473,    2, 0x08 /* Private */,
      15,    1,  476,    2, 0x08 /* Private */,
      16,    2,  479,    2, 0x08 /* Private */,
      18,    2,  484,    2, 0x08 /* Private */,
      19,    1,  489,    2, 0x08 /* Private */,
      19,    0,  492,    2, 0x28 /* Private | MethodCloned */,
      21,    0,  493,    2, 0x08 /* Private */,
      22,    1,  494,    2, 0x08 /* Private */,
      23,    0,  497,    2, 0x08 /* Private */,
      24,    1,  498,    2, 0x08 /* Private */,
      25,    1,  501,    2, 0x08 /* Private */,
      26,    0,  504,    2, 0x08 /* Private */,
      27,    0,  505,    2, 0x08 /* Private */,
      28,    0,  506,    2, 0x08 /* Private */,
      29,    0,  507,    2, 0x08 /* Private */,
      30,    0,  508,    2, 0x08 /* Private */,
      31,    1,  509,    2, 0x08 /* Private */,
      33,    0,  512,    2, 0x08 /* Private */,
      34,    1,  513,    2, 0x08 /* Private */,
      35,    1,  516,    2, 0x08 /* Private */,
      36,    1,  519,    2, 0x08 /* Private */,
      37,    1,  522,    2, 0x08 /* Private */,
      38,    1,  525,    2, 0x08 /* Private */,
      39,    1,  528,    2, 0x08 /* Private */,
      40,    1,  531,    2, 0x08 /* Private */,
      41,    1,  534,    2, 0x08 /* Private */,
      42,    1,  537,    2, 0x08 /* Private */,
      43,    1,  540,    2, 0x08 /* Private */,
      44,    1,  543,    2, 0x08 /* Private */,
      45,    1,  546,    2, 0x08 /* Private */,
      46,    1,  549,    2, 0x08 /* Private */,
      47,    1,  552,    2, 0x08 /* Private */,
      48,    1,  555,    2, 0x08 /* Private */,
      49,    1,  558,    2, 0x08 /* Private */,
      50,    1,  561,    2, 0x08 /* Private */,
      51,    1,  564,    2, 0x08 /* Private */,
      52,    1,  567,    2, 0x08 /* Private */,
      53,    1,  570,    2, 0x08 /* Private */,
      54,    1,  573,    2, 0x08 /* Private */,
      55,    1,  576,    2, 0x08 /* Private */,
      56,    1,  579,    2, 0x08 /* Private */,
      57,    1,  582,    2, 0x08 /* Private */,
      58,    1,  585,    2, 0x08 /* Private */,
      59,    0,  588,    2, 0x08 /* Private */,
      60,    0,  589,    2, 0x08 /* Private */,
      61,    1,  590,    2, 0x08 /* Private */,
      62,    0,  593,    2, 0x08 /* Private */,
      63,    0,  594,    2, 0x08 /* Private */,
      64,    0,  595,    2, 0x08 /* Private */,
      65,    0,  596,    2, 0x08 /* Private */,
      66,    0,  597,    2, 0x08 /* Private */,
      67,    1,  598,    2, 0x08 /* Private */,
      68,    1,  601,    2, 0x08 /* Private */,
      69,    1,  604,    2, 0x08 /* Private */,
      70,    0,  607,    2, 0x08 /* Private */,
      71,    0,  608,    2, 0x08 /* Private */,
      72,    0,  609,    2, 0x08 /* Private */,
      73,    1,  610,    2, 0x08 /* Private */,
      74,    0,  613,    2, 0x08 /* Private */,
      75,    0,  614,    2, 0x08 /* Private */,
      76,    1,  615,    2, 0x08 /* Private */,
      77,    0,  618,    2, 0x08 /* Private */,
      78,    0,  619,    2, 0x08 /* Private */,
      79,    1,  620,    2, 0x08 /* Private */,
      81,    1,  623,    2, 0x08 /* Private */,
      83,    1,  626,    2, 0x08 /* Private */,
      84,    1,  629,    2, 0x08 /* Private */,
      85,    1,  632,    2, 0x08 /* Private */,
      86,    1,  635,    2, 0x08 /* Private */,
      88,    1,  638,    2, 0x08 /* Private */,
      89,    1,  641,    2, 0x08 /* Private */,
      90,    1,  644,    2, 0x08 /* Private */,
      91,    1,  647,    2, 0x08 /* Private */,
      92,    1,  650,    2, 0x08 /* Private */,
      93,    1,  653,    2, 0x08 /* Private */,
      94,    1,  656,    2, 0x08 /* Private */,
      95,    1,  659,    2, 0x08 /* Private */,
      96,    1,  662,    2, 0x08 /* Private */,
      97,    1,  665,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 17, QMetaType::QPointF,    2,    2,
    QMetaType::Void, 0x80000000 | 17, QMetaType::QPointF,    2,    2,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QFont,   80,
    QMetaType::Void, QMetaType::QColor,   82,
    QMetaType::Void, QMetaType::QColor,   82,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   87,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   87,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   87,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   87,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   87,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   87,

       0        // eod
};

void KsirkSkinEditor::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotShowAboutApplication(); break;
        case 1: _t->optionsConfigure(); break;
        case 2: _t->slotFlagButtonClicked(); break;
        case 3: _t->slotInfantryButtonClicked(); break;
        case 4: _t->slotCavalryButtonClicked(); break;
        case 5: _t->slotCannonButtonClicked(); break;
        case 6: _t->slotAnchorButtonClicked(); break;
        case 7: _t->slotCenterButtonClicked(); break;
        case 8: _t->slotPosition((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 9: _t->slotPressPosition((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 10: _t->slotCountrySelected((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 11: _t->slotContinentSelected((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 12: _t->slotItemPressed((*reinterpret_cast< QGraphicsItem*(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2]))); break;
        case 13: _t->slotItemPlaced((*reinterpret_cast< QGraphicsItem*(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2]))); break;
        case 14: _t->slotOpenSkin((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->slotOpenSkin(); break;
        case 16: _t->slotSaveSkin(); break;
        case 17: _t->slotURLSelected((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 18: _t->slotSkinNameEdited(); break;
        case 19: _t->slotSkinWidthEdited((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->slotSkinHeightEdited((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->slotSkinDescriptionEdited(); break;
        case 22: _t->slotSkinWidthDiffEdited(); break;
        case 23: _t->slotNewCountry(); break;
        case 24: _t->slotDeleteCountry(); break;
        case 25: _t->slotNeighbours(); break;
        case 26: _t->slotSkinPartTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: _t->slotContinentCountries(); break;
        case 28: _t->slotContinentBonusEdited((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->slotFlagWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 30: _t->slotFlagHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->slotFlagFramesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->slotFlagVersionsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->slotInfantryWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->slotInfantryHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 35: _t->slotInfantryFramesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 36: _t->slotInfantryVersionsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: _t->slotCavalryWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 38: _t->slotCavalryHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 39: _t->slotCavalryFramesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 40: _t->slotCavalryVersionsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 41: _t->slotCannonWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 42: _t->slotCannonHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 43: _t->slotCannonFramesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 44: _t->slotCannonVersionsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 45: _t->slotFiringWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 46: _t->slotFiringHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 47: _t->slotFiringFramesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->slotFiringVersionsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 49: _t->slotExplodingWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 50: _t->slotExplodingHeightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 51: _t->slotExplodingFramesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 52: _t->slotExplodingVersionsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 53: _t->slotNewContinent(); break;
        case 54: _t->slotDeleteContinent(); break;
        case 55: _t->slotGoalSelected((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 56: _t->slotGoalTypeWorldClicked(); break;
        case 57: _t->slotGoalTypePlayerClicked(); break;
        case 58: _t->slotGoalTypeCountriesClicked(); break;
        case 59: _t->slotGoalTypeContinentsClicked(); break;
        case 60: _t->slotGoalDescriptionEdited(); break;
        case 61: _t->slotGoalNbCountriesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 62: _t->slotGoalNbArmiesByCountryChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 63: _t->slotGoalAnyContinentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 64: _t->slotGoalContinents(); break;
        case 65: _t->slotNewGoal(); break;
        case 66: _t->slotDeleteGoal(); break;
        case 67: _t->slotNationalitySelected((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 68: _t->slotNationalityNameEdited(); break;
        case 69: _t->slotNationalityLeaderNameEdited(); break;
        case 70: _t->slotNationalityFlagEdited((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 71: _t->slotNewNationality(); break;
        case 72: _t->slotDeleteNationality(); break;
        case 73: _t->slotFontSelected((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 74: _t->slotFgSelected((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 75: _t->slotBgColorSelected((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 76: _t->slotReleasePosition((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 77: _t->slotFLagxValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 78: _t->slotFLagyValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 79: _t->slotCenterxValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 80: _t->slotCenteryValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 81: _t->slotAnchorxValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 82: _t->slotAnchoryValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 83: _t->slotCavalryxValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 84: _t->slotCavalryyValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 85: _t->slotCannonxValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 86: _t->slotCannonyValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 87: _t->slotInfantryxValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 88: _t->slotInfantryyValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KsirkSkinEditor::MainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KsirkSkinEditor__MainWindow.data,
      qt_meta_data_KsirkSkinEditor__MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KsirkSkinEditor::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KsirkSkinEditor::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KsirkSkinEditor__MainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KsirkSkinEditor::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 89)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 89;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 89)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 89;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
