#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'ksirkspritesdefinition.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKSPRITESDEFINITION_H
#define UI_KSIRKSPRITESDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_KsirkSpritesDefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_26;
    QLineEdit *widthDiffLineEdit;
    QTabWidget *ktabwidget;
    QWidget *flagTab;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout_5;
    QLabel *label;
    QSpinBox *flagw;
    QLabel *label_2;
    QSpinBox *flagh;
    QLabel *label_3;
    QSpinBox *flagf;
    QLabel *label_4;
    QSpinBox *flagv;
    QSpacerItem *verticalSpacer_6;
    QWidget *infantryTab;
    QGridLayout *gridLayout_7;
    QLabel *label_5;
    QSpinBox *infantryw;
    QLabel *label_6;
    QSpinBox *infantryh;
    QLabel *label_8;
    QSpinBox *infantryf;
    QLabel *label_7;
    QSpinBox *infantryv;
    QSpacerItem *verticalSpacer_5;
    QWidget *cavalryTab;
    QGridLayout *gridLayout_3;
    QLabel *label_10;
    QSpinBox *cavalryw;
    QLabel *label_9;
    QSpinBox *cavalryh;
    QLabel *label_11;
    QSpinBox *cavalryf;
    QLabel *label_12;
    QSpinBox *cavalryv;
    QSpacerItem *verticalSpacer_4;
    QWidget *cannonTab;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout_4;
    QLabel *label_14;
    QSpinBox *cannonw;
    QLabel *label_13;
    QSpinBox *cannonh;
    QLabel *label_15;
    QSpinBox *cannonf;
    QLabel *label_16;
    QSpinBox *cannonv;
    QSpacerItem *verticalSpacer_3;
    QWidget *firingTab;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_18;
    QSpinBox *firingw;
    QLabel *label_17;
    QSpinBox *firingh;
    QLabel *label_19;
    QSpinBox *firingf;
    QLabel *label_20;
    QSpinBox *firingv;
    QSpacerItem *verticalSpacer;
    QWidget *explodingTab;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_2;
    QLabel *label_22;
    QSpinBox *explodingw;
    QLabel *label_21;
    QSpinBox *explodingh;
    QLabel *label_23;
    QSpinBox *explodingf;
    QLabel *label_24;
    QSpinBox *explodingv;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QDockWidget *KsirkSpritesDefinition)
    {
        if (KsirkSpritesDefinition->objectName().isEmpty())
            KsirkSpritesDefinition->setObjectName(QStringLiteral("KsirkSpritesDefinition"));
        KsirkSpritesDefinition->resize(293, 523);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName(QStringLiteral("dockWidgetContents"));
        verticalLayout_5 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_5->setObjectName(QStringLiteral("verticalLayout_5"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        label_26 = new QLabel(dockWidgetContents);
        label_26->setObjectName(QStringLiteral("label_26"));
        label_26->setEnabled(true);
        label_26->setTextInteractionFlags(Qt::NoTextInteraction);

        horizontalLayout_4->addWidget(label_26);

        widthDiffLineEdit = new QLineEdit(dockWidgetContents);
        widthDiffLineEdit->setObjectName(QStringLiteral("widthDiffLineEdit"));

        horizontalLayout_4->addWidget(widthDiffLineEdit);


        verticalLayout_5->addLayout(horizontalLayout_4);

        ktabwidget = new QTabWidget(dockWidgetContents);
        ktabwidget->setObjectName(QStringLiteral("ktabwidget"));
        ktabwidget->setTabPosition(QTabWidget::West);
        flagTab = new QWidget();
        flagTab->setObjectName(QStringLiteral("flagTab"));
        verticalLayout_4 = new QVBoxLayout(flagTab);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        label = new QLabel(flagTab);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_5->addWidget(label, 0, 0, 1, 1);

        flagw = new QSpinBox(flagTab);
        flagw->setObjectName(QStringLiteral("flagw"));

        gridLayout_5->addWidget(flagw, 0, 1, 1, 1);

        label_2 = new QLabel(flagTab);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout_5->addWidget(label_2, 1, 0, 1, 1);

        flagh = new QSpinBox(flagTab);
        flagh->setObjectName(QStringLiteral("flagh"));

        gridLayout_5->addWidget(flagh, 1, 1, 1, 1);

        label_3 = new QLabel(flagTab);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout_5->addWidget(label_3, 2, 0, 1, 1);

        flagf = new QSpinBox(flagTab);
        flagf->setObjectName(QStringLiteral("flagf"));

        gridLayout_5->addWidget(flagf, 2, 1, 1, 1);

        label_4 = new QLabel(flagTab);
        label_4->setObjectName(QStringLiteral("label_4"));

        gridLayout_5->addWidget(label_4, 3, 0, 1, 1);

        flagv = new QSpinBox(flagTab);
        flagv->setObjectName(QStringLiteral("flagv"));

        gridLayout_5->addWidget(flagv, 3, 1, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_5->addItem(verticalSpacer_6, 4, 0, 1, 1);


        verticalLayout_4->addLayout(gridLayout_5);

        ktabwidget->addTab(flagTab, QString());
        infantryTab = new QWidget();
        infantryTab->setObjectName(QStringLiteral("infantryTab"));
        gridLayout_7 = new QGridLayout(infantryTab);
        gridLayout_7->setObjectName(QStringLiteral("gridLayout_7"));
        label_5 = new QLabel(infantryTab);
        label_5->setObjectName(QStringLiteral("label_5"));

        gridLayout_7->addWidget(label_5, 0, 0, 1, 1);

        infantryw = new QSpinBox(infantryTab);
        infantryw->setObjectName(QStringLiteral("infantryw"));

        gridLayout_7->addWidget(infantryw, 0, 1, 1, 1);

        label_6 = new QLabel(infantryTab);
        label_6->setObjectName(QStringLiteral("label_6"));

        gridLayout_7->addWidget(label_6, 1, 0, 1, 1);

        infantryh = new QSpinBox(infantryTab);
        infantryh->setObjectName(QStringLiteral("infantryh"));

        gridLayout_7->addWidget(infantryh, 1, 1, 1, 1);

        label_8 = new QLabel(infantryTab);
        label_8->setObjectName(QStringLiteral("label_8"));

        gridLayout_7->addWidget(label_8, 2, 0, 1, 1);

        infantryf = new QSpinBox(infantryTab);
        infantryf->setObjectName(QStringLiteral("infantryf"));

        gridLayout_7->addWidget(infantryf, 2, 1, 1, 1);

        label_7 = new QLabel(infantryTab);
        label_7->setObjectName(QStringLiteral("label_7"));

        gridLayout_7->addWidget(label_7, 3, 0, 1, 1);

        infantryv = new QSpinBox(infantryTab);
        infantryv->setObjectName(QStringLiteral("infantryv"));

        gridLayout_7->addWidget(infantryv, 3, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_7->addItem(verticalSpacer_5, 4, 0, 1, 1);

        ktabwidget->addTab(infantryTab, QString());
        cavalryTab = new QWidget();
        cavalryTab->setObjectName(QStringLiteral("cavalryTab"));
        gridLayout_3 = new QGridLayout(cavalryTab);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        label_10 = new QLabel(cavalryTab);
        label_10->setObjectName(QStringLiteral("label_10"));

        gridLayout_3->addWidget(label_10, 0, 0, 1, 1);

        cavalryw = new QSpinBox(cavalryTab);
        cavalryw->setObjectName(QStringLiteral("cavalryw"));

        gridLayout_3->addWidget(cavalryw, 0, 1, 1, 1);

        label_9 = new QLabel(cavalryTab);
        label_9->setObjectName(QStringLiteral("label_9"));

        gridLayout_3->addWidget(label_9, 1, 0, 1, 1);

        cavalryh = new QSpinBox(cavalryTab);
        cavalryh->setObjectName(QStringLiteral("cavalryh"));

        gridLayout_3->addWidget(cavalryh, 1, 1, 1, 1);

        label_11 = new QLabel(cavalryTab);
        label_11->setObjectName(QStringLiteral("label_11"));

        gridLayout_3->addWidget(label_11, 2, 0, 1, 1);

        cavalryf = new QSpinBox(cavalryTab);
        cavalryf->setObjectName(QStringLiteral("cavalryf"));

        gridLayout_3->addWidget(cavalryf, 2, 1, 1, 1);

        label_12 = new QLabel(cavalryTab);
        label_12->setObjectName(QStringLiteral("label_12"));

        gridLayout_3->addWidget(label_12, 3, 0, 1, 1);

        cavalryv = new QSpinBox(cavalryTab);
        cavalryv->setObjectName(QStringLiteral("cavalryv"));

        gridLayout_3->addWidget(cavalryv, 3, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(verticalSpacer_4, 4, 0, 1, 1);

        ktabwidget->addTab(cavalryTab, QString());
        cannonTab = new QWidget();
        cannonTab->setObjectName(QStringLiteral("cannonTab"));
        verticalLayout_3 = new QVBoxLayout(cannonTab);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        label_14 = new QLabel(cannonTab);
        label_14->setObjectName(QStringLiteral("label_14"));

        gridLayout_4->addWidget(label_14, 0, 0, 1, 1);

        cannonw = new QSpinBox(cannonTab);
        cannonw->setObjectName(QStringLiteral("cannonw"));

        gridLayout_4->addWidget(cannonw, 0, 1, 1, 1);

        label_13 = new QLabel(cannonTab);
        label_13->setObjectName(QStringLiteral("label_13"));

        gridLayout_4->addWidget(label_13, 1, 0, 1, 1);

        cannonh = new QSpinBox(cannonTab);
        cannonh->setObjectName(QStringLiteral("cannonh"));

        gridLayout_4->addWidget(cannonh, 1, 1, 1, 1);

        label_15 = new QLabel(cannonTab);
        label_15->setObjectName(QStringLiteral("label_15"));

        gridLayout_4->addWidget(label_15, 2, 0, 1, 1);

        cannonf = new QSpinBox(cannonTab);
        cannonf->setObjectName(QStringLiteral("cannonf"));

        gridLayout_4->addWidget(cannonf, 2, 1, 1, 1);

        label_16 = new QLabel(cannonTab);
        label_16->setObjectName(QStringLiteral("label_16"));

        gridLayout_4->addWidget(label_16, 3, 0, 1, 1);

        cannonv = new QSpinBox(cannonTab);
        cannonv->setObjectName(QStringLiteral("cannonv"));

        gridLayout_4->addWidget(cannonv, 3, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(verticalSpacer_3, 4, 0, 1, 1);


        verticalLayout_3->addLayout(gridLayout_4);

        ktabwidget->addTab(cannonTab, QString());
        firingTab = new QWidget();
        firingTab->setObjectName(QStringLiteral("firingTab"));
        verticalLayout = new QVBoxLayout(firingTab);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label_18 = new QLabel(firingTab);
        label_18->setObjectName(QStringLiteral("label_18"));

        gridLayout->addWidget(label_18, 0, 0, 1, 1);

        firingw = new QSpinBox(firingTab);
        firingw->setObjectName(QStringLiteral("firingw"));

        gridLayout->addWidget(firingw, 0, 1, 1, 1);

        label_17 = new QLabel(firingTab);
        label_17->setObjectName(QStringLiteral("label_17"));

        gridLayout->addWidget(label_17, 1, 0, 1, 1);

        firingh = new QSpinBox(firingTab);
        firingh->setObjectName(QStringLiteral("firingh"));

        gridLayout->addWidget(firingh, 1, 1, 1, 1);

        label_19 = new QLabel(firingTab);
        label_19->setObjectName(QStringLiteral("label_19"));

        gridLayout->addWidget(label_19, 2, 0, 1, 1);

        firingf = new QSpinBox(firingTab);
        firingf->setObjectName(QStringLiteral("firingf"));

        gridLayout->addWidget(firingf, 2, 1, 1, 1);

        label_20 = new QLabel(firingTab);
        label_20->setObjectName(QStringLiteral("label_20"));

        gridLayout->addWidget(label_20, 3, 0, 1, 1);

        firingv = new QSpinBox(firingTab);
        firingv->setObjectName(QStringLiteral("firingv"));

        gridLayout->addWidget(firingv, 3, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        ktabwidget->addTab(firingTab, QString());
        explodingTab = new QWidget();
        explodingTab->setObjectName(QStringLiteral("explodingTab"));
        verticalLayout_2 = new QVBoxLayout(explodingTab);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        label_22 = new QLabel(explodingTab);
        label_22->setObjectName(QStringLiteral("label_22"));

        gridLayout_2->addWidget(label_22, 0, 0, 1, 1);

        explodingw = new QSpinBox(explodingTab);
        explodingw->setObjectName(QStringLiteral("explodingw"));

        gridLayout_2->addWidget(explodingw, 0, 1, 1, 1);

        label_21 = new QLabel(explodingTab);
        label_21->setObjectName(QStringLiteral("label_21"));

        gridLayout_2->addWidget(label_21, 1, 0, 1, 1);

        explodingh = new QSpinBox(explodingTab);
        explodingh->setObjectName(QStringLiteral("explodingh"));

        gridLayout_2->addWidget(explodingh, 1, 1, 1, 1);

        label_23 = new QLabel(explodingTab);
        label_23->setObjectName(QStringLiteral("label_23"));

        gridLayout_2->addWidget(label_23, 2, 0, 1, 1);

        explodingf = new QSpinBox(explodingTab);
        explodingf->setObjectName(QStringLiteral("explodingf"));

        gridLayout_2->addWidget(explodingf, 2, 1, 1, 1);

        label_24 = new QLabel(explodingTab);
        label_24->setObjectName(QStringLiteral("label_24"));

        gridLayout_2->addWidget(label_24, 3, 0, 1, 1);

        explodingv = new QSpinBox(explodingTab);
        explodingv->setObjectName(QStringLiteral("explodingv"));

        gridLayout_2->addWidget(explodingv, 3, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 4, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        ktabwidget->addTab(explodingTab, QString());

        verticalLayout_5->addWidget(ktabwidget);

        KsirkSpritesDefinition->setWidget(dockWidgetContents);

        retranslateUi(KsirkSpritesDefinition);

        ktabwidget->setCurrentIndex(5);


        QMetaObject::connectSlotsByName(KsirkSpritesDefinition);
    } // setupUi

    void retranslateUi(QDockWidget *KsirkSpritesDefinition)
    {
        KsirkSpritesDefinition->setWindowTitle(tr2i18n("Sprites", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        label_26->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        label_26->setText(tr2i18n("Width between fighter\n"
"and flag:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        widthDiffLineEdit->setToolTip(tr2i18n("Empty space size between fighting cannon and flag", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        widthDiffLineEdit->setWhatsThis(tr2i18n("Empty space size between fighting cannon and flag.\n"
"\n"
"During a battle, firing (end exploding) cannons of each player are placed in both sides of the defender country flag. This parameter is the number of pixels between the flag and each cannon, measured relatively to the map base size as set in the main skin definition panel.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_TOOLTIP
        ktabwidget->setToolTip(tr2i18n("Data about all sprites", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_TOOLTIP
        flagTab->setToolTip(tr2i18n("Data about the flag sprite", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label->setText(tr2i18n("Width:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        flagw->setToolTip(tr2i18n("Flag individual frame width", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        flagw->setWhatsThis(tr2i18n("<p>Flag individual frame width.</p><p>The pool <i>flag</i> element will be rendered on a pixmap of width: <i>Width</i> * N<i>number of frames</i> and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_2->setText(tr2i18n("Height:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        flagh->setToolTip(tr2i18n("Flag individual frame height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        flagh->setWhatsThis(tr2i18n("Flag individual frame height.\n"
"\n"
"The pool flag element will be rendered on a pixmap of height: (Height * Number of versions) and then split into individual frames.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_3->setText(tr2i18n("Nb Frames:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        flagf->setToolTip(tr2i18n("Number of individual flag frames", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        flagf->setWhatsThis(tr2i18n("<p>Number of individual flag frames.</p><p>The pool <i>flag</i> element will be rendered on a pixmap of width: (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_4->setText(tr2i18n("Nb Versions:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        flagv->setToolTip(tr2i18n("Number of flag versions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        flagv->setWhatsThis(tr2i18n("Number of flag versions.\n"
"\n"
"The pool flag element will be rendered on a pixmap of height: (Height * Number of versions) and then split into individual frames.\n"
"\n"
"Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from the front and the last one from the back. However, not all sprites need all versions.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        ktabwidget->setTabText(ktabwidget->indexOf(flagTab), tr2i18n("Flag", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        infantryTab->setToolTip(tr2i18n("Data about the infantry sprite", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_5->setText(tr2i18n("Width:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        infantryw->setToolTip(tr2i18n("Infantry individual frame width", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        infantryw->setWhatsThis(tr2i18n("<p>Infantry individual frame width.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of width: <i>Width</i> * <i>number of frames</i> and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_6->setText(tr2i18n("Height:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        infantryh->setToolTip(tr2i18n("Infantry individual frame height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        infantryh->setWhatsThis(tr2i18n("<p>Infantry individual frame height.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of height: <i>Height</i> * <i>Number of versions</i> and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_8->setText(tr2i18n("Nb Frames:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        infantryf->setToolTip(tr2i18n("Number of individual infantry frames", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        infantryf->setWhatsThis(tr2i18n("<p>Infantry number of individual frames.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of width: (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_7->setText(tr2i18n("Nb Versions:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        infantryv->setToolTip(tr2i18n("Number of infantry versions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        infantryv->setWhatsThis(tr2i18n("<p>Number of infantry versions.</p><p>The pool <i>infantry</i> element will be rendered on a pixmap of height: (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        ktabwidget->setTabText(ktabwidget->indexOf(infantryTab), tr2i18n("Infantry", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cavalryTab->setToolTip(tr2i18n("Data about the cavalry sprite", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_10->setText(tr2i18n("Width:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cavalryw->setToolTip(tr2i18n("Individual cavalry frame width", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cavalryw->setWhatsThis(tr2i18n("<p>Individual cavalry frame width.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_9->setText(tr2i18n("Height:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cavalryh->setToolTip(tr2i18n("Individual cavalry frame height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cavalryh->setWhatsThis(tr2i18n("<p>Individual cavalry frame height.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_11->setText(tr2i18n("Nb Frames:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cavalryf->setToolTip(tr2i18n("Number of individual cavalry frames", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cavalryf->setWhatsThis(tr2i18n("<p>Number of individual cavalry frames.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of width: (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_12->setText(tr2i18n("Nb Versions:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cavalryv->setToolTip(tr2i18n("Number of cavalry versions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cavalryv->setWhatsThis(tr2i18n("<p>Number of cavalry versions.</p><p>The pool <i>cavalry</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        ktabwidget->setTabText(ktabwidget->indexOf(cavalryTab), tr2i18n("Cavalry", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cannonTab->setToolTip(tr2i18n("Data about the cannon sprite", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_14->setText(tr2i18n("Width:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cannonw->setToolTip(tr2i18n("Cannon individual frame width", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cannonw->setWhatsThis(tr2i18n("<p>Cannon individual frame width.</p><p>The pool <i>cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_13->setText(tr2i18n("Height:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cannonh->setToolTip(tr2i18n("Individual cannon frame height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cannonh->setWhatsThis(tr2i18n("<p>Individual cannon frame height.</p><p>The pool <i>cannon<i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_15->setText(tr2i18n("Nb Frames:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cannonf->setToolTip(tr2i18n("Number of individual cannon frames", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cannonf->setWhatsThis(tr2i18n("<p>Number of individual cannon frames.</p><p>The pool <i>cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_16->setText(tr2i18n("Nb Versions:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cannonv->setToolTip(tr2i18n("Number of cannon versions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cannonv->setWhatsThis(tr2i18n("<p>Number of cannon versions.</p><p>The pool <i>cannon</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        ktabwidget->setTabText(ktabwidget->indexOf(cannonTab), tr2i18n("Cannon", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        firingTab->setToolTip(tr2i18n("Data about the firing sprite", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_18->setText(tr2i18n("Width:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        firingw->setToolTip(tr2i18n("Firing cannon individual frame width", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        firingw->setWhatsThis(tr2i18n("<p>Firing cannon individual frame width.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_17->setText(tr2i18n("Height:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        firingh->setToolTip(tr2i18n("Firing cannon individual frame height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        firingh->setWhatsThis(tr2i18n("<p>Firing cannon individual frame height.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_19->setText(tr2i18n("Nb Frames:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        firingf->setToolTip(tr2i18n("Number of individual firing cannon frames", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        firingf->setWhatsThis(tr2i18n("<p>Number of individual firing cannon frames.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_20->setText(tr2i18n("Nb Versions:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        firingv->setToolTip(tr2i18n("Number of firing cannon versions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        firingv->setWhatsThis(tr2i18n("<p>Number of firing cannon versions.</p><p>The pool <i>firing cannon</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        ktabwidget->setTabText(ktabwidget->indexOf(firingTab), tr2i18n("Firing", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        explodingTab->setToolTip(tr2i18n("Data about the exploding sprite", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_22->setText(tr2i18n("Width:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        explodingw->setToolTip(tr2i18n("Exploding cannon individual frame width", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        explodingw->setWhatsThis(tr2i18n("<p>Exploding cannon individual frame width.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_21->setText(tr2i18n("Height:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        explodingh->setToolTip(tr2i18n("Exploding cannon individual frame height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        explodingh->setWhatsThis(tr2i18n("<p>Exploding cannon individual frame height.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_23->setText(tr2i18n("Nb Frames:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        explodingf->setToolTip(tr2i18n("Number of individual exploding cannon frames", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        explodingf->setWhatsThis(tr2i18n("<p>Number of individual exploding cannon frames.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of width (<i>Width</i> * <i>Number of frames</i>) and then split into individual frames.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label_24->setText(tr2i18n("Nb Versions:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        explodingv->setToolTip(tr2i18n("Number of exploding cannon versions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        explodingv->setWhatsThis(tr2i18n("<p>Number of exploding cannon versions.</p><p>The pool <i>exploding</i> element will be rendered on a pixmap of height (<i>Height</i> * <i>Number of versions</i>) and then split into individual frames.</p><p>Each version shows the sprite visible from one direction: the first one is directed towards the right, the second towards the left, the third one from front and the last one from the back. However, not all sprites need all versions.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        ktabwidget->setTabText(ktabwidget->indexOf(explodingTab), tr2i18n("Exploding", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class KsirkSpritesDefinition: public Ui_KsirkSpritesDefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKSPRITESDEFINITION_H

