// This file is generated by kconfig_compiler_kf5 from ksirksettings.kcfg.
// All changes you do to this file will be lost.
#ifndef KSIRK_KSIRKSETTINGS_H
#define KSIRK_KSIRKSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace Ksirk {

class KsirkSettings : public KConfigSkeleton
{
  public:

    static KsirkSettings *self();
    ~KsirkSettings();

    /**
      Set The sprites speed: slow, normal, quick, immediate
    */
    static
    void setSpritesSpeed( int v )
    {
      if (!self()->isImmutable( QStringLiteral( "spritesSpeed" ) ))
        self()->mSpritesSpeed = v;
    }

    /**
      Get The sprites speed: slow, normal, quick, immediate
    */
    static
    int spritesSpeed()
    {
      return self()->mSpritesSpeed;
    }

    /**
      Set If true, sounds are played; they are not otherwise.
    */
    static
    void setSoundEnabled( bool v )
    {
      if (!self()->isImmutable( QStringLiteral( "soundEnabled" ) ))
        self()->mSoundEnabled = v;
    }

    /**
      Get If true, sounds are played; they are not otherwise.
    */
    static
    bool soundEnabled()
    {
      return self()->mSoundEnabled;
    }

    /**
      Set If true, help is displayed; they are not otherwise.
    */
    static
    void setHelpEnabled( bool v )
    {
      if (!self()->isImmutable( QStringLiteral( "helpEnabled" ) ))
        self()->mHelpEnabled = v;
    }

    /**
      Get If true, help is displayed; they are not otherwise.
    */
    static
    bool helpEnabled()
    {
      return self()->mHelpEnabled;
    }

    /**
      Set If true, the number of armies is displayed on each country.
    */
    static
    void setShowArmiesNumbers( bool v )
    {
      if (!self()->isImmutable( QStringLiteral( "showArmiesNumbers" ) ))
        self()->mShowArmiesNumbers = v;
    }

    /**
      Get If true, the number of armies is displayed on each country.
    */
    static
    bool showArmiesNumbers()
    {
      return self()->mShowArmiesNumbers;
    }

    /**
      Set The graphical theme to be used.
    */
    static
    void setTheme( const QString & v )
    {
      if (!self()->isImmutable( QStringLiteral( "Theme" ) ))
        self()->mTheme = v;
    }

    /**
      Get The graphical theme to be used.
    */
    static
    QString theme()
    {
      return self()->mTheme;
    }

    /**
      Set The last used Jabber Id.
    */
    static
    void setJabberId( const QString & v )
    {
      if (!self()->isImmutable( QStringLiteral( "jabberId" ) ))
        self()->mJabberId = v;
    }

    /**
      Get The last used Jabber Id.
    */
    static
    QString jabberId()
    {
      return self()->mJabberId;
    }

    /**
      Set The password of the last used Jabber Id.
    */
    static
    void setJabberPassword( const QString & v )
    {
      if (!self()->isImmutable( QStringLiteral( "jabberPassword" ) ))
        self()->mJabberPassword = v;
    }

    /**
      Get The password of the last used Jabber Id.
    */
    static
    QString jabberPassword()
    {
      return self()->mJabberPassword;
    }

    /**
      Set The last used Jabber groupchat room.
    */
    static
    void setRoomJid( const QString & v )
    {
      if (!self()->isImmutable( QStringLiteral( "roomJid" ) ))
        self()->mRoomJid = v;
    }

    /**
      Get The last used Jabber groupchat room.
    */
    static
    QString roomJid()
    {
      return self()->mRoomJid;
    }

    /**
      Set The password for last used Jabber groupchat room.
    */
    static
    void setRoomPassword( const QString & v )
    {
      if (!self()->isImmutable( QStringLiteral( "roomPassword" ) ))
        self()->mRoomPassword = v;
    }

    /**
      Get The password for last used Jabber groupchat room.
    */
    static
    QString roomPassword()
    {
      return self()->mRoomPassword;
    }

    /**
      Set The nickname used in the last used Jabber groupchat room.
    */
    static
    void setNickname( const QString & v )
    {
      if (!self()->isImmutable( QStringLiteral( "nickname" ) ))
        self()->mNickname = v;
    }

    /**
      Get The nickname used in the last used Jabber groupchat room.
    */
    static
    QString nickname()
    {
      return self()->mNickname;
    }

  protected:
    KsirkSettings();
    friend class KsirkSettingsHelper;


    // General
    int mSpritesSpeed;
    bool mSoundEnabled;
    bool mHelpEnabled;
    bool mShowArmiesNumbers;
    QString mTheme;
    QString mJabberId;
    QString mJabberPassword;
    QString mRoomJid;
    QString mRoomPassword;
    QString mNickname;

  private:
};

}

#endif

