#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'qplayersetupdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QPLAYERSETUPDIALOG_H
#define UI_QPLAYERSETUPDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kpassworddialog.h"

QT_BEGIN_NAMESPACE

class Ui_QPlayerSetupWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *TextLabel1;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *nameLineEdit;
    QComboBox *nationCombo;
    QLabel *messageLabel;
    QHBoxLayout *horizontalLayout;
    QLabel *passwordLabel;
    QLineEdit *passwordEdit;
    QCheckBox *isComputerCheckBox;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *previousButton;
    QPushButton *nextButton;

    void setupUi(QWidget *QPlayerSetupWidget)
    {
        if (QPlayerSetupWidget->objectName().isEmpty())
            QPlayerSetupWidget->setObjectName(QStringLiteral("QPlayerSetupWidget"));
        QPlayerSetupWidget->resize(560, 393);
        verticalLayout = new QVBoxLayout(QPlayerSetupWidget);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        TextLabel1 = new QLabel(QPlayerSetupWidget);
        TextLabel1->setObjectName(QStringLiteral("TextLabel1"));
        TextLabel1->setFrameShape(QFrame::NoFrame);
        TextLabel1->setWordWrap(true);

        verticalLayout->addWidget(TextLabel1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        nameLineEdit = new QLineEdit(QPlayerSetupWidget);
        nameLineEdit->setObjectName(QStringLiteral("nameLineEdit"));
        nameLineEdit->setMaxLength(30);
        nameLineEdit->setAlignment(Qt::AlignLeading);

        horizontalLayout_2->addWidget(nameLineEdit);

        nationCombo = new QComboBox(QPlayerSetupWidget);
        nationCombo->setObjectName(QStringLiteral("nationCombo"));
        nationCombo->setDuplicatesEnabled(false);

        horizontalLayout_2->addWidget(nationCombo);


        verticalLayout->addLayout(horizontalLayout_2);

        messageLabel = new QLabel(QPlayerSetupWidget);
        messageLabel->setObjectName(QStringLiteral("messageLabel"));
        messageLabel->setEnabled(true);

        verticalLayout->addWidget(messageLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        passwordLabel = new QLabel(QPlayerSetupWidget);
        passwordLabel->setObjectName(QStringLiteral("passwordLabel"));
        passwordLabel->setWordWrap(false);

        horizontalLayout->addWidget(passwordLabel);

        passwordEdit = new QLineEdit(QPlayerSetupWidget);
        passwordEdit->setObjectName(QStringLiteral("passwordEdit"));
        passwordEdit->setEnabled(true);
        passwordEdit->setMaxLength(8);
        passwordEdit->setEchoMode(QLineEdit::Password);

        horizontalLayout->addWidget(passwordEdit);


        verticalLayout->addLayout(horizontalLayout);

        isComputerCheckBox = new QCheckBox(QPlayerSetupWidget);
        isComputerCheckBox->setObjectName(QStringLiteral("isComputerCheckBox"));

        verticalLayout->addWidget(isComputerCheckBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        cancelButton = new QPushButton(QPlayerSetupWidget);
        cancelButton->setObjectName(QStringLiteral("cancelButton"));

        horizontalLayout_3->addWidget(cancelButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        previousButton = new QPushButton(QPlayerSetupWidget);
        previousButton->setObjectName(QStringLiteral("previousButton"));

        horizontalLayout_3->addWidget(previousButton);

        nextButton = new QPushButton(QPlayerSetupWidget);
        nextButton->setObjectName(QStringLiteral("nextButton"));

        horizontalLayout_3->addWidget(nextButton);


        verticalLayout->addLayout(horizontalLayout_3);

#ifndef UI_QT_NO_SHORTCUT
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(nameLineEdit, nationCombo);
        QWidget::setTabOrder(nationCombo, isComputerCheckBox);

        retranslateUi(QPlayerSetupWidget);

        QMetaObject::connectSlotsByName(QPlayerSetupWidget);
    } // setupUi

    void retranslateUi(QWidget *QPlayerSetupWidget)
    {
        QPlayerSetupWidget->setWindowTitle(tr2i18n("Player Setup", Q_NULLPTR));
        TextLabel1->setText(tr2i18n("Player number %1, please enter your name and choose your nation:", Q_NULLPTR));
        nameLineEdit->setText(QString());
#ifndef UI_QT_NO_TOOLTIP
        nationCombo->setToolTip(tr2i18n("Choose your nation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        nationCombo->setWhatsThis(tr2i18n("A combo box that lists currently available nations.\n"
"Choose one of them. It will be your nation during the game", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        messageLabel->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        passwordLabel->setText(tr2i18n("Enter your password:", Q_NULLPTR));
        isComputerCheckBox->setText(tr2i18n("Pla&yer is computer", Q_NULLPTR));
        cancelButton->setText(tr2i18n("Cancel", Q_NULLPTR));
        previousButton->setText(tr2i18n("<< Previous", Q_NULLPTR));
        nextButton->setText(tr2i18n("Next >>", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class QPlayerSetupWidget: public Ui_QPlayerSetupWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QPLAYERSETUPDIALOG_H

