/****************************************************************************
** Meta object code from reading C++ file 'xmpp_clientstream.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/xmpp-core/xmpp_clientstream.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xmpp_clientstream.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__ClientStream_t {
    QByteArrayData data[35];
    char stringdata0[446];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__ClientStream_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__ClientStream_t qt_meta_stringdata_XMPP__ClientStream = {
    {
QT_MOC_LITERAL(0, 0, 18), // "XMPP::ClientStream"
QT_MOC_LITERAL(1, 19, 9), // "connected"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 22), // "securityLayerActivated"
QT_MOC_LITERAL(4, 53, 14), // "needAuthParams"
QT_MOC_LITERAL(5, 68, 4), // "user"
QT_MOC_LITERAL(6, 73, 4), // "pass"
QT_MOC_LITERAL(7, 78, 5), // "realm"
QT_MOC_LITERAL(8, 84, 13), // "authenticated"
QT_MOC_LITERAL(9, 98, 7), // "warning"
QT_MOC_LITERAL(10, 106, 11), // "incomingXml"
QT_MOC_LITERAL(11, 118, 1), // "s"
QT_MOC_LITERAL(12, 120, 11), // "outgoingXml"
QT_MOC_LITERAL(13, 132, 20), // "continueAfterWarning"
QT_MOC_LITERAL(14, 153, 12), // "cr_connected"
QT_MOC_LITERAL(15, 166, 8), // "cr_error"
QT_MOC_LITERAL(16, 175, 19), // "bs_connectionClosed"
QT_MOC_LITERAL(17, 195, 23), // "bs_delayedCloseFinished"
QT_MOC_LITERAL(18, 219, 8), // "bs_error"
QT_MOC_LITERAL(19, 228, 12), // "ss_readyRead"
QT_MOC_LITERAL(20, 241, 15), // "ss_bytesWritten"
QT_MOC_LITERAL(21, 257, 16), // "ss_tlsHandshaken"
QT_MOC_LITERAL(22, 274, 12), // "ss_tlsClosed"
QT_MOC_LITERAL(23, 287, 8), // "ss_error"
QT_MOC_LITERAL(24, 296, 20), // "sasl_clientFirstStep"
QT_MOC_LITERAL(25, 317, 13), // "sasl_nextStep"
QT_MOC_LITERAL(26, 331, 8), // "stepData"
QT_MOC_LITERAL(27, 340, 15), // "sasl_needParams"
QT_MOC_LITERAL(28, 356, 17), // "QCA::SASL::Params"
QT_MOC_LITERAL(29, 374, 14), // "sasl_authCheck"
QT_MOC_LITERAL(30, 389, 7), // "authzid"
QT_MOC_LITERAL(31, 397, 18), // "sasl_authenticated"
QT_MOC_LITERAL(32, 416, 10), // "sasl_error"
QT_MOC_LITERAL(33, 427, 6), // "doNoop"
QT_MOC_LITERAL(34, 434, 11) // "doReadyRead"

    },
    "XMPP::ClientStream\0connected\0\0"
    "securityLayerActivated\0needAuthParams\0"
    "user\0pass\0realm\0authenticated\0warning\0"
    "incomingXml\0s\0outgoingXml\0"
    "continueAfterWarning\0cr_connected\0"
    "cr_error\0bs_connectionClosed\0"
    "bs_delayedCloseFinished\0bs_error\0"
    "ss_readyRead\0ss_bytesWritten\0"
    "ss_tlsHandshaken\0ss_tlsClosed\0ss_error\0"
    "sasl_clientFirstStep\0sasl_nextStep\0"
    "stepData\0sasl_needParams\0QCA::SASL::Params\0"
    "sasl_authCheck\0authzid\0sasl_authenticated\0"
    "sasl_error\0doNoop\0doReadyRead"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__ClientStream[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      26,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  144,    2, 0x06 /* Public */,
       3,    1,  145,    2, 0x06 /* Public */,
       4,    3,  148,    2, 0x06 /* Public */,
       8,    0,  155,    2, 0x06 /* Public */,
       9,    1,  156,    2, 0x06 /* Public */,
      10,    1,  159,    2, 0x06 /* Public */,
      12,    1,  162,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    0,  165,    2, 0x0a /* Public */,
      14,    0,  166,    2, 0x08 /* Private */,
      15,    0,  167,    2, 0x08 /* Private */,
      16,    0,  168,    2, 0x08 /* Private */,
      17,    0,  169,    2, 0x08 /* Private */,
      18,    1,  170,    2, 0x08 /* Private */,
      19,    0,  173,    2, 0x08 /* Private */,
      20,    1,  174,    2, 0x08 /* Private */,
      21,    0,  177,    2, 0x08 /* Private */,
      22,    0,  178,    2, 0x08 /* Private */,
      23,    1,  179,    2, 0x08 /* Private */,
      24,    2,  182,    2, 0x08 /* Private */,
      25,    1,  187,    2, 0x08 /* Private */,
      27,    1,  190,    2, 0x08 /* Private */,
      29,    2,  193,    2, 0x08 /* Private */,
      31,    0,  198,    2, 0x08 /* Private */,
      32,    0,  199,    2, 0x08 /* Private */,
      33,    0,  200,    2, 0x08 /* Private */,
      34,    0,  201,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,    5,    6,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QString,   11,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool, QMetaType::QByteArray,    2,    2,
    QMetaType::Void, QMetaType::QByteArray,   26,
    QMetaType::Void, 0x80000000 | 28,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   30,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::ClientStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ClientStream *_t = static_cast<ClientStream *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->securityLayerActivated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->needAuthParams((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 3: _t->authenticated(); break;
        case 4: _t->warning((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->incomingXml((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->outgoingXml((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->continueAfterWarning(); break;
        case 8: _t->cr_connected(); break;
        case 9: _t->cr_error(); break;
        case 10: _t->bs_connectionClosed(); break;
        case 11: _t->bs_delayedCloseFinished(); break;
        case 12: _t->bs_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->ss_readyRead(); break;
        case 14: _t->ss_bytesWritten((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->ss_tlsHandshaken(); break;
        case 16: _t->ss_tlsClosed(); break;
        case 17: _t->ss_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->sasl_clientFirstStep((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 19: _t->sasl_nextStep((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 20: _t->sasl_needParams((*reinterpret_cast< const QCA::SASL::Params(*)>(_a[1]))); break;
        case 21: _t->sasl_authCheck((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 22: _t->sasl_authenticated(); break;
        case 23: _t->sasl_error(); break;
        case 24: _t->doNoop(); break;
        case 25: _t->doReadyRead(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ClientStream::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientStream::connected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ClientStream::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientStream::securityLayerActivated)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ClientStream::*_t)(bool , bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientStream::needAuthParams)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ClientStream::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientStream::authenticated)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ClientStream::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientStream::warning)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ClientStream::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientStream::incomingXml)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ClientStream::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientStream::outgoingXml)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject XMPP::ClientStream::staticMetaObject = {
    { &Stream::staticMetaObject, qt_meta_stringdata_XMPP__ClientStream.data,
      qt_meta_data_XMPP__ClientStream,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::ClientStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::ClientStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__ClientStream.stringdata0))
        return static_cast<void*>(this);
    return Stream::qt_metacast(_clname);
}

int XMPP::ClientStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Stream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void XMPP::ClientStream::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XMPP::ClientStream::securityLayerActivated(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void XMPP::ClientStream::needAuthParams(bool _t1, bool _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void XMPP::ClientStream::authenticated()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void XMPP::ClientStream::warning(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void XMPP::ClientStream::incomingXml(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void XMPP::ClientStream::outgoingXml(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
