/****************************************************************************
** Meta object code from reading C++ file 's5b.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/xmpp-im/s5b.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 's5b.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__S5BConnection_t {
    QByteArrayData data[22];
    char stringdata0[268];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__S5BConnection_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__S5BConnection_t qt_meta_stringdata_XMPP__S5BConnection = {
    {
QT_MOC_LITERAL(0, 0, 19), // "XMPP::S5BConnection"
QT_MOC_LITERAL(1, 20, 10), // "proxyQuery"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 11), // "proxyResult"
QT_MOC_LITERAL(4, 44, 1), // "b"
QT_MOC_LITERAL(5, 46, 10), // "requesting"
QT_MOC_LITERAL(6, 57, 8), // "accepted"
QT_MOC_LITERAL(7, 66, 11), // "tryingHosts"
QT_MOC_LITERAL(8, 78, 14), // "StreamHostList"
QT_MOC_LITERAL(9, 93, 5), // "hosts"
QT_MOC_LITERAL(10, 99, 12), // "proxyConnect"
QT_MOC_LITERAL(11, 112, 20), // "waitingForActivation"
QT_MOC_LITERAL(12, 133, 9), // "connected"
QT_MOC_LITERAL(13, 143, 13), // "datagramReady"
QT_MOC_LITERAL(14, 157, 9), // "doPending"
QT_MOC_LITERAL(15, 167, 19), // "sc_connectionClosed"
QT_MOC_LITERAL(16, 187, 23), // "sc_delayedCloseFinished"
QT_MOC_LITERAL(17, 211, 12), // "sc_readyRead"
QT_MOC_LITERAL(18, 224, 15), // "sc_bytesWritten"
QT_MOC_LITERAL(19, 240, 8), // "sc_error"
QT_MOC_LITERAL(20, 249, 14), // "su_packetReady"
QT_MOC_LITERAL(21, 264, 3) // "buf"

    },
    "XMPP::S5BConnection\0proxyQuery\0\0"
    "proxyResult\0b\0requesting\0accepted\0"
    "tryingHosts\0StreamHostList\0hosts\0"
    "proxyConnect\0waitingForActivation\0"
    "connected\0datagramReady\0doPending\0"
    "sc_connectionClosed\0sc_delayedCloseFinished\0"
    "sc_readyRead\0sc_bytesWritten\0sc_error\0"
    "su_packetReady\0buf"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__S5BConnection[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x06 /* Public */,
       3,    1,   95,    2, 0x06 /* Public */,
       5,    0,   98,    2, 0x06 /* Public */,
       6,    0,   99,    2, 0x06 /* Public */,
       7,    1,  100,    2, 0x06 /* Public */,
      10,    0,  103,    2, 0x06 /* Public */,
      11,    0,  104,    2, 0x06 /* Public */,
      12,    0,  105,    2, 0x06 /* Public */,
      13,    0,  106,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,  107,    2, 0x08 /* Private */,
      15,    0,  108,    2, 0x08 /* Private */,
      16,    0,  109,    2, 0x08 /* Private */,
      17,    0,  110,    2, 0x08 /* Private */,
      18,    1,  111,    2, 0x08 /* Private */,
      19,    1,  114,    2, 0x08 /* Private */,
      20,    1,  117,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QByteArray,   21,

       0        // eod
};

void XMPP::S5BConnection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        S5BConnection *_t = static_cast<S5BConnection *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->proxyQuery(); break;
        case 1: _t->proxyResult((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->requesting(); break;
        case 3: _t->accepted(); break;
        case 4: _t->tryingHosts((*reinterpret_cast< const StreamHostList(*)>(_a[1]))); break;
        case 5: _t->proxyConnect(); break;
        case 6: _t->waitingForActivation(); break;
        case 7: _t->connected(); break;
        case 8: _t->datagramReady(); break;
        case 9: _t->doPending(); break;
        case 10: _t->sc_connectionClosed(); break;
        case 11: _t->sc_delayedCloseFinished(); break;
        case 12: _t->sc_readyRead(); break;
        case 13: _t->sc_bytesWritten((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->sc_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->su_packetReady((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (S5BConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::proxyQuery)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::proxyResult)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::requesting)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::accepted)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)(const StreamHostList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::tryingHosts)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::proxyConnect)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::waitingForActivation)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::connected)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (S5BConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnection::datagramReady)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject XMPP::S5BConnection::staticMetaObject = {
    { &ByteStream::staticMetaObject, qt_meta_stringdata_XMPP__S5BConnection.data,
      qt_meta_data_XMPP__S5BConnection,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::S5BConnection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::S5BConnection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__S5BConnection.stringdata0))
        return static_cast<void*>(this);
    return ByteStream::qt_metacast(_clname);
}

int XMPP::S5BConnection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ByteStream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void XMPP::S5BConnection::proxyQuery()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XMPP::S5BConnection::proxyResult(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void XMPP::S5BConnection::requesting()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void XMPP::S5BConnection::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void XMPP::S5BConnection::tryingHosts(const StreamHostList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void XMPP::S5BConnection::proxyConnect()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void XMPP::S5BConnection::waitingForActivation()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void XMPP::S5BConnection::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void XMPP::S5BConnection::datagramReady()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
struct qt_meta_stringdata_XMPP__S5BManager_t {
    QByteArrayData data[22];
    char stringdata0[269];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__S5BManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__S5BManager_t qt_meta_stringdata_XMPP__S5BManager = {
    {
QT_MOC_LITERAL(0, 0, 16), // "XMPP::S5BManager"
QT_MOC_LITERAL(1, 17, 13), // "incomingReady"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 11), // "ps_incoming"
QT_MOC_LITERAL(4, 44, 10), // "S5BRequest"
QT_MOC_LITERAL(5, 55, 3), // "req"
QT_MOC_LITERAL(6, 59, 21), // "ps_incomingUDPSuccess"
QT_MOC_LITERAL(7, 81, 3), // "Jid"
QT_MOC_LITERAL(8, 85, 4), // "from"
QT_MOC_LITERAL(9, 90, 7), // "dstaddr"
QT_MOC_LITERAL(10, 98, 19), // "ps_incomingActivate"
QT_MOC_LITERAL(11, 118, 3), // "sid"
QT_MOC_LITERAL(12, 122, 10), // "streamHost"
QT_MOC_LITERAL(13, 133, 13), // "item_accepted"
QT_MOC_LITERAL(14, 147, 16), // "item_tryingHosts"
QT_MOC_LITERAL(15, 164, 14), // "StreamHostList"
QT_MOC_LITERAL(16, 179, 4), // "list"
QT_MOC_LITERAL(17, 184, 17), // "item_proxyConnect"
QT_MOC_LITERAL(18, 202, 25), // "item_waitingForActivation"
QT_MOC_LITERAL(19, 228, 14), // "item_connected"
QT_MOC_LITERAL(20, 243, 10), // "item_error"
QT_MOC_LITERAL(21, 254, 14) // "query_finished"

    },
    "XMPP::S5BManager\0incomingReady\0\0"
    "ps_incoming\0S5BRequest\0req\0"
    "ps_incomingUDPSuccess\0Jid\0from\0dstaddr\0"
    "ps_incomingActivate\0sid\0streamHost\0"
    "item_accepted\0item_tryingHosts\0"
    "StreamHostList\0list\0item_proxyConnect\0"
    "item_waitingForActivation\0item_connected\0"
    "item_error\0query_finished"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__S5BManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   70,    2, 0x08 /* Private */,
       6,    2,   73,    2, 0x08 /* Private */,
      10,    3,   78,    2, 0x08 /* Private */,
      13,    0,   85,    2, 0x08 /* Private */,
      14,    1,   86,    2, 0x08 /* Private */,
      17,    0,   89,    2, 0x08 /* Private */,
      18,    0,   90,    2, 0x08 /* Private */,
      19,    0,   91,    2, 0x08 /* Private */,
      20,    1,   92,    2, 0x08 /* Private */,
      21,    0,   95,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QString,    8,    9,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QString, 0x80000000 | 7,    8,   11,   12,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,

       0        // eod
};

void XMPP::S5BManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        S5BManager *_t = static_cast<S5BManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incomingReady(); break;
        case 1: _t->ps_incoming((*reinterpret_cast< const S5BRequest(*)>(_a[1]))); break;
        case 2: _t->ps_incomingUDPSuccess((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->ps_incomingActivate((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const Jid(*)>(_a[3]))); break;
        case 4: _t->item_accepted(); break;
        case 5: _t->item_tryingHosts((*reinterpret_cast< const StreamHostList(*)>(_a[1]))); break;
        case 6: _t->item_proxyConnect(); break;
        case 7: _t->item_waitingForActivation(); break;
        case 8: _t->item_connected(); break;
        case 9: _t->item_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->query_finished(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (S5BManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BManager::incomingReady)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject XMPP::S5BManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__S5BManager.data,
      qt_meta_data_XMPP__S5BManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::S5BManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::S5BManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__S5BManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::S5BManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void XMPP::S5BManager::incomingReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_XMPP__S5BConnector_t {
    QByteArrayData data[5];
    char stringdata0[49];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__S5BConnector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__S5BConnector_t qt_meta_stringdata_XMPP__S5BConnector = {
    {
QT_MOC_LITERAL(0, 0, 18), // "XMPP::S5BConnector"
QT_MOC_LITERAL(1, 19, 6), // "result"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 11), // "item_result"
QT_MOC_LITERAL(4, 39, 9) // "t_timeout"

    },
    "XMPP::S5BConnector\0result\0\0item_result\0"
    "t_timeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__S5BConnector[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   32,    2, 0x08 /* Private */,
       4,    0,   35,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

       0        // eod
};

void XMPP::S5BConnector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        S5BConnector *_t = static_cast<S5BConnector *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->result((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->item_result((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->t_timeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (S5BConnector::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&S5BConnector::result)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject XMPP::S5BConnector::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__S5BConnector.data,
      qt_meta_data_XMPP__S5BConnector,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::S5BConnector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::S5BConnector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__S5BConnector.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::S5BConnector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void XMPP::S5BConnector::result(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_XMPP__S5BServer_t {
    QByteArrayData data[11];
    char stringdata0[105];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__S5BServer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__S5BServer_t qt_meta_stringdata_XMPP__S5BServer = {
    {
QT_MOC_LITERAL(0, 0, 15), // "XMPP::S5BServer"
QT_MOC_LITERAL(1, 16, 16), // "ss_incomingReady"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 14), // "ss_incomingUDP"
QT_MOC_LITERAL(4, 49, 4), // "host"
QT_MOC_LITERAL(5, 54, 4), // "port"
QT_MOC_LITERAL(6, 59, 12), // "QHostAddress"
QT_MOC_LITERAL(7, 72, 4), // "addr"
QT_MOC_LITERAL(8, 77, 10), // "sourcePort"
QT_MOC_LITERAL(9, 88, 4), // "data"
QT_MOC_LITERAL(10, 93, 11) // "item_result"

    },
    "XMPP::S5BServer\0ss_incomingReady\0\0"
    "ss_incomingUDP\0host\0port\0QHostAddress\0"
    "addr\0sourcePort\0data\0item_result"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__S5BServer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x08 /* Private */,
       3,    5,   30,    2, 0x08 /* Private */,
      10,    1,   41,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, 0x80000000 | 6, QMetaType::Int, QMetaType::QByteArray,    4,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void XMPP::S5BServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        S5BServer *_t = static_cast<S5BServer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->ss_incomingReady(); break;
        case 1: _t->ss_incomingUDP((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QHostAddress(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QByteArray(*)>(_a[5]))); break;
        case 2: _t->item_result((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject XMPP::S5BServer::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__S5BServer.data,
      qt_meta_data_XMPP__S5BServer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::S5BServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::S5BServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__S5BServer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::S5BServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_S5B_t {
    QByteArrayData data[3];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_S5B_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_S5B_t qt_meta_stringdata_XMPP__JT_S5B = {
    {
QT_MOC_LITERAL(0, 0, 12), // "XMPP::JT_S5B"
QT_MOC_LITERAL(1, 13, 9), // "t_timeout"
QT_MOC_LITERAL(2, 23, 0) // ""

    },
    "XMPP::JT_S5B\0t_timeout\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_S5B[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void XMPP::JT_S5B::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_S5B *_t = static_cast<JT_S5B *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->t_timeout(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_S5B::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_S5B.data,
      qt_meta_data_XMPP__JT_S5B,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_S5B::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_S5B::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_S5B.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_S5B::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_PushS5B_t {
    QByteArrayData data[12];
    char stringdata0[110];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_PushS5B_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_PushS5B_t qt_meta_stringdata_XMPP__JT_PushS5B = {
    {
QT_MOC_LITERAL(0, 0, 16), // "XMPP::JT_PushS5B"
QT_MOC_LITERAL(1, 17, 8), // "incoming"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 10), // "S5BRequest"
QT_MOC_LITERAL(4, 38, 3), // "req"
QT_MOC_LITERAL(5, 42, 18), // "incomingUDPSuccess"
QT_MOC_LITERAL(6, 61, 3), // "Jid"
QT_MOC_LITERAL(7, 65, 4), // "from"
QT_MOC_LITERAL(8, 70, 7), // "dstaddr"
QT_MOC_LITERAL(9, 78, 16), // "incomingActivate"
QT_MOC_LITERAL(10, 95, 3), // "sid"
QT_MOC_LITERAL(11, 99, 10) // "streamHost"

    },
    "XMPP::JT_PushS5B\0incoming\0\0S5BRequest\0"
    "req\0incomingUDPSuccess\0Jid\0from\0dstaddr\0"
    "incomingActivate\0sid\0streamHost"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_PushS5B[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       5,    2,   32,    2, 0x06 /* Public */,
       9,    3,   37,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString,    7,    8,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, 0x80000000 | 6,    7,   10,   11,

       0        // eod
};

void XMPP::JT_PushS5B::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_PushS5B *_t = static_cast<JT_PushS5B *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incoming((*reinterpret_cast< const S5BRequest(*)>(_a[1]))); break;
        case 1: _t->incomingUDPSuccess((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->incomingActivate((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const Jid(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JT_PushS5B::*_t)(const S5BRequest & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushS5B::incoming)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (JT_PushS5B::*_t)(const Jid & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushS5B::incomingUDPSuccess)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (JT_PushS5B::*_t)(const Jid & , const QString & , const Jid & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushS5B::incomingActivate)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject XMPP::JT_PushS5B::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_PushS5B.data,
      qt_meta_data_XMPP__JT_PushS5B,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_PushS5B::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_PushS5B::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_PushS5B.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_PushS5B::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void XMPP::JT_PushS5B::incoming(const S5BRequest & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::JT_PushS5B::incomingUDPSuccess(const Jid & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void XMPP::JT_PushS5B::incomingActivate(const Jid & _t1, const QString & _t2, const Jid & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
