/****************************************************************************
** Meta object code from reading C++ file 'socks.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/cutestuff/socks.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'socks.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SocksUDP_t {
    QByteArrayData data[5];
    char stringdata0[40];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SocksUDP_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SocksUDP_t qt_meta_stringdata_SocksUDP = {
    {
QT_MOC_LITERAL(0, 0, 8), // "SocksUDP"
QT_MOC_LITERAL(1, 9, 11), // "packetReady"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 4), // "data"
QT_MOC_LITERAL(4, 27, 12) // "sd_activated"

    },
    "SocksUDP\0packetReady\0\0data\0sd_activated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SocksUDP[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   27,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QByteArray,    3,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void SocksUDP::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SocksUDP *_t = static_cast<SocksUDP *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->packetReady((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 1: _t->sd_activated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SocksUDP::*_t)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksUDP::packetReady)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject SocksUDP::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_SocksUDP.data,
      qt_meta_data_SocksUDP,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *SocksUDP::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SocksUDP::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SocksUDP.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SocksUDP::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void SocksUDP::packetReady(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_SocksClient_t {
    QByteArrayData data[18];
    char stringdata0[236];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SocksClient_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SocksClient_t qt_meta_stringdata_SocksClient = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SocksClient"
QT_MOC_LITERAL(1, 12, 9), // "connected"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 15), // "incomingMethods"
QT_MOC_LITERAL(4, 39, 12), // "incomingAuth"
QT_MOC_LITERAL(5, 52, 4), // "user"
QT_MOC_LITERAL(6, 57, 4), // "pass"
QT_MOC_LITERAL(7, 62, 22), // "incomingConnectRequest"
QT_MOC_LITERAL(8, 85, 4), // "host"
QT_MOC_LITERAL(9, 90, 4), // "port"
QT_MOC_LITERAL(10, 95, 27), // "incomingUDPAssociateRequest"
QT_MOC_LITERAL(11, 123, 14), // "sock_connected"
QT_MOC_LITERAL(12, 138, 21), // "sock_connectionClosed"
QT_MOC_LITERAL(13, 160, 25), // "sock_delayedCloseFinished"
QT_MOC_LITERAL(14, 186, 14), // "sock_readyRead"
QT_MOC_LITERAL(15, 201, 17), // "sock_bytesWritten"
QT_MOC_LITERAL(16, 219, 10), // "sock_error"
QT_MOC_LITERAL(17, 230, 5) // "serve"

    },
    "SocksClient\0connected\0\0incomingMethods\0"
    "incomingAuth\0user\0pass\0incomingConnectRequest\0"
    "host\0port\0incomingUDPAssociateRequest\0"
    "sock_connected\0sock_connectionClosed\0"
    "sock_delayedCloseFinished\0sock_readyRead\0"
    "sock_bytesWritten\0sock_error\0serve"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SocksClient[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    1,   75,    2, 0x06 /* Public */,
       4,    2,   78,    2, 0x06 /* Public */,
       7,    2,   83,    2, 0x06 /* Public */,
      10,    0,   88,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   89,    2, 0x08 /* Private */,
      12,    0,   90,    2, 0x08 /* Private */,
      13,    0,   91,    2, 0x08 /* Private */,
      14,    0,   92,    2, 0x08 /* Private */,
      15,    1,   93,    2, 0x08 /* Private */,
      16,    1,   96,    2, 0x08 /* Private */,
      17,    0,   99,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    8,    9,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,

       0        // eod
};

void SocksClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SocksClient *_t = static_cast<SocksClient *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->incomingMethods((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->incomingAuth((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->incomingConnectRequest((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->incomingUDPAssociateRequest(); break;
        case 5: _t->sock_connected(); break;
        case 6: _t->sock_connectionClosed(); break;
        case 7: _t->sock_delayedCloseFinished(); break;
        case 8: _t->sock_readyRead(); break;
        case 9: _t->sock_bytesWritten((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->sock_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->serve(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SocksClient::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksClient::connected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SocksClient::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksClient::incomingMethods)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (SocksClient::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksClient::incomingAuth)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (SocksClient::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksClient::incomingConnectRequest)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (SocksClient::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksClient::incomingUDPAssociateRequest)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject SocksClient::staticMetaObject = {
    { &ByteStream::staticMetaObject, qt_meta_stringdata_SocksClient.data,
      qt_meta_data_SocksClient,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *SocksClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SocksClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SocksClient.stringdata0))
        return static_cast<void*>(this);
    return ByteStream::qt_metacast(_clname);
}

int SocksClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ByteStream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void SocksClient::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SocksClient::incomingMethods(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void SocksClient::incomingAuth(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void SocksClient::incomingConnectRequest(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void SocksClient::incomingUDPAssociateRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
struct qt_meta_stringdata_SocksServer_t {
    QByteArrayData data[13];
    char stringdata0[128];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SocksServer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SocksServer_t qt_meta_stringdata_SocksServer = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SocksServer"
QT_MOC_LITERAL(1, 12, 13), // "incomingReady"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 11), // "incomingUDP"
QT_MOC_LITERAL(4, 39, 4), // "host"
QT_MOC_LITERAL(5, 44, 4), // "port"
QT_MOC_LITERAL(6, 49, 12), // "QHostAddress"
QT_MOC_LITERAL(7, 62, 4), // "addr"
QT_MOC_LITERAL(8, 67, 10), // "sourcePort"
QT_MOC_LITERAL(9, 78, 4), // "data"
QT_MOC_LITERAL(10, 83, 15), // "connectionReady"
QT_MOC_LITERAL(11, 99, 15), // "connectionError"
QT_MOC_LITERAL(12, 115, 12) // "sd_activated"

    },
    "SocksServer\0incomingReady\0\0incomingUDP\0"
    "host\0port\0QHostAddress\0addr\0sourcePort\0"
    "data\0connectionReady\0connectionError\0"
    "sd_activated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SocksServer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    5,   40,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   51,    2, 0x08 /* Private */,
      11,    0,   54,    2, 0x08 /* Private */,
      12,    0,   55,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, 0x80000000 | 6, QMetaType::Int, QMetaType::QByteArray,    4,    5,    7,    8,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void SocksServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SocksServer *_t = static_cast<SocksServer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incomingReady(); break;
        case 1: _t->incomingUDP((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QHostAddress(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QByteArray(*)>(_a[5]))); break;
        case 2: _t->connectionReady((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->connectionError(); break;
        case 4: _t->sd_activated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SocksServer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksServer::incomingReady)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SocksServer::*_t)(const QString & , int , const QHostAddress & , int , const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SocksServer::incomingUDP)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject SocksServer::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_SocksServer.data,
      qt_meta_data_SocksServer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *SocksServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SocksServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SocksServer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SocksServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void SocksServer::incomingReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SocksServer::incomingUDP(const QString & _t1, int _t2, const QHostAddress & _t3, int _t4, const QByteArray & _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
