/****************************************************************************
** Meta object code from reading C++ file 'filetransfer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/xmpp-im/filetransfer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filetransfer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__FileTransfer_t {
    QByteArrayData data[15];
    char stringdata0[167];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__FileTransfer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__FileTransfer_t qt_meta_stringdata_XMPP__FileTransfer = {
    {
QT_MOC_LITERAL(0, 0, 18), // "XMPP::FileTransfer"
QT_MOC_LITERAL(1, 19, 8), // "accepted"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 9), // "connected"
QT_MOC_LITERAL(4, 39, 9), // "readyRead"
QT_MOC_LITERAL(5, 49, 1), // "a"
QT_MOC_LITERAL(6, 51, 12), // "bytesWritten"
QT_MOC_LITERAL(7, 64, 5), // "error"
QT_MOC_LITERAL(8, 70, 11), // "ft_finished"
QT_MOC_LITERAL(9, 82, 13), // "s5b_connected"
QT_MOC_LITERAL(10, 96, 20), // "s5b_connectionClosed"
QT_MOC_LITERAL(11, 117, 13), // "s5b_readyRead"
QT_MOC_LITERAL(12, 131, 16), // "s5b_bytesWritten"
QT_MOC_LITERAL(13, 148, 9), // "s5b_error"
QT_MOC_LITERAL(14, 158, 8) // "doAccept"

    },
    "XMPP::FileTransfer\0accepted\0\0connected\0"
    "readyRead\0a\0bytesWritten\0error\0"
    "ft_finished\0s5b_connected\0"
    "s5b_connectionClosed\0s5b_readyRead\0"
    "s5b_bytesWritten\0s5b_error\0doAccept"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__FileTransfer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    0,   75,    2, 0x06 /* Public */,
       4,    1,   76,    2, 0x06 /* Public */,
       6,    1,   79,    2, 0x06 /* Public */,
       7,    1,   82,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   85,    2, 0x08 /* Private */,
       9,    0,   86,    2, 0x08 /* Private */,
      10,    0,   87,    2, 0x08 /* Private */,
      11,    0,   88,    2, 0x08 /* Private */,
      12,    1,   89,    2, 0x08 /* Private */,
      13,    1,   92,    2, 0x08 /* Private */,
      14,    0,   95,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArray,    5,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,

       0        // eod
};

void XMPP::FileTransfer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileTransfer *_t = static_cast<FileTransfer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->accepted(); break;
        case 1: _t->connected(); break;
        case 2: _t->readyRead((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 3: _t->bytesWritten((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->ft_finished(); break;
        case 6: _t->s5b_connected(); break;
        case 7: _t->s5b_connectionClosed(); break;
        case 8: _t->s5b_readyRead(); break;
        case 9: _t->s5b_bytesWritten((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->s5b_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->doAccept(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FileTransfer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileTransfer::accepted)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (FileTransfer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileTransfer::connected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (FileTransfer::*_t)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileTransfer::readyRead)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (FileTransfer::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileTransfer::bytesWritten)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (FileTransfer::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileTransfer::error)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject XMPP::FileTransfer::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__FileTransfer.data,
      qt_meta_data_XMPP__FileTransfer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::FileTransfer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::FileTransfer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__FileTransfer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::FileTransfer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void XMPP::FileTransfer::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XMPP::FileTransfer::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XMPP::FileTransfer::readyRead(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void XMPP::FileTransfer::bytesWritten(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void XMPP::FileTransfer::error(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
struct qt_meta_stringdata_XMPP__FileTransferManager_t {
    QByteArrayData data[6];
    char stringdata0[68];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__FileTransferManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__FileTransferManager_t qt_meta_stringdata_XMPP__FileTransferManager = {
    {
QT_MOC_LITERAL(0, 0, 25), // "XMPP::FileTransferManager"
QT_MOC_LITERAL(1, 26, 13), // "incomingReady"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 12), // "pft_incoming"
QT_MOC_LITERAL(4, 54, 9), // "FTRequest"
QT_MOC_LITERAL(5, 64, 3) // "req"

    },
    "XMPP::FileTransferManager\0incomingReady\0"
    "\0pft_incoming\0FTRequest\0req"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__FileTransferManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   25,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,

       0        // eod
};

void XMPP::FileTransferManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileTransferManager *_t = static_cast<FileTransferManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incomingReady(); break;
        case 1: _t->pft_incoming((*reinterpret_cast< const FTRequest(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FileTransferManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileTransferManager::incomingReady)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject XMPP::FileTransferManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__FileTransferManager.data,
      qt_meta_data_XMPP__FileTransferManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::FileTransferManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::FileTransferManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__FileTransferManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::FileTransferManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void XMPP::FileTransferManager::incomingReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_XMPP__JT_FT_t {
    QByteArrayData data[1];
    char stringdata0[12];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_FT_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_FT_t qt_meta_stringdata_XMPP__JT_FT = {
    {
QT_MOC_LITERAL(0, 0, 11) // "XMPP::JT_FT"

    },
    "XMPP::JT_FT"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_FT[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::JT_FT::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::JT_FT::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_FT.data,
      qt_meta_data_XMPP__JT_FT,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_FT::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_FT::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_FT.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_FT::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__JT_PushFT_t {
    QByteArrayData data[5];
    char stringdata0[40];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_PushFT_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_PushFT_t qt_meta_stringdata_XMPP__JT_PushFT = {
    {
QT_MOC_LITERAL(0, 0, 15), // "XMPP::JT_PushFT"
QT_MOC_LITERAL(1, 16, 8), // "incoming"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 9), // "FTRequest"
QT_MOC_LITERAL(4, 36, 3) // "req"

    },
    "XMPP::JT_PushFT\0incoming\0\0FTRequest\0"
    "req"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_PushFT[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void XMPP::JT_PushFT::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_PushFT *_t = static_cast<JT_PushFT *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incoming((*reinterpret_cast< const FTRequest(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JT_PushFT::*_t)(const FTRequest & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_PushFT::incoming)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject XMPP::JT_PushFT::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_PushFT.data,
      qt_meta_data_XMPP__JT_PushFT,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_PushFT::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_PushFT::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_PushFT.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_PushFT::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void XMPP::JT_PushFT::incoming(const FTRequest & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
