/****************************************************************************
** Meta object code from reading C++ file 'gameautomaton.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirk/GameLogic/gameautomaton.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gameautomaton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Ksirk__GameLogic__GameAutomaton_t {
    QByteArrayData data[27];
    char stringdata0[338];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Ksirk__GameLogic__GameAutomaton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Ksirk__GameLogic__GameAutomaton_t qt_meta_stringdata_Ksirk__GameLogic__GameAutomaton = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Ksirk::GameLogic::GameAutomaton"
QT_MOC_LITERAL(1, 32, 13), // "newJabberGame"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 3), // "run"
QT_MOC_LITERAL(4, 51, 9), // "GameState"
QT_MOC_LITERAL(5, 61, 19), // "slotPropertyChanged"
QT_MOC_LITERAL(6, 81, 18), // "KGamePropertyBase*"
QT_MOC_LITERAL(7, 100, 4), // "prop"
QT_MOC_LITERAL(8, 105, 6), // "KGame*"
QT_MOC_LITERAL(9, 112, 4), // "game"
QT_MOC_LITERAL(10, 117, 20), // "slotPlayerJoinedGame"
QT_MOC_LITERAL(11, 138, 8), // "KPlayer*"
QT_MOC_LITERAL(12, 147, 6), // "player"
QT_MOC_LITERAL(13, 154, 15), // "slotNetworkData"
QT_MOC_LITERAL(14, 170, 5), // "msgid"
QT_MOC_LITERAL(15, 176, 6), // "buffer"
QT_MOC_LITERAL(16, 183, 8), // "receiver"
QT_MOC_LITERAL(17, 192, 6), // "sender"
QT_MOC_LITERAL(18, 199, 20), // "slotClientJoinedGame"
QT_MOC_LITERAL(19, 220, 8), // "clientid"
QT_MOC_LITERAL(20, 229, 2), // "me"
QT_MOC_LITERAL(21, 232, 28), // "slotConnectionToServerBroken"
QT_MOC_LITERAL(22, 261, 28), // "slotConnectionToClientBroken"
QT_MOC_LITERAL(23, 290, 11), // "KMessageIO*"
QT_MOC_LITERAL(24, 302, 13), // "getDefCountry"
QT_MOC_LITERAL(25, 316, 8), // "Country*"
QT_MOC_LITERAL(26, 325, 12) // "displayGoals"

    },
    "Ksirk::GameLogic::GameAutomaton\0"
    "newJabberGame\0\0run\0GameState\0"
    "slotPropertyChanged\0KGamePropertyBase*\0"
    "prop\0KGame*\0game\0slotPlayerJoinedGame\0"
    "KPlayer*\0player\0slotNetworkData\0msgid\0"
    "buffer\0receiver\0sender\0slotClientJoinedGame\0"
    "clientid\0me\0slotConnectionToServerBroken\0"
    "slotConnectionToClientBroken\0KMessageIO*\0"
    "getDefCountry\0Country*\0displayGoals"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Ksirk__GameLogic__GameAutomaton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   71,    2, 0x0a /* Public */,
       5,    2,   72,    2, 0x0a /* Public */,
      10,    1,   77,    2, 0x0a /* Public */,
      13,    4,   80,    2, 0x0a /* Public */,
      18,    2,   89,    2, 0x0a /* Public */,
      21,    0,   94,    2, 0x0a /* Public */,
      22,    1,   95,    2, 0x0a /* Public */,
      24,    0,   98,    2, 0x0a /* Public */,
      26,    0,   99,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    2,    2,    2,

 // slots: parameters
    0x80000000 | 4,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 8,    7,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::Int, QMetaType::QByteArray, QMetaType::UInt, QMetaType::UInt,   14,   15,   16,   17,
    QMetaType::Void, QMetaType::UInt, 0x80000000 | 8,   19,   20,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 23,    2,
    0x80000000 | 25,
    QMetaType::Void,

       0        // eod
};

void Ksirk::GameLogic::GameAutomaton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameAutomaton *_t = static_cast<GameAutomaton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newJabberGame((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 1: { GameState _r = _t->run();
            if (_a[0]) *reinterpret_cast< GameState*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->slotPropertyChanged((*reinterpret_cast< KGamePropertyBase*(*)>(_a[1])),(*reinterpret_cast< KGame*(*)>(_a[2]))); break;
        case 3: _t->slotPlayerJoinedGame((*reinterpret_cast< KPlayer*(*)>(_a[1]))); break;
        case 4: _t->slotNetworkData((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< quint32(*)>(_a[3])),(*reinterpret_cast< quint32(*)>(_a[4]))); break;
        case 5: _t->slotClientJoinedGame((*reinterpret_cast< quint32(*)>(_a[1])),(*reinterpret_cast< KGame*(*)>(_a[2]))); break;
        case 6: _t->slotConnectionToServerBroken(); break;
        case 7: _t->slotConnectionToClientBroken((*reinterpret_cast< KMessageIO*(*)>(_a[1]))); break;
        case 8: { Country* _r = _t->getDefCountry();
            if (_a[0]) *reinterpret_cast< Country**>(_a[0]) = std::move(_r); }  break;
        case 9: _t->displayGoals(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGame* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPlayer* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGame* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KMessageIO* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GameAutomaton::*_t)(const QString & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameAutomaton::newJabberGame)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Ksirk::GameLogic::GameAutomaton::staticMetaObject = {
    { &KGame::staticMetaObject, qt_meta_stringdata_Ksirk__GameLogic__GameAutomaton.data,
      qt_meta_data_Ksirk__GameLogic__GameAutomaton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Ksirk::GameLogic::GameAutomaton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::GameLogic::GameAutomaton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Ksirk__GameLogic__GameAutomaton.stringdata0))
        return static_cast<void*>(this);
    return KGame::qt_metacast(_clname);
}

int Ksirk::GameLogic::GameAutomaton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Ksirk::GameLogic::GameAutomaton::newJabberGame(const QString & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
