/****************************************************************************
** Meta object code from reading C++ file 'decoratedgameframe.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirk/decoratedgameframe.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decoratedgameframe.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Ksirk__ArenaAction_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Ksirk__ArenaAction_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Ksirk__ArenaAction_t qt_meta_stringdata_Ksirk__ArenaAction = {
    {
QT_MOC_LITERAL(0, 0, 18) // "Ksirk::ArenaAction"

    },
    "Ksirk::ArenaAction"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Ksirk__ArenaAction[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Ksirk::ArenaAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject Ksirk::ArenaAction::staticMetaObject = {
    { &QAction::staticMetaObject, qt_meta_stringdata_Ksirk__ArenaAction.data,
      qt_meta_data_Ksirk__ArenaAction,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Ksirk::ArenaAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::ArenaAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Ksirk__ArenaAction.stringdata0))
        return static_cast<void*>(this);
    return QAction::qt_metacast(_clname);
}

int Ksirk::ArenaAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAction::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Ksirk__DecoratedGameFrame_t {
    QByteArrayData data[17];
    char stringdata0[191];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Ksirk__DecoratedGameFrame_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Ksirk__DecoratedGameFrame_t qt_meta_stringdata_Ksirk__DecoratedGameFrame = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Ksirk::DecoratedGameFrame"
QT_MOC_LITERAL(1, 26, 22), // "mouseMoveEventReceived"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 12), // "QMouseEvent*"
QT_MOC_LITERAL(4, 63, 5), // "event"
QT_MOC_LITERAL(5, 69, 16), // "arenaStateSignal"
QT_MOC_LITERAL(6, 86, 14), // "slotMouseInput"
QT_MOC_LITERAL(7, 101, 8), // "KGameIO*"
QT_MOC_LITERAL(8, 110, 5), // "input"
QT_MOC_LITERAL(9, 116, 12), // "QDataStream&"
QT_MOC_LITERAL(10, 129, 6), // "stream"
QT_MOC_LITERAL(11, 136, 5), // "mouse"
QT_MOC_LITERAL(12, 142, 5), // "bool*"
QT_MOC_LITERAL(13, 148, 8), // "eatevent"
QT_MOC_LITERAL(14, 157, 10), // "arenaState"
QT_MOC_LITERAL(15, 168, 11), // "slotDetails"
QT_MOC_LITERAL(16, 180, 10) // "attackAuto"

    },
    "Ksirk::DecoratedGameFrame\0"
    "mouseMoveEventReceived\0\0QMouseEvent*\0"
    "event\0arenaStateSignal\0slotMouseInput\0"
    "KGameIO*\0input\0QDataStream&\0stream\0"
    "mouse\0bool*\0eatevent\0arenaState\0"
    "slotDetails\0attackAuto"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Ksirk__DecoratedGameFrame[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       5,    1,   47,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    4,   50,    2, 0x0a /* Public */,
      14,    0,   59,    2, 0x0a /* Public */,
      15,    0,   60,    2, 0x0a /* Public */,
      16,    0,   61,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9, 0x80000000 | 3, 0x80000000 | 12,    8,   10,   11,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Ksirk::DecoratedGameFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DecoratedGameFrame *_t = static_cast<DecoratedGameFrame *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->mouseMoveEventReceived((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 1: _t->arenaStateSignal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->slotMouseInput((*reinterpret_cast< KGameIO*(*)>(_a[1])),(*reinterpret_cast< QDataStream(*)>(_a[2])),(*reinterpret_cast< QMouseEvent*(*)>(_a[3])),(*reinterpret_cast< bool*(*)>(_a[4]))); break;
        case 3: _t->arenaState(); break;
        case 4: _t->slotDetails(); break;
        case 5: _t->attackAuto(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KGameIO* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (DecoratedGameFrame::*_t)(QMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedGameFrame::mouseMoveEventReceived)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DecoratedGameFrame::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedGameFrame::arenaStateSignal)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Ksirk::DecoratedGameFrame::staticMetaObject = {
    { &QGraphicsView::staticMetaObject, qt_meta_stringdata_Ksirk__DecoratedGameFrame.data,
      qt_meta_data_Ksirk__DecoratedGameFrame,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Ksirk::DecoratedGameFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::DecoratedGameFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Ksirk__DecoratedGameFrame.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int Ksirk::DecoratedGameFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Ksirk::DecoratedGameFrame::mouseMoveEventReceived(QMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Ksirk::DecoratedGameFrame::arenaStateSignal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
