/****************************************************************************
** Meta object code from reading C++ file 'xmpp_ibb.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/xmpp-im/xmpp_ibb.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xmpp_ibb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__IBBConnection_t {
    QByteArrayData data[5];
    char stringdata0[52];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__IBBConnection_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__IBBConnection_t qt_meta_stringdata_XMPP__IBBConnection = {
    {
QT_MOC_LITERAL(0, 0, 19), // "XMPP::IBBConnection"
QT_MOC_LITERAL(1, 20, 9), // "connected"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 12), // "ibb_finished"
QT_MOC_LITERAL(4, 44, 7) // "trySend"

    },
    "XMPP::IBBConnection\0connected\0\0"
    "ibb_finished\0trySend"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__IBBConnection[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   30,    2, 0x08 /* Private */,
       4,    0,   31,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::IBBConnection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IBBConnection *_t = static_cast<IBBConnection *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->ibb_finished(); break;
        case 2: _t->trySend(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (IBBConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IBBConnection::connected)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject XMPP::IBBConnection::staticMetaObject = {
    { &ByteStream::staticMetaObject, qt_meta_stringdata_XMPP__IBBConnection.data,
      qt_meta_data_XMPP__IBBConnection,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::IBBConnection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::IBBConnection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__IBBConnection.stringdata0))
        return static_cast<void*>(this);
    return ByteStream::qt_metacast(_clname);
}

int XMPP::IBBConnection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ByteStream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void XMPP::IBBConnection::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_XMPP__IBBManager_t {
    QByteArrayData data[12];
    char stringdata0[113];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__IBBManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__IBBManager_t qt_meta_stringdata_XMPP__IBBManager = {
    {
QT_MOC_LITERAL(0, 0, 16), // "XMPP::IBBManager"
QT_MOC_LITERAL(1, 17, 13), // "incomingReady"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 19), // "ibb_incomingRequest"
QT_MOC_LITERAL(4, 52, 3), // "Jid"
QT_MOC_LITERAL(5, 56, 4), // "from"
QT_MOC_LITERAL(6, 61, 2), // "id"
QT_MOC_LITERAL(7, 64, 11), // "QDomElement"
QT_MOC_LITERAL(8, 76, 16), // "ibb_incomingData"
QT_MOC_LITERAL(9, 93, 8), // "streamid"
QT_MOC_LITERAL(10, 102, 4), // "data"
QT_MOC_LITERAL(11, 107, 5) // "close"

    },
    "XMPP::IBBManager\0incomingReady\0\0"
    "ibb_incomingRequest\0Jid\0from\0id\0"
    "QDomElement\0ibb_incomingData\0streamid\0"
    "data\0close"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__IBBManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    3,   30,    2, 0x08 /* Private */,
       8,    5,   37,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4, QMetaType::QString, 0x80000000 | 7,    5,    6,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QString, QMetaType::QString, QMetaType::QByteArray, QMetaType::Bool,    5,    9,    6,   10,   11,

       0        // eod
};

void XMPP::IBBManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IBBManager *_t = static_cast<IBBManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incomingReady(); break;
        case 1: _t->ibb_incomingRequest((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QDomElement(*)>(_a[3]))); break;
        case 2: _t->ibb_incomingData((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QByteArray(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (IBBManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IBBManager::incomingReady)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject XMPP::IBBManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__IBBManager.data,
      qt_meta_data_XMPP__IBBManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::IBBManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::IBBManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__IBBManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::IBBManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void XMPP::IBBManager::incomingReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_XMPP__JT_IBB_t {
    QByteArrayData data[11];
    char stringdata0[87];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__JT_IBB_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__JT_IBB_t qt_meta_stringdata_XMPP__JT_IBB = {
    {
QT_MOC_LITERAL(0, 0, 12), // "XMPP::JT_IBB"
QT_MOC_LITERAL(1, 13, 15), // "incomingRequest"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 3), // "Jid"
QT_MOC_LITERAL(4, 34, 4), // "from"
QT_MOC_LITERAL(5, 39, 2), // "id"
QT_MOC_LITERAL(6, 42, 11), // "QDomElement"
QT_MOC_LITERAL(7, 54, 12), // "incomingData"
QT_MOC_LITERAL(8, 67, 8), // "streamid"
QT_MOC_LITERAL(9, 76, 4), // "data"
QT_MOC_LITERAL(10, 81, 5) // "close"

    },
    "XMPP::JT_IBB\0incomingRequest\0\0Jid\0"
    "from\0id\0QDomElement\0incomingData\0"
    "streamid\0data\0close"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__JT_IBB[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   24,    2, 0x06 /* Public */,
       7,    5,   31,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, 0x80000000 | 6,    4,    5,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString, QMetaType::QByteArray, QMetaType::Bool,    4,    8,    5,    9,   10,

       0        // eod
};

void XMPP::JT_IBB::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JT_IBB *_t = static_cast<JT_IBB *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incomingRequest((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QDomElement(*)>(_a[3]))); break;
        case 1: _t->incomingData((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QByteArray(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JT_IBB::*_t)(const Jid & , const QString & , const QDomElement & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_IBB::incomingRequest)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (JT_IBB::*_t)(const Jid & , const QString & , const QString & , const QByteArray & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JT_IBB::incomingData)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject XMPP::JT_IBB::staticMetaObject = {
    { &Task::staticMetaObject, qt_meta_stringdata_XMPP__JT_IBB.data,
      qt_meta_data_XMPP__JT_IBB,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::JT_IBB::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::JT_IBB::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__JT_IBB.stringdata0))
        return static_cast<void*>(this);
    return Task::qt_metacast(_clname);
}

int XMPP::JT_IBB::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Task::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void XMPP::JT_IBB::incomingRequest(const Jid & _t1, const QString & _t2, const QDomElement & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::JT_IBB::incomingData(const Jid & _t1, const QString & _t2, const QString & _t3, const QByteArray & _t4, bool _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
