/****************************************************************************
** Meta object code from reading C++ file 'httppoll.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/cutestuff/httppoll.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'httppoll.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_HttpPoll_t {
    QByteArrayData data[8];
    char stringdata0[76];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_HttpPoll_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_HttpPoll_t qt_meta_stringdata_HttpPoll = {
    {
QT_MOC_LITERAL(0, 0, 8), // "HttpPoll"
QT_MOC_LITERAL(1, 9, 9), // "connected"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 11), // "syncStarted"
QT_MOC_LITERAL(4, 32, 12), // "syncFinished"
QT_MOC_LITERAL(5, 45, 11), // "http_result"
QT_MOC_LITERAL(6, 57, 10), // "http_error"
QT_MOC_LITERAL(7, 68, 7) // "do_sync"

    },
    "HttpPoll\0connected\0\0syncStarted\0"
    "syncFinished\0http_result\0http_error\0"
    "do_sync"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_HttpPoll[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    0,   45,    2, 0x06 /* Public */,
       4,    0,   46,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   47,    2, 0x08 /* Private */,
       6,    1,   48,    2, 0x08 /* Private */,
       7,    0,   51,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,

       0        // eod
};

void HttpPoll::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HttpPoll *_t = static_cast<HttpPoll *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->syncStarted(); break;
        case 2: _t->syncFinished(); break;
        case 3: _t->http_result(); break;
        case 4: _t->http_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->do_sync(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (HttpPoll::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpPoll::connected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (HttpPoll::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpPoll::syncStarted)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (HttpPoll::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpPoll::syncFinished)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject HttpPoll::staticMetaObject = {
    { &ByteStream::staticMetaObject, qt_meta_stringdata_HttpPoll.data,
      qt_meta_data_HttpPoll,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *HttpPoll::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HttpPoll::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_HttpPoll.stringdata0))
        return static_cast<void*>(this);
    return ByteStream::qt_metacast(_clname);
}

int HttpPoll::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ByteStream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void HttpPoll::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void HttpPoll::syncStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void HttpPoll::syncFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
struct qt_meta_stringdata_HttpProxyPost_t {
    QByteArrayData data[8];
    char stringdata0[91];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_HttpProxyPost_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_HttpProxyPost_t qt_meta_stringdata_HttpProxyPost = {
    {
QT_MOC_LITERAL(0, 0, 13), // "HttpProxyPost"
QT_MOC_LITERAL(1, 14, 6), // "result"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 5), // "error"
QT_MOC_LITERAL(4, 28, 14), // "sock_connected"
QT_MOC_LITERAL(5, 43, 21), // "sock_connectionClosed"
QT_MOC_LITERAL(6, 65, 14), // "sock_readyRead"
QT_MOC_LITERAL(7, 80, 10) // "sock_error"

    },
    "HttpProxyPost\0result\0\0error\0sock_connected\0"
    "sock_connectionClosed\0sock_readyRead\0"
    "sock_error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_HttpProxyPost[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    1,   45,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   48,    2, 0x08 /* Private */,
       5,    0,   49,    2, 0x08 /* Private */,
       6,    0,   50,    2, 0x08 /* Private */,
       7,    1,   51,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void HttpProxyPost::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HttpProxyPost *_t = static_cast<HttpProxyPost *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->result(); break;
        case 1: _t->error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->sock_connected(); break;
        case 3: _t->sock_connectionClosed(); break;
        case 4: _t->sock_readyRead(); break;
        case 5: _t->sock_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (HttpProxyPost::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpProxyPost::result)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (HttpProxyPost::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpProxyPost::error)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject HttpProxyPost::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_HttpProxyPost.data,
      qt_meta_data_HttpProxyPost,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *HttpProxyPost::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HttpProxyPost::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_HttpProxyPost.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int HttpProxyPost::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void HttpProxyPost::result()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void HttpProxyPost::error(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_HttpProxyGetStream_t {
    QByteArrayData data[14];
    char stringdata0[169];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_HttpProxyGetStream_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_HttpProxyGetStream_t qt_meta_stringdata_HttpProxyGetStream = {
    {
QT_MOC_LITERAL(0, 0, 18), // "HttpProxyGetStream"
QT_MOC_LITERAL(1, 19, 10), // "handshaken"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 9), // "dataReady"
QT_MOC_LITERAL(4, 41, 3), // "buf"
QT_MOC_LITERAL(5, 45, 8), // "finished"
QT_MOC_LITERAL(6, 54, 5), // "error"
QT_MOC_LITERAL(7, 60, 14), // "sock_connected"
QT_MOC_LITERAL(8, 75, 21), // "sock_connectionClosed"
QT_MOC_LITERAL(9, 97, 14), // "sock_readyRead"
QT_MOC_LITERAL(10, 112, 10), // "sock_error"
QT_MOC_LITERAL(11, 123, 13), // "tls_readyRead"
QT_MOC_LITERAL(12, 137, 21), // "tls_readyReadOutgoing"
QT_MOC_LITERAL(13, 159, 9) // "tls_error"

    },
    "HttpProxyGetStream\0handshaken\0\0dataReady\0"
    "buf\0finished\0error\0sock_connected\0"
    "sock_connectionClosed\0sock_readyRead\0"
    "sock_error\0tls_readyRead\0tls_readyReadOutgoing\0"
    "tls_error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_HttpProxyGetStream[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    1,   70,    2, 0x06 /* Public */,
       5,    0,   73,    2, 0x06 /* Public */,
       6,    1,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   77,    2, 0x08 /* Private */,
       8,    0,   78,    2, 0x08 /* Private */,
       9,    0,   79,    2, 0x08 /* Private */,
      10,    1,   80,    2, 0x08 /* Private */,
      11,    0,   83,    2, 0x08 /* Private */,
      12,    0,   84,    2, 0x08 /* Private */,
      13,    0,   85,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArray,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void HttpProxyGetStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HttpProxyGetStream *_t = static_cast<HttpProxyGetStream *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->handshaken(); break;
        case 1: _t->dataReady((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 2: _t->finished(); break;
        case 3: _t->error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->sock_connected(); break;
        case 5: _t->sock_connectionClosed(); break;
        case 6: _t->sock_readyRead(); break;
        case 7: _t->sock_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->tls_readyRead(); break;
        case 9: _t->tls_readyReadOutgoing(); break;
        case 10: _t->tls_error(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (HttpProxyGetStream::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpProxyGetStream::handshaken)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (HttpProxyGetStream::*_t)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpProxyGetStream::dataReady)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (HttpProxyGetStream::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpProxyGetStream::finished)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (HttpProxyGetStream::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpProxyGetStream::error)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject HttpProxyGetStream::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_HttpProxyGetStream.data,
      qt_meta_data_HttpProxyGetStream,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *HttpProxyGetStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HttpProxyGetStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_HttpProxyGetStream.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int HttpProxyGetStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void HttpProxyGetStream::handshaken()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void HttpProxyGetStream::dataReady(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void HttpProxyGetStream::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void HttpProxyGetStream::error(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
