/****************************************************************************
** Meta object code from reading C++ file 'httpconnect.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/cutestuff/httpconnect.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'httpconnect.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_HttpConnect_t {
    QByteArrayData data[9];
    char stringdata0[130];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_HttpConnect_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_HttpConnect_t qt_meta_stringdata_HttpConnect = {
    {
QT_MOC_LITERAL(0, 0, 11), // "HttpConnect"
QT_MOC_LITERAL(1, 12, 9), // "connected"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 14), // "sock_connected"
QT_MOC_LITERAL(4, 38, 21), // "sock_connectionClosed"
QT_MOC_LITERAL(5, 60, 25), // "sock_delayedCloseFinished"
QT_MOC_LITERAL(6, 86, 14), // "sock_readyRead"
QT_MOC_LITERAL(7, 101, 17), // "sock_bytesWritten"
QT_MOC_LITERAL(8, 119, 10) // "sock_error"

    },
    "HttpConnect\0connected\0\0sock_connected\0"
    "sock_connectionClosed\0sock_delayedCloseFinished\0"
    "sock_readyRead\0sock_bytesWritten\0"
    "sock_error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_HttpConnect[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   50,    2, 0x08 /* Private */,
       4,    0,   51,    2, 0x08 /* Private */,
       5,    0,   52,    2, 0x08 /* Private */,
       6,    0,   53,    2, 0x08 /* Private */,
       7,    1,   54,    2, 0x08 /* Private */,
       8,    1,   57,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void HttpConnect::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HttpConnect *_t = static_cast<HttpConnect *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->sock_connected(); break;
        case 2: _t->sock_connectionClosed(); break;
        case 3: _t->sock_delayedCloseFinished(); break;
        case 4: _t->sock_readyRead(); break;
        case 5: _t->sock_bytesWritten((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->sock_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (HttpConnect::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpConnect::connected)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject HttpConnect::staticMetaObject = {
    { &ByteStream::staticMetaObject, qt_meta_stringdata_HttpConnect.data,
      qt_meta_data_HttpConnect,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *HttpConnect::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HttpConnect::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_HttpConnect.stringdata0))
        return static_cast<void*>(this);
    return ByteStream::qt_metacast(_clname);
}

int HttpConnect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ByteStream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void HttpConnect::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
