/****************************************************************************
** Meta object code from reading C++ file 'jabbergameui.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirk/Dialogs/jabbergameui.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jabbergameui.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KsirkJabberGameWidget_t {
    QByteArrayData data[33];
    char stringdata0[489];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KsirkJabberGameWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KsirkJabberGameWidget_t qt_meta_stringdata_KsirkJabberGameWidget = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KsirkJabberGameWidget"
QT_MOC_LITERAL(1, 22, 9), // "cancelled"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 17), // "slotNewJabberGame"
QT_MOC_LITERAL(4, 51, 4), // "nick"
QT_MOC_LITERAL(5, 56, 9), // "nbPlayers"
QT_MOC_LITERAL(6, 66, 4), // "skin"
QT_MOC_LITERAL(7, 71, 30), // "slotJabberConnectButtonClicked"
QT_MOC_LITERAL(8, 102, 22), // "slotJabberDisconnected"
QT_MOC_LITERAL(9, 125, 15), // "slotJabberError"
QT_MOC_LITERAL(10, 141, 20), // "slotHandleTLSWarning"
QT_MOC_LITERAL(11, 162, 24), // "QCA::TLS::IdentityResult"
QT_MOC_LITERAL(12, 187, 13), // "QCA::Validity"
QT_MOC_LITERAL(13, 201, 19), // "slotJabberConnected"
QT_MOC_LITERAL(14, 221, 21), // "slotJabberClientError"
QT_MOC_LITERAL(15, 243, 23), // "JabberClient::ErrorCode"
QT_MOC_LITERAL(16, 267, 25), // "slotRosterRequestFinished"
QT_MOC_LITERAL(17, 293, 12), // "slotJoinRoom"
QT_MOC_LITERAL(18, 306, 19), // "slotGroupChatJoined"
QT_MOC_LITERAL(19, 326, 9), // "XMPP::Jid"
QT_MOC_LITERAL(20, 336, 3), // "jid"
QT_MOC_LITERAL(21, 340, 17), // "slotGroupChatLeft"
QT_MOC_LITERAL(22, 358, 21), // "slotGroupChatPresence"
QT_MOC_LITERAL(23, 380, 12), // "XMPP::Status"
QT_MOC_LITERAL(24, 393, 6), // "status"
QT_MOC_LITERAL(25, 400, 18), // "slotGroupChatError"
QT_MOC_LITERAL(26, 419, 5), // "error"
QT_MOC_LITERAL(27, 425, 6), // "reason"
QT_MOC_LITERAL(28, 432, 18), // "slotJoinJabberGame"
QT_MOC_LITERAL(29, 451, 15), // "slotCellClicked"
QT_MOC_LITERAL(30, 467, 3), // "row"
QT_MOC_LITERAL(31, 471, 6), // "column"
QT_MOC_LITERAL(32, 478, 10) // "slotCancel"

    },
    "KsirkJabberGameWidget\0cancelled\0\0"
    "slotNewJabberGame\0nick\0nbPlayers\0skin\0"
    "slotJabberConnectButtonClicked\0"
    "slotJabberDisconnected\0slotJabberError\0"
    "slotHandleTLSWarning\0QCA::TLS::IdentityResult\0"
    "QCA::Validity\0slotJabberConnected\0"
    "slotJabberClientError\0JabberClient::ErrorCode\0"
    "slotRosterRequestFinished\0slotJoinRoom\0"
    "slotGroupChatJoined\0XMPP::Jid\0jid\0"
    "slotGroupChatLeft\0slotGroupChatPresence\0"
    "XMPP::Status\0status\0slotGroupChatError\0"
    "error\0reason\0slotJoinJabberGame\0"
    "slotCellClicked\0row\0column\0slotCancel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KsirkJabberGameWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    3,  102,    2, 0x0a /* Public */,
       7,    0,  109,    2, 0x08 /* Private */,
       8,    0,  110,    2, 0x08 /* Private */,
       9,    1,  111,    2, 0x08 /* Private */,
      10,    2,  114,    2, 0x08 /* Private */,
      13,    0,  119,    2, 0x08 /* Private */,
      14,    1,  120,    2, 0x08 /* Private */,
      16,    1,  123,    2, 0x08 /* Private */,
      17,    0,  126,    2, 0x08 /* Private */,
      18,    1,  127,    2, 0x08 /* Private */,
      21,    1,  130,    2, 0x08 /* Private */,
      22,    2,  133,    2, 0x08 /* Private */,
      25,    3,  138,    2, 0x08 /* Private */,
      28,    0,  145,    2, 0x08 /* Private */,
      29,    2,  146,    2, 0x08 /* Private */,
      32,    0,  151,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    4,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 11, 0x80000000 | 12,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void, 0x80000000 | 19, 0x80000000 | 23,   20,   24,
    QMetaType::Void, 0x80000000 | 19, QMetaType::Int, QMetaType::QString,   20,   26,   27,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   30,   31,
    QMetaType::Void,

       0        // eod
};

void KsirkJabberGameWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KsirkJabberGameWidget *_t = static_cast<KsirkJabberGameWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->cancelled((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->slotNewJabberGame((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->slotJabberConnectButtonClicked(); break;
        case 3: _t->slotJabberDisconnected(); break;
        case 4: _t->slotJabberError((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->slotHandleTLSWarning((*reinterpret_cast< QCA::TLS::IdentityResult(*)>(_a[1])),(*reinterpret_cast< QCA::Validity(*)>(_a[2]))); break;
        case 6: _t->slotJabberConnected(); break;
        case 7: _t->slotJabberClientError((*reinterpret_cast< JabberClient::ErrorCode(*)>(_a[1]))); break;
        case 8: _t->slotRosterRequestFinished((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->slotJoinRoom(); break;
        case 10: _t->slotGroupChatJoined((*reinterpret_cast< const XMPP::Jid(*)>(_a[1]))); break;
        case 11: _t->slotGroupChatLeft((*reinterpret_cast< const XMPP::Jid(*)>(_a[1]))); break;
        case 12: _t->slotGroupChatPresence((*reinterpret_cast< const XMPP::Jid(*)>(_a[1])),(*reinterpret_cast< const XMPP::Status(*)>(_a[2]))); break;
        case 13: _t->slotGroupChatError((*reinterpret_cast< const XMPP::Jid(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 14: _t->slotJoinJabberGame(); break;
        case 15: _t->slotCellClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 16: _t->slotCancel(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KsirkJabberGameWidget::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KsirkJabberGameWidget::cancelled)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KsirkJabberGameWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KsirkJabberGameWidget.data,
      qt_meta_data_KsirkJabberGameWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KsirkJabberGameWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KsirkJabberGameWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KsirkJabberGameWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::KsirkJabberGameWidget"))
        return static_cast< Ui::KsirkJabberGameWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int KsirkJabberGameWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void KsirkJabberGameWidget::cancelled(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
