/****************************************************************************
** Meta object code from reading C++ file 'xmpp.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/xmpp-core/xmpp.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xmpp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__Connector_t {
    QByteArrayData data[4];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__Connector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__Connector_t qt_meta_stringdata_XMPP__Connector = {
    {
QT_MOC_LITERAL(0, 0, 15), // "XMPP::Connector"
QT_MOC_LITERAL(1, 16, 9), // "connected"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 5) // "error"

    },
    "XMPP::Connector\0connected\0\0error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__Connector[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    0,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::Connector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Connector *_t = static_cast<Connector *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->error(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Connector::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Connector::connected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Connector::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Connector::error)) {
                *result = 1;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject XMPP::Connector::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__Connector.data,
      qt_meta_data_XMPP__Connector,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::Connector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::Connector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__Connector.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::Connector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void XMPP::Connector::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XMPP::Connector::error()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_XMPP__AdvancedConnector_t {
    QByteArrayData data[15];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__AdvancedConnector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__AdvancedConnector_t qt_meta_stringdata_XMPP__AdvancedConnector = {
    {
QT_MOC_LITERAL(0, 0, 23), // "XMPP::AdvancedConnector"
QT_MOC_LITERAL(1, 24, 9), // "srvLookup"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 6), // "server"
QT_MOC_LITERAL(4, 42, 9), // "srvResult"
QT_MOC_LITERAL(5, 52, 7), // "success"
QT_MOC_LITERAL(6, 60, 15), // "httpSyncStarted"
QT_MOC_LITERAL(7, 76, 16), // "httpSyncFinished"
QT_MOC_LITERAL(8, 93, 8), // "dns_done"
QT_MOC_LITERAL(9, 102, 8), // "srv_done"
QT_MOC_LITERAL(10, 111, 12), // "bs_connected"
QT_MOC_LITERAL(11, 124, 8), // "bs_error"
QT_MOC_LITERAL(12, 133, 16), // "http_syncStarted"
QT_MOC_LITERAL(13, 150, 17), // "http_syncFinished"
QT_MOC_LITERAL(14, 168, 9) // "t_timeout"

    },
    "XMPP::AdvancedConnector\0srvLookup\0\0"
    "server\0srvResult\0success\0httpSyncStarted\0"
    "httpSyncFinished\0dns_done\0srv_done\0"
    "bs_connected\0bs_error\0http_syncStarted\0"
    "http_syncFinished\0t_timeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__AdvancedConnector[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    1,   72,    2, 0x06 /* Public */,
       6,    0,   75,    2, 0x06 /* Public */,
       7,    0,   76,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   77,    2, 0x08 /* Private */,
       9,    0,   78,    2, 0x08 /* Private */,
      10,    0,   79,    2, 0x08 /* Private */,
      11,    1,   80,    2, 0x08 /* Private */,
      12,    0,   83,    2, 0x08 /* Private */,
      13,    0,   84,    2, 0x08 /* Private */,
      14,    0,   85,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::AdvancedConnector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AdvancedConnector *_t = static_cast<AdvancedConnector *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->srvLookup((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->srvResult((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->httpSyncStarted(); break;
        case 3: _t->httpSyncFinished(); break;
        case 4: _t->dns_done(); break;
        case 5: _t->srv_done(); break;
        case 6: _t->bs_connected(); break;
        case 7: _t->bs_error((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->http_syncStarted(); break;
        case 9: _t->http_syncFinished(); break;
        case 10: _t->t_timeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (AdvancedConnector::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AdvancedConnector::srvLookup)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AdvancedConnector::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AdvancedConnector::srvResult)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (AdvancedConnector::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AdvancedConnector::httpSyncStarted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (AdvancedConnector::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AdvancedConnector::httpSyncFinished)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject XMPP::AdvancedConnector::staticMetaObject = {
    { &Connector::staticMetaObject, qt_meta_stringdata_XMPP__AdvancedConnector.data,
      qt_meta_data_XMPP__AdvancedConnector,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::AdvancedConnector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::AdvancedConnector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__AdvancedConnector.stringdata0))
        return static_cast<void*>(this);
    return Connector::qt_metacast(_clname);
}

int XMPP::AdvancedConnector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Connector::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void XMPP::AdvancedConnector::srvLookup(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::AdvancedConnector::srvResult(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void XMPP::AdvancedConnector::httpSyncStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void XMPP::AdvancedConnector::httpSyncFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
struct qt_meta_stringdata_XMPP__TLSHandler_t {
    QByteArrayData data[9];
    char stringdata0[79];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__TLSHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__TLSHandler_t qt_meta_stringdata_XMPP__TLSHandler = {
    {
QT_MOC_LITERAL(0, 0, 16), // "XMPP::TLSHandler"
QT_MOC_LITERAL(1, 17, 7), // "success"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 4), // "fail"
QT_MOC_LITERAL(4, 31, 6), // "closed"
QT_MOC_LITERAL(5, 38, 9), // "readyRead"
QT_MOC_LITERAL(6, 48, 1), // "a"
QT_MOC_LITERAL(7, 50, 17), // "readyReadOutgoing"
QT_MOC_LITERAL(8, 68, 10) // "plainBytes"

    },
    "XMPP::TLSHandler\0success\0\0fail\0closed\0"
    "readyRead\0a\0readyReadOutgoing\0plainBytes"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__TLSHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    0,   40,    2, 0x06 /* Public */,
       4,    0,   41,    2, 0x06 /* Public */,
       5,    1,   42,    2, 0x06 /* Public */,
       7,    2,   45,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArray,    6,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::Int,    6,    8,

       0        // eod
};

void XMPP::TLSHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TLSHandler *_t = static_cast<TLSHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->success(); break;
        case 1: _t->fail(); break;
        case 2: _t->closed(); break;
        case 3: _t->readyRead((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 4: _t->readyReadOutgoing((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TLSHandler::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TLSHandler::success)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TLSHandler::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TLSHandler::fail)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TLSHandler::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TLSHandler::closed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (TLSHandler::*_t)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TLSHandler::readyRead)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (TLSHandler::*_t)(const QByteArray & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TLSHandler::readyReadOutgoing)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject XMPP::TLSHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__TLSHandler.data,
      qt_meta_data_XMPP__TLSHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::TLSHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::TLSHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__TLSHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::TLSHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void XMPP::TLSHandler::success()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XMPP::TLSHandler::fail()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XMPP::TLSHandler::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void XMPP::TLSHandler::readyRead(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void XMPP::TLSHandler::readyReadOutgoing(const QByteArray & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
struct qt_meta_stringdata_XMPP__QCATLSHandler_t {
    QByteArrayData data[9];
    char stringdata0[130];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__QCATLSHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__QCATLSHandler_t qt_meta_stringdata_XMPP__QCATLSHandler = {
    {
QT_MOC_LITERAL(0, 0, 19), // "XMPP::QCATLSHandler"
QT_MOC_LITERAL(1, 20, 13), // "tlsHandshaken"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 22), // "continueAfterHandshake"
QT_MOC_LITERAL(4, 58, 14), // "tls_handshaken"
QT_MOC_LITERAL(5, 73, 13), // "tls_readyRead"
QT_MOC_LITERAL(6, 87, 21), // "tls_readyReadOutgoing"
QT_MOC_LITERAL(7, 109, 10), // "tls_closed"
QT_MOC_LITERAL(8, 120, 9) // "tls_error"

    },
    "XMPP::QCATLSHandler\0tlsHandshaken\0\0"
    "continueAfterHandshake\0tls_handshaken\0"
    "tls_readyRead\0tls_readyReadOutgoing\0"
    "tls_closed\0tls_error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__QCATLSHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   50,    2, 0x0a /* Public */,
       4,    0,   51,    2, 0x08 /* Private */,
       5,    0,   52,    2, 0x08 /* Private */,
       6,    0,   53,    2, 0x08 /* Private */,
       7,    0,   54,    2, 0x08 /* Private */,
       8,    0,   55,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::QCATLSHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QCATLSHandler *_t = static_cast<QCATLSHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->tlsHandshaken(); break;
        case 1: _t->continueAfterHandshake(); break;
        case 2: _t->tls_handshaken(); break;
        case 3: _t->tls_readyRead(); break;
        case 4: _t->tls_readyReadOutgoing(); break;
        case 5: _t->tls_closed(); break;
        case 6: _t->tls_error(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (QCATLSHandler::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCATLSHandler::tlsHandshaken)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject XMPP::QCATLSHandler::staticMetaObject = {
    { &TLSHandler::staticMetaObject, qt_meta_stringdata_XMPP__QCATLSHandler.data,
      qt_meta_data_XMPP__QCATLSHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::QCATLSHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::QCATLSHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__QCATLSHandler.stringdata0))
        return static_cast<void*>(this);
    return TLSHandler::qt_metacast(_clname);
}

int XMPP::QCATLSHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TLSHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void XMPP::QCATLSHandler::tlsHandshaken()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
