#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'ksirkcountrydefinition.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KSIRKCOUNTRYDEFINITION_H
#define UI_KSIRKCOUNTRYDEFINITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_KsirkCountryDefinition
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *label_5;
    QLabel *label_6;
    QLabel *label_7;
    QSpinBox *infantryx;
    QLabel *label_8;
    QSpinBox *infantryy;
    QLabel *label_9;
    QSpinBox *cavalryx;
    QLabel *label_10;
    QSpinBox *cavalryy;
    QLabel *label_12;
    QLabel *label_11;
    QSpinBox *cannony;
    QSpinBox *cannonx;
    QSpinBox *centery;
    QSpinBox *centerx;
    QSpinBox *anchory;
    QSpinBox *anchorx;
    QSpinBox *flagy;
    QSpinBox *flagx;
    QPushButton *neighboursbutton;
    QListWidget *neighbourslist;

    void setupUi(QDockWidget *KsirkCountryDefinition)
    {
        if (KsirkCountryDefinition->objectName().isEmpty())
            KsirkCountryDefinition->setObjectName(QStringLiteral("KsirkCountryDefinition"));
        KsirkCountryDefinition->resize(291, 550);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName(QStringLiteral("dockWidgetContents"));
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label = new QLabel(dockWidgetContents);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(dockWidgetContents);
        label_2->setObjectName(QStringLiteral("label_2"));
        label_2->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_2, 0, 2, 1, 1);

        label_3 = new QLabel(dockWidgetContents);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        label_4 = new QLabel(dockWidgetContents);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_4, 1, 2, 1, 1);

        label_5 = new QLabel(dockWidgetContents);
        label_5->setObjectName(QStringLiteral("label_5"));

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        label_6 = new QLabel(dockWidgetContents);
        label_6->setObjectName(QStringLiteral("label_6"));
        label_6->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_6, 2, 2, 1, 1);

        label_7 = new QLabel(dockWidgetContents);
        label_7->setObjectName(QStringLiteral("label_7"));

        gridLayout->addWidget(label_7, 3, 0, 1, 1);

        infantryx = new QSpinBox(dockWidgetContents);
        infantryx->setObjectName(QStringLiteral("infantryx"));

        gridLayout->addWidget(infantryx, 3, 1, 1, 1);

        label_8 = new QLabel(dockWidgetContents);
        label_8->setObjectName(QStringLiteral("label_8"));
        label_8->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_8, 3, 2, 1, 1);

        infantryy = new QSpinBox(dockWidgetContents);
        infantryy->setObjectName(QStringLiteral("infantryy"));

        gridLayout->addWidget(infantryy, 3, 3, 1, 1);

        label_9 = new QLabel(dockWidgetContents);
        label_9->setObjectName(QStringLiteral("label_9"));

        gridLayout->addWidget(label_9, 4, 0, 1, 1);

        cavalryx = new QSpinBox(dockWidgetContents);
        cavalryx->setObjectName(QStringLiteral("cavalryx"));

        gridLayout->addWidget(cavalryx, 4, 1, 1, 1);

        label_10 = new QLabel(dockWidgetContents);
        label_10->setObjectName(QStringLiteral("label_10"));
        label_10->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_10, 4, 2, 1, 1);

        cavalryy = new QSpinBox(dockWidgetContents);
        cavalryy->setObjectName(QStringLiteral("cavalryy"));

        gridLayout->addWidget(cavalryy, 4, 3, 1, 1);

        label_12 = new QLabel(dockWidgetContents);
        label_12->setObjectName(QStringLiteral("label_12"));

        gridLayout->addWidget(label_12, 5, 0, 1, 1);

        label_11 = new QLabel(dockWidgetContents);
        label_11->setObjectName(QStringLiteral("label_11"));
        label_11->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_11, 5, 2, 1, 1);

        cannony = new QSpinBox(dockWidgetContents);
        cannony->setObjectName(QStringLiteral("cannony"));

        gridLayout->addWidget(cannony, 5, 3, 1, 1);

        cannonx = new QSpinBox(dockWidgetContents);
        cannonx->setObjectName(QStringLiteral("cannonx"));

        gridLayout->addWidget(cannonx, 5, 1, 1, 1);

        centery = new QSpinBox(dockWidgetContents);
        centery->setObjectName(QStringLiteral("centery"));

        gridLayout->addWidget(centery, 2, 3, 1, 1);

        centerx = new QSpinBox(dockWidgetContents);
        centerx->setObjectName(QStringLiteral("centerx"));

        gridLayout->addWidget(centerx, 2, 1, 1, 1);

        anchory = new QSpinBox(dockWidgetContents);
        anchory->setObjectName(QStringLiteral("anchory"));

        gridLayout->addWidget(anchory, 1, 3, 1, 1);

        anchorx = new QSpinBox(dockWidgetContents);
        anchorx->setObjectName(QStringLiteral("anchorx"));

        gridLayout->addWidget(anchorx, 1, 1, 1, 1);

        flagy = new QSpinBox(dockWidgetContents);
        flagy->setObjectName(QStringLiteral("flagy"));

        gridLayout->addWidget(flagy, 0, 3, 1, 1);

        flagx = new QSpinBox(dockWidgetContents);
        flagx->setObjectName(QStringLiteral("flagx"));

        gridLayout->addWidget(flagx, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        neighboursbutton = new QPushButton(dockWidgetContents);
        neighboursbutton->setObjectName(QStringLiteral("neighboursbutton"));

        verticalLayout->addWidget(neighboursbutton);

        neighbourslist = new QListWidget(dockWidgetContents);
        neighbourslist->setObjectName(QStringLiteral("neighbourslist"));

        verticalLayout->addWidget(neighbourslist);

        KsirkCountryDefinition->setWidget(dockWidgetContents);

        retranslateUi(KsirkCountryDefinition);

        QMetaObject::connectSlotsByName(KsirkCountryDefinition);
    } // setupUi

    void retranslateUi(QDockWidget *KsirkCountryDefinition)
    {
        KsirkCountryDefinition->setWindowTitle(tr2i18n("Country", Q_NULLPTR));
        label->setText(tr2i18n("Flag:", Q_NULLPTR));
        label_2->setText(tr2i18n("x", Q_NULLPTR));
        label_3->setText(tr2i18n("Anchor:", Q_NULLPTR));
        label_4->setText(tr2i18n("x", Q_NULLPTR));
        label_5->setText(tr2i18n("Center:", Q_NULLPTR));
        label_6->setText(tr2i18n("x", Q_NULLPTR));
        label_7->setText(tr2i18n("Infantry:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        infantryx->setToolTip(tr2i18n("Infantry's sprite top left point x-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        infantryx->setWhatsThis(tr2i18n("Infantry's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the infantry.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        infantryx->setProperty("text", QVariant(QString()));
        label_8->setText(tr2i18n("x", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        infantryy->setToolTip(tr2i18n("Infantry's sprite top left point y-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        infantryy->setWhatsThis(tr2i18n("Infantry's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the infantry by drag and drop.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        infantryy->setProperty("text", QVariant(QString()));
        label_9->setText(tr2i18n("Cavalry:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cavalryx->setToolTip(tr2i18n("Cavalry's sprite top left point x-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cavalryx->setWhatsThis(tr2i18n("Cavalry's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cavalry.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        cavalryx->setProperty("text", QVariant(QString()));
        label_10->setText(tr2i18n("x", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cavalryy->setToolTip(tr2i18n("Cavalry's sprite top left point y-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cavalryy->setWhatsThis(tr2i18n("Cavalry's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cavalry by drag and drop.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        cavalryy->setProperty("text", QVariant(QString()));
        label_12->setText(tr2i18n("Cannon:", Q_NULLPTR));
        label_11->setText(tr2i18n("x", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        cannony->setToolTip(tr2i18n("Cannon's sprite top left point y-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cannony->setWhatsThis(tr2i18n("Cannon's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cannon by drag and drop.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        cannony->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        cannonx->setToolTip(tr2i18n("Cannon's sprite top left point x-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        cannonx->setWhatsThis(tr2i18n("Cannon's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the cannon.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        cannonx->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        centery->setToolTip(tr2i18n("Point around which the country name is drawn y-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        centery->setWhatsThis(tr2i18n("Point around which the country name is drawn y-coordinate.\n"
"\n"
"Note that this point should be located inside the limits of the country on the map mask.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the country name by dragging and dropping its target icon.\n"
"", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        centery->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        centerx->setToolTip(tr2i18n("Point around which the country name is drawn x-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        centerx->setWhatsThis(tr2i18n("Point around which the country name is drawn x-coordinate.\n"
"\n"
"Note that this point should be located inside the limits of the country on the map mask.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the country name by dragging and dropping its target icon.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        centerx->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        anchory->setToolTip(tr2i18n("Center of the highlighting y-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        anchory->setWhatsThis(tr2i18n("Center of the highlighting y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the highlighting by dragging and dropping its cross icon.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        anchory->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        anchorx->setToolTip(tr2i18n("Center of the highlighting x-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        anchorx->setWhatsThis(tr2i18n("Center of the highlighting x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the highlighting by dragging and dropping its cross icon.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        anchorx->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        flagy->setToolTip(tr2i18n("Flag's sprite top left point y-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        flagy->setWhatsThis(tr2i18n("Flag's sprite top left point y-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the flag by drag and drop.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        flagy->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        flagx->setToolTip(tr2i18n("Flag's sprite top left point x-coordinate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        flagx->setWhatsThis(tr2i18n("Flag's sprite top left point x-coordinate.\n"
"\n"
"This is given relatively to the top left of the map, sized as defined in the main skin definition widget.\n"
"\n"
"This value will be automatically updated if you move the flag by drag and drop.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        flagx->setProperty("text", QVariant(QString()));
#ifndef UI_QT_NO_TOOLTIP
        neighboursbutton->setToolTip(tr2i18n("Select this country's neighbors", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        neighboursbutton->setWhatsThis(tr2i18n("Click here to select this country's neighbors.\n"
"\n"
"A list of all the world's countries will be shown and you will be able to select the countries using the mouse and the Ctrl and Shift keys.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        neighboursbutton->setText(tr2i18n("Neighbors:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        neighbourslist->setToolTip(tr2i18n("This country's neighbors", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        neighbourslist->setWhatsThis(tr2i18n("This is the list of countries currently considered as neighbors of this country.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
    } // retranslateUi

};

namespace Ui {
    class KsirkCountryDefinition: public Ui_KsirkCountryDefinition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KSIRKCOUNTRYDEFINITION_H

