/****************************************************************************
** Meta object code from reading C++ file 'bsocket.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/cutestuff/bsocket.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bsocket.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BSocket_t {
    QByteArrayData data[14];
    char stringdata0[162];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BSocket_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BSocket_t qt_meta_stringdata_BSocket = {
    {
QT_MOC_LITERAL(0, 0, 7), // "BSocket"
QT_MOC_LITERAL(1, 8, 9), // "hostFound"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 9), // "connected"
QT_MOC_LITERAL(4, 29, 12), // "qs_hostFound"
QT_MOC_LITERAL(5, 42, 12), // "qs_connected"
QT_MOC_LITERAL(6, 55, 9), // "qs_closed"
QT_MOC_LITERAL(7, 65, 12), // "qs_readyRead"
QT_MOC_LITERAL(8, 78, 15), // "qs_bytesWritten"
QT_MOC_LITERAL(9, 94, 8), // "qs_error"
QT_MOC_LITERAL(10, 103, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(11, 132, 8), // "srv_done"
QT_MOC_LITERAL(12, 141, 9), // "ndns_done"
QT_MOC_LITERAL(13, 151, 10) // "do_connect"

    },
    "BSocket\0hostFound\0\0connected\0qs_hostFound\0"
    "qs_connected\0qs_closed\0qs_readyRead\0"
    "qs_bytesWritten\0qs_error\0"
    "QAbstractSocket::SocketError\0srv_done\0"
    "ndns_done\0do_connect"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BSocket[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    0,   70,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   71,    2, 0x08 /* Private */,
       5,    0,   72,    2, 0x08 /* Private */,
       6,    0,   73,    2, 0x08 /* Private */,
       7,    0,   74,    2, 0x08 /* Private */,
       8,    1,   75,    2, 0x08 /* Private */,
       9,    1,   78,    2, 0x08 /* Private */,
      11,    0,   81,    2, 0x08 /* Private */,
      12,    0,   82,    2, 0x08 /* Private */,
      13,    0,   83,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void BSocket::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BSocket *_t = static_cast<BSocket *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->hostFound(); break;
        case 1: _t->connected(); break;
        case 2: _t->qs_hostFound(); break;
        case 3: _t->qs_connected(); break;
        case 4: _t->qs_closed(); break;
        case 5: _t->qs_readyRead(); break;
        case 6: _t->qs_bytesWritten((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 7: _t->qs_error((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 8: _t->srv_done(); break;
        case 9: _t->ndns_done(); break;
        case 10: _t->do_connect(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (BSocket::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BSocket::hostFound)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (BSocket::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BSocket::connected)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject BSocket::staticMetaObject = {
    { &ByteStream::staticMetaObject, qt_meta_stringdata_BSocket.data,
      qt_meta_data_BSocket,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *BSocket::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BSocket::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BSocket.stringdata0))
        return static_cast<void*>(this);
    return ByteStream::qt_metacast(_clname);
}

int BSocket::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ByteStream::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void BSocket::hostFound()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BSocket::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
