/****************************************************************************
** Meta object code from reading C++ file 'jabberclient.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirk/Jabber/jabberclient.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jabberclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_JabberClient_t {
    QByteArrayData data[74];
    char stringdata0[1027];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_JabberClient_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_JabberClient_t qt_meta_stringdata_JabberClient = {
    {
QT_MOC_LITERAL(0, 0, 12), // "JabberClient"
QT_MOC_LITERAL(1, 13, 9), // "connected"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 15), // "csAuthenticated"
QT_MOC_LITERAL(4, 40, 7), // "csError"
QT_MOC_LITERAL(5, 48, 5), // "error"
QT_MOC_LITERAL(6, 54, 14), // "csDisconnected"
QT_MOC_LITERAL(7, 69, 10), // "tlsWarning"
QT_MOC_LITERAL(8, 80, 24), // "QCA::TLS::IdentityResult"
QT_MOC_LITERAL(9, 105, 13), // "QCA::Validity"
QT_MOC_LITERAL(10, 119, 20), // "incomingFileTransfer"
QT_MOC_LITERAL(11, 140, 23), // "JabberClient::ErrorCode"
QT_MOC_LITERAL(12, 164, 4), // "code"
QT_MOC_LITERAL(13, 169, 21), // "rosterRequestFinished"
QT_MOC_LITERAL(14, 191, 7), // "success"
QT_MOC_LITERAL(15, 199, 10), // "newContact"
QT_MOC_LITERAL(16, 210, 10), // "RosterItem"
QT_MOC_LITERAL(17, 221, 4), // "item"
QT_MOC_LITERAL(18, 226, 14), // "contactDeleted"
QT_MOC_LITERAL(19, 241, 14), // "contactUpdated"
QT_MOC_LITERAL(20, 256, 17), // "resourceAvailable"
QT_MOC_LITERAL(21, 274, 3), // "Jid"
QT_MOC_LITERAL(22, 278, 3), // "jid"
QT_MOC_LITERAL(23, 282, 8), // "Resource"
QT_MOC_LITERAL(24, 291, 8), // "resource"
QT_MOC_LITERAL(25, 300, 19), // "resourceUnavailable"
QT_MOC_LITERAL(26, 320, 15), // "messageReceived"
QT_MOC_LITERAL(27, 336, 13), // "XMPP::Message"
QT_MOC_LITERAL(28, 350, 7), // "message"
QT_MOC_LITERAL(29, 358, 15), // "groupChatJoined"
QT_MOC_LITERAL(30, 374, 9), // "XMPP::Jid"
QT_MOC_LITERAL(31, 384, 13), // "groupChatLeft"
QT_MOC_LITERAL(32, 398, 17), // "groupChatPresence"
QT_MOC_LITERAL(33, 416, 12), // "XMPP::Status"
QT_MOC_LITERAL(34, 429, 6), // "status"
QT_MOC_LITERAL(35, 436, 14), // "groupChatError"
QT_MOC_LITERAL(36, 451, 6), // "reason"
QT_MOC_LITERAL(37, 458, 12), // "subscription"
QT_MOC_LITERAL(38, 471, 4), // "type"
QT_MOC_LITERAL(39, 476, 12), // "debugMessage"
QT_MOC_LITERAL(40, 489, 11), // "incomingXML"
QT_MOC_LITERAL(41, 501, 3), // "msg"
QT_MOC_LITERAL(42, 505, 11), // "outgoingXML"
QT_MOC_LITERAL(43, 517, 17), // "slotS5BServerGone"
QT_MOC_LITERAL(44, 535, 21), // "slotUpdatePenaltyTime"
QT_MOC_LITERAL(45, 557, 20), // "slotCSNeedAuthParams"
QT_MOC_LITERAL(46, 578, 4), // "user"
QT_MOC_LITERAL(47, 583, 4), // "pass"
QT_MOC_LITERAL(48, 588, 5), // "realm"
QT_MOC_LITERAL(49, 594, 19), // "slotCSAuthenticated"
QT_MOC_LITERAL(50, 614, 18), // "slotCSDisconnected"
QT_MOC_LITERAL(51, 633, 13), // "slotCSWarning"
QT_MOC_LITERAL(52, 647, 11), // "slotCSError"
QT_MOC_LITERAL(53, 659, 17), // "slotTLSHandshaken"
QT_MOC_LITERAL(54, 677, 25), // "slotRosterRequestFinished"
QT_MOC_LITERAL(55, 703, 10), // "statusCode"
QT_MOC_LITERAL(56, 714, 12), // "statusString"
QT_MOC_LITERAL(57, 727, 24), // "slotIncomingFileTransfer"
QT_MOC_LITERAL(58, 752, 14), // "slotNewContact"
QT_MOC_LITERAL(59, 767, 18), // "slotContactDeleted"
QT_MOC_LITERAL(60, 786, 18), // "slotContactUpdated"
QT_MOC_LITERAL(61, 805, 21), // "slotResourceAvailable"
QT_MOC_LITERAL(62, 827, 23), // "slotResourceUnavailable"
QT_MOC_LITERAL(63, 851, 19), // "slotReceivedMessage"
QT_MOC_LITERAL(64, 871, 7), // "Message"
QT_MOC_LITERAL(65, 879, 12), // "slotPsiDebug"
QT_MOC_LITERAL(66, 892, 15), // "slotIncomingXML"
QT_MOC_LITERAL(67, 908, 15), // "slotOutgoingXML"
QT_MOC_LITERAL(68, 924, 19), // "slotGroupChatJoined"
QT_MOC_LITERAL(69, 944, 17), // "slotGroupChatLeft"
QT_MOC_LITERAL(70, 962, 21), // "slotGroupChatPresence"
QT_MOC_LITERAL(71, 984, 6), // "Status"
QT_MOC_LITERAL(72, 991, 18), // "slotGroupChatError"
QT_MOC_LITERAL(73, 1010, 16) // "slotSubscription"

    },
    "JabberClient\0connected\0\0csAuthenticated\0"
    "csError\0error\0csDisconnected\0tlsWarning\0"
    "QCA::TLS::IdentityResult\0QCA::Validity\0"
    "incomingFileTransfer\0JabberClient::ErrorCode\0"
    "code\0rosterRequestFinished\0success\0"
    "newContact\0RosterItem\0item\0contactDeleted\0"
    "contactUpdated\0resourceAvailable\0Jid\0"
    "jid\0Resource\0resource\0resourceUnavailable\0"
    "messageReceived\0XMPP::Message\0message\0"
    "groupChatJoined\0XMPP::Jid\0groupChatLeft\0"
    "groupChatPresence\0XMPP::Status\0status\0"
    "groupChatError\0reason\0subscription\0"
    "type\0debugMessage\0incomingXML\0msg\0"
    "outgoingXML\0slotS5BServerGone\0"
    "slotUpdatePenaltyTime\0slotCSNeedAuthParams\0"
    "user\0pass\0realm\0slotCSAuthenticated\0"
    "slotCSDisconnected\0slotCSWarning\0"
    "slotCSError\0slotTLSHandshaken\0"
    "slotRosterRequestFinished\0statusCode\0"
    "statusString\0slotIncomingFileTransfer\0"
    "slotNewContact\0slotContactDeleted\0"
    "slotContactUpdated\0slotResourceAvailable\0"
    "slotResourceUnavailable\0slotReceivedMessage\0"
    "Message\0slotPsiDebug\0slotIncomingXML\0"
    "slotOutgoingXML\0slotGroupChatJoined\0"
    "slotGroupChatLeft\0slotGroupChatPresence\0"
    "Status\0slotGroupChatError\0slotSubscription"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_JabberClient[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      46,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      22,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  244,    2, 0x06 /* Public */,
       3,    0,  245,    2, 0x06 /* Public */,
       4,    1,  246,    2, 0x06 /* Public */,
       6,    0,  249,    2, 0x06 /* Public */,
       7,    2,  250,    2, 0x06 /* Public */,
      10,    0,  255,    2, 0x06 /* Public */,
       5,    1,  256,    2, 0x06 /* Public */,
      13,    1,  259,    2, 0x06 /* Public */,
      15,    1,  262,    2, 0x06 /* Public */,
      18,    1,  265,    2, 0x06 /* Public */,
      19,    1,  268,    2, 0x06 /* Public */,
      20,    2,  271,    2, 0x06 /* Public */,
      25,    2,  276,    2, 0x06 /* Public */,
      26,    1,  281,    2, 0x06 /* Public */,
      29,    1,  284,    2, 0x06 /* Public */,
      31,    1,  287,    2, 0x06 /* Public */,
      32,    2,  290,    2, 0x06 /* Public */,
      35,    3,  295,    2, 0x06 /* Public */,
      37,    2,  302,    2, 0x06 /* Public */,
      39,    1,  307,    2, 0x06 /* Public */,
      40,    1,  310,    2, 0x06 /* Public */,
      42,    1,  313,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      43,    0,  316,    2, 0x08 /* Private */,
      44,    0,  317,    2, 0x08 /* Private */,
      45,    3,  318,    2, 0x08 /* Private */,
      49,    0,  325,    2, 0x08 /* Private */,
      50,    0,  326,    2, 0x08 /* Private */,
      51,    1,  327,    2, 0x08 /* Private */,
      52,    1,  330,    2, 0x08 /* Private */,
      53,    0,  333,    2, 0x08 /* Private */,
      54,    3,  334,    2, 0x08 /* Private */,
      57,    0,  341,    2, 0x08 /* Private */,
      58,    1,  342,    2, 0x08 /* Private */,
      59,    1,  345,    2, 0x08 /* Private */,
      60,    1,  348,    2, 0x08 /* Private */,
      61,    2,  351,    2, 0x08 /* Private */,
      62,    2,  356,    2, 0x08 /* Private */,
      63,    1,  361,    2, 0x08 /* Private */,
      65,    1,  364,    2, 0x08 /* Private */,
      66,    1,  367,    2, 0x08 /* Private */,
      67,    1,  370,    2, 0x08 /* Private */,
      68,    1,  373,    2, 0x08 /* Private */,
      69,    1,  376,    2, 0x08 /* Private */,
      70,    2,  379,    2, 0x08 /* Private */,
      72,    3,  384,    2, 0x08 /* Private */,
      73,    2,  391,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 9,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 23,   22,   24,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 23,   22,   24,
    QMetaType::Void, 0x80000000 | 27,   28,
    QMetaType::Void, 0x80000000 | 30,   22,
    QMetaType::Void, 0x80000000 | 30,   22,
    QMetaType::Void, 0x80000000 | 30, 0x80000000 | 33,   22,   34,
    QMetaType::Void, 0x80000000 | 30, QMetaType::Int, QMetaType::QString,   22,    5,   36,
    QMetaType::Void, 0x80000000 | 21, QMetaType::QString,   22,   38,
    QMetaType::Void, QMetaType::QString,   28,
    QMetaType::Void, QMetaType::QString,   41,
    QMetaType::Void, QMetaType::QString,   41,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,   46,   47,   48,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString,   14,   55,   56,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 23,    2,    2,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 23,    2,    2,
    QMetaType::Void, 0x80000000 | 64,    2,
    QMetaType::Void, QMetaType::QString,   41,
    QMetaType::Void, QMetaType::QString,   41,
    QMetaType::Void, QMetaType::QString,   41,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 71,   22,   34,
    QMetaType::Void, 0x80000000 | 21, QMetaType::Int, QMetaType::QString,   22,    5,   36,
    QMetaType::Void, 0x80000000 | 21, QMetaType::QString,   22,   38,

       0        // eod
};

void JabberClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JabberClient *_t = static_cast<JabberClient *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->csAuthenticated(); break;
        case 2: _t->csError((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->csDisconnected(); break;
        case 4: _t->tlsWarning((*reinterpret_cast< QCA::TLS::IdentityResult(*)>(_a[1])),(*reinterpret_cast< QCA::Validity(*)>(_a[2]))); break;
        case 5: _t->incomingFileTransfer(); break;
        case 6: _t->error((*reinterpret_cast< JabberClient::ErrorCode(*)>(_a[1]))); break;
        case 7: _t->rosterRequestFinished((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->newContact((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 9: _t->contactDeleted((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 10: _t->contactUpdated((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 11: _t->resourceAvailable((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Resource(*)>(_a[2]))); break;
        case 12: _t->resourceUnavailable((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Resource(*)>(_a[2]))); break;
        case 13: _t->messageReceived((*reinterpret_cast< const XMPP::Message(*)>(_a[1]))); break;
        case 14: _t->groupChatJoined((*reinterpret_cast< const XMPP::Jid(*)>(_a[1]))); break;
        case 15: _t->groupChatLeft((*reinterpret_cast< const XMPP::Jid(*)>(_a[1]))); break;
        case 16: _t->groupChatPresence((*reinterpret_cast< const XMPP::Jid(*)>(_a[1])),(*reinterpret_cast< const XMPP::Status(*)>(_a[2]))); break;
        case 17: _t->groupChatError((*reinterpret_cast< const XMPP::Jid(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 18: _t->subscription((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 19: _t->debugMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->incomingXML((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->outgoingXML((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->slotS5BServerGone(); break;
        case 23: _t->slotUpdatePenaltyTime(); break;
        case 24: _t->slotCSNeedAuthParams((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 25: _t->slotCSAuthenticated(); break;
        case 26: _t->slotCSDisconnected(); break;
        case 27: _t->slotCSWarning((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 28: _t->slotCSError((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->slotTLSHandshaken(); break;
        case 30: _t->slotRosterRequestFinished((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 31: _t->slotIncomingFileTransfer(); break;
        case 32: _t->slotNewContact((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 33: _t->slotContactDeleted((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 34: _t->slotContactUpdated((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 35: _t->slotResourceAvailable((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Resource(*)>(_a[2]))); break;
        case 36: _t->slotResourceUnavailable((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Resource(*)>(_a[2]))); break;
        case 37: _t->slotReceivedMessage((*reinterpret_cast< const Message(*)>(_a[1]))); break;
        case 38: _t->slotPsiDebug((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 39: _t->slotIncomingXML((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 40: _t->slotOutgoingXML((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 41: _t->slotGroupChatJoined((*reinterpret_cast< const Jid(*)>(_a[1]))); break;
        case 42: _t->slotGroupChatLeft((*reinterpret_cast< const Jid(*)>(_a[1]))); break;
        case 43: _t->slotGroupChatPresence((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Status(*)>(_a[2]))); break;
        case 44: _t->slotGroupChatError((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 45: _t->slotSubscription((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JabberClient::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::connected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::csAuthenticated)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::csError)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::csDisconnected)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(QCA::TLS::IdentityResult , QCA::Validity );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::tlsWarning)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::incomingFileTransfer)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(JabberClient::ErrorCode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::error)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::rosterRequestFinished)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const RosterItem & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::newContact)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const RosterItem & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::contactDeleted)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const RosterItem & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::contactUpdated)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const Jid & , const Resource & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::resourceAvailable)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const Jid & , const Resource & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::resourceUnavailable)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const XMPP::Message & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::messageReceived)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const XMPP::Jid & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::groupChatJoined)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const XMPP::Jid & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::groupChatLeft)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const XMPP::Jid & , const XMPP::Status & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::groupChatPresence)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const XMPP::Jid & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::groupChatError)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const Jid & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::subscription)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::debugMessage)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::incomingXML)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (JabberClient::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JabberClient::outgoingXML)) {
                *result = 21;
                return;
            }
        }
    }
}

const QMetaObject JabberClient::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_JabberClient.data,
      qt_meta_data_JabberClient,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *JabberClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JabberClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_JabberClient.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int JabberClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 46;
    }
    return _id;
}

// SIGNAL 0
void JabberClient::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void JabberClient::csAuthenticated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void JabberClient::csError(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void JabberClient::csDisconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void JabberClient::tlsWarning(QCA::TLS::IdentityResult _t1, QCA::Validity _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void JabberClient::incomingFileTransfer()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void JabberClient::error(JabberClient::ErrorCode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void JabberClient::rosterRequestFinished(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void JabberClient::newContact(const RosterItem & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void JabberClient::contactDeleted(const RosterItem & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void JabberClient::contactUpdated(const RosterItem & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void JabberClient::resourceAvailable(const Jid & _t1, const Resource & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void JabberClient::resourceUnavailable(const Jid & _t1, const Resource & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void JabberClient::messageReceived(const XMPP::Message & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void JabberClient::groupChatJoined(const XMPP::Jid & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void JabberClient::groupChatLeft(const XMPP::Jid & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void JabberClient::groupChatPresence(const XMPP::Jid & _t1, const XMPP::Status & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void JabberClient::groupChatError(const XMPP::Jid & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void JabberClient::subscription(const Jid & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void JabberClient::debugMessage(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void JabberClient::incomingXML(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void JabberClient::outgoingXML(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
