/****************************************************************************
** Meta object code from reading C++ file 'xmpp_client.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/ksirk-17.12.3/ksirk/iris/src/xmpp/xmpp-im/xmpp_client.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xmpp_client.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__Client_t {
    QByteArrayData data[38];
    char stringdata0[522];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__Client_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__Client_t qt_meta_stringdata_XMPP__Client = {
    {
QT_MOC_LITERAL(0, 0, 12), // "XMPP::Client"
QT_MOC_LITERAL(1, 13, 9), // "activated"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 12), // "disconnected"
QT_MOC_LITERAL(4, 37, 21), // "rosterRequestFinished"
QT_MOC_LITERAL(5, 59, 15), // "rosterItemAdded"
QT_MOC_LITERAL(6, 75, 10), // "RosterItem"
QT_MOC_LITERAL(7, 86, 17), // "rosterItemUpdated"
QT_MOC_LITERAL(8, 104, 17), // "rosterItemRemoved"
QT_MOC_LITERAL(9, 122, 17), // "resourceAvailable"
QT_MOC_LITERAL(10, 140, 3), // "Jid"
QT_MOC_LITERAL(11, 144, 8), // "Resource"
QT_MOC_LITERAL(12, 153, 19), // "resourceUnavailable"
QT_MOC_LITERAL(13, 173, 13), // "presenceError"
QT_MOC_LITERAL(14, 187, 12), // "subscription"
QT_MOC_LITERAL(15, 200, 15), // "messageReceived"
QT_MOC_LITERAL(16, 216, 7), // "Message"
QT_MOC_LITERAL(17, 224, 9), // "debugText"
QT_MOC_LITERAL(18, 234, 11), // "xmlIncoming"
QT_MOC_LITERAL(19, 246, 11), // "xmlOutgoing"
QT_MOC_LITERAL(20, 258, 15), // "groupChatJoined"
QT_MOC_LITERAL(21, 274, 13), // "groupChatLeft"
QT_MOC_LITERAL(22, 288, 17), // "groupChatPresence"
QT_MOC_LITERAL(23, 306, 6), // "Status"
QT_MOC_LITERAL(24, 313, 14), // "groupChatError"
QT_MOC_LITERAL(25, 328, 15), // "incomingJidLink"
QT_MOC_LITERAL(26, 344, 11), // "streamError"
QT_MOC_LITERAL(27, 356, 15), // "streamReadyRead"
QT_MOC_LITERAL(28, 372, 17), // "streamIncomingXml"
QT_MOC_LITERAL(29, 390, 17), // "streamOutgoingXml"
QT_MOC_LITERAL(30, 408, 25), // "slotRosterRequestFinished"
QT_MOC_LITERAL(31, 434, 14), // "ppSubscription"
QT_MOC_LITERAL(32, 449, 10), // "ppPresence"
QT_MOC_LITERAL(33, 460, 9), // "pmMessage"
QT_MOC_LITERAL(34, 470, 8), // "prRoster"
QT_MOC_LITERAL(35, 479, 6), // "Roster"
QT_MOC_LITERAL(36, 486, 17), // "s5b_incomingReady"
QT_MOC_LITERAL(37, 504, 17) // "ibb_incomingReady"

    },
    "XMPP::Client\0activated\0\0disconnected\0"
    "rosterRequestFinished\0rosterItemAdded\0"
    "RosterItem\0rosterItemUpdated\0"
    "rosterItemRemoved\0resourceAvailable\0"
    "Jid\0Resource\0resourceUnavailable\0"
    "presenceError\0subscription\0messageReceived\0"
    "Message\0debugText\0xmlIncoming\0xmlOutgoing\0"
    "groupChatJoined\0groupChatLeft\0"
    "groupChatPresence\0Status\0groupChatError\0"
    "incomingJidLink\0streamError\0streamReadyRead\0"
    "streamIncomingXml\0streamOutgoingXml\0"
    "slotRosterRequestFinished\0ppSubscription\0"
    "ppPresence\0pmMessage\0prRoster\0Roster\0"
    "s5b_incomingReady\0ibb_incomingReady"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__Client[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      19,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  164,    2, 0x06 /* Public */,
       3,    0,  165,    2, 0x06 /* Public */,
       4,    3,  166,    2, 0x06 /* Public */,
       5,    1,  173,    2, 0x06 /* Public */,
       7,    1,  176,    2, 0x06 /* Public */,
       8,    1,  179,    2, 0x06 /* Public */,
       9,    2,  182,    2, 0x06 /* Public */,
      12,    2,  187,    2, 0x06 /* Public */,
      13,    3,  192,    2, 0x06 /* Public */,
      14,    3,  199,    2, 0x06 /* Public */,
      15,    1,  206,    2, 0x06 /* Public */,
      17,    1,  209,    2, 0x06 /* Public */,
      18,    1,  212,    2, 0x06 /* Public */,
      19,    1,  215,    2, 0x06 /* Public */,
      20,    1,  218,    2, 0x06 /* Public */,
      21,    1,  221,    2, 0x06 /* Public */,
      22,    2,  224,    2, 0x06 /* Public */,
      24,    3,  229,    2, 0x06 /* Public */,
      25,    0,  236,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      26,    1,  237,    2, 0x08 /* Private */,
      27,    0,  240,    2, 0x08 /* Private */,
      28,    1,  241,    2, 0x08 /* Private */,
      29,    1,  244,    2, 0x08 /* Private */,
      30,    0,  247,    2, 0x08 /* Private */,
      31,    3,  248,    2, 0x08 /* Private */,
      32,    2,  255,    2, 0x08 /* Private */,
      33,    1,  260,    2, 0x08 /* Private */,
      34,    1,  263,    2, 0x08 /* Private */,
      36,    0,  266,    2, 0x08 /* Private */,
      37,    0,  267,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 11,    2,    2,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 11,    2,    2,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 23,    2,    2,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int, QMetaType::QString,    2,    2,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 23,    2,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 35,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void XMPP::Client::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Client *_t = static_cast<Client *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->activated(); break;
        case 1: _t->disconnected(); break;
        case 2: _t->rosterRequestFinished((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 3: _t->rosterItemAdded((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 4: _t->rosterItemUpdated((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 5: _t->rosterItemRemoved((*reinterpret_cast< const RosterItem(*)>(_a[1]))); break;
        case 6: _t->resourceAvailable((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Resource(*)>(_a[2]))); break;
        case 7: _t->resourceUnavailable((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Resource(*)>(_a[2]))); break;
        case 8: _t->presenceError((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 9: _t->subscription((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 10: _t->messageReceived((*reinterpret_cast< const Message(*)>(_a[1]))); break;
        case 11: _t->debugText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->xmlIncoming((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->xmlOutgoing((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->groupChatJoined((*reinterpret_cast< const Jid(*)>(_a[1]))); break;
        case 15: _t->groupChatLeft((*reinterpret_cast< const Jid(*)>(_a[1]))); break;
        case 16: _t->groupChatPresence((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Status(*)>(_a[2]))); break;
        case 17: _t->groupChatError((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 18: _t->incomingJidLink(); break;
        case 19: _t->streamError((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->streamReadyRead(); break;
        case 21: _t->streamIncomingXml((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->streamOutgoingXml((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: _t->slotRosterRequestFinished(); break;
        case 24: _t->ppSubscription((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 25: _t->ppPresence((*reinterpret_cast< const Jid(*)>(_a[1])),(*reinterpret_cast< const Status(*)>(_a[2]))); break;
        case 26: _t->pmMessage((*reinterpret_cast< const Message(*)>(_a[1]))); break;
        case 27: _t->prRoster((*reinterpret_cast< const Roster(*)>(_a[1]))); break;
        case 28: _t->s5b_incomingReady(); break;
        case 29: _t->ibb_incomingReady(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Client::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::activated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Client::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::disconnected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Client::*_t)(bool , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::rosterRequestFinished)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const RosterItem & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::rosterItemAdded)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const RosterItem & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::rosterItemUpdated)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const RosterItem & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::rosterItemRemoved)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & , const Resource & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::resourceAvailable)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & , const Resource & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::resourceUnavailable)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::presenceError)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::subscription)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Message & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::messageReceived)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::debugText)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::xmlIncoming)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::xmlOutgoing)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::groupChatJoined)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::groupChatLeft)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & , const Status & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::groupChatPresence)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (Client::*_t)(const Jid & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::groupChatError)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (Client::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::incomingJidLink)) {
                *result = 18;
                return;
            }
        }
    }
}

const QMetaObject XMPP::Client::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__Client.data,
      qt_meta_data_XMPP__Client,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::Client::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::Client::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__Client.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::Client::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void XMPP::Client::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XMPP::Client::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XMPP::Client::rosterRequestFinished(bool _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void XMPP::Client::rosterItemAdded(const RosterItem & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void XMPP::Client::rosterItemUpdated(const RosterItem & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void XMPP::Client::rosterItemRemoved(const RosterItem & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void XMPP::Client::resourceAvailable(const Jid & _t1, const Resource & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void XMPP::Client::resourceUnavailable(const Jid & _t1, const Resource & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void XMPP::Client::presenceError(const Jid & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void XMPP::Client::subscription(const Jid & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void XMPP::Client::messageReceived(const Message & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void XMPP::Client::debugText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void XMPP::Client::xmlIncoming(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void XMPP::Client::xmlOutgoing(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void XMPP::Client::groupChatJoined(const Jid & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void XMPP::Client::groupChatLeft(const Jid & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void XMPP::Client::groupChatPresence(const Jid & _t1, const Status & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void XMPP::Client::groupChatError(const Jid & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void XMPP::Client::incomingJidLink()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
