#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'jabbergameui.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JABBERGAMEUI_H
#define UI_JABBERGAMEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kled.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_KsirkJabberGameWidget
{
public:
    QGridLayout *gridLayout;
    QStackedWidget *stackedWidget;
    QWidget *jabberconnectpage;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_7;
    QGridLayout *gridLayout_4;
    QLabel *label;
    KLineEdit *jabberid;
    KLineEdit *password;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_5;
    QPushButton *connectbutton;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_8;
    KLed *jabberstateled;
    QSpacerItem *verticalSpacer_4;
    QWidget *chatroomconnectpage;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_9;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    KLineEdit *roomjid;
    QLabel *label_4;
    KLineEdit *nickname;
    QLabel *label_5;
    KLineEdit *roompassword;
    QPushButton *joinroombutton;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_10;
    KLed *chatroomstateled;
    QLabel *label_6;
    QHBoxLayout *horizontalLayout;
    QTableWidget *jabberTable;
    QVBoxLayout *verticalLayout;
    QPushButton *startnewgamebutton;
    QPushButton *joingamebutton;
    QPushButton *loadsavedgamebutton;
    QSpacerItem *verticalSpacer;
    QLabel *label_11;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *cancelbutton;

    void setupUi(QWidget *KsirkJabberGameWidget)
    {
        if (KsirkJabberGameWidget->objectName().isEmpty())
            KsirkJabberGameWidget->setObjectName(QStringLiteral("KsirkJabberGameWidget"));
        KsirkJabberGameWidget->resize(615, 547);
        gridLayout = new QGridLayout(KsirkJabberGameWidget);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        stackedWidget = new QStackedWidget(KsirkJabberGameWidget);
        stackedWidget->setObjectName(QStringLiteral("stackedWidget"));
        jabberconnectpage = new QWidget();
        jabberconnectpage->setObjectName(QStringLiteral("jabberconnectpage"));
        verticalLayout_3 = new QVBoxLayout(jabberconnectpage);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        label_7 = new QLabel(jabberconnectpage);
        label_7->setObjectName(QStringLiteral("label_7"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label_7->setFont(font);

        verticalLayout_3->addWidget(label_7);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        label = new QLabel(jabberconnectpage);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_4->addWidget(label, 0, 0, 1, 1);

        jabberid = new KLineEdit(jabberconnectpage);
        jabberid->setObjectName(QStringLiteral("jabberid"));

        gridLayout_4->addWidget(jabberid, 0, 2, 2, 1);

        password = new KLineEdit(jabberconnectpage);
        password->setObjectName(QStringLiteral("password"));
        password->setEchoMode(QLineEdit::Password);

        gridLayout_4->addWidget(password, 1, 2, 2, 1);

        label_2 = new QLabel(jabberconnectpage);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout_4->addWidget(label_2, 2, 0, 1, 1);


        verticalLayout_3->addLayout(gridLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        connectbutton = new QPushButton(jabberconnectpage);
        connectbutton->setObjectName(QStringLiteral("connectbutton"));

        horizontalLayout_5->addWidget(connectbutton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        label_8 = new QLabel(jabberconnectpage);
        label_8->setObjectName(QStringLiteral("label_8"));

        horizontalLayout_4->addWidget(label_8);

        jabberstateled = new KLed(jabberconnectpage);
        jabberstateled->setObjectName(QStringLiteral("jabberstateled"));
        jabberstateled->setLayoutDirection(Qt::LeftToRight);

        horizontalLayout_4->addWidget(jabberstateled);


        horizontalLayout_5->addLayout(horizontalLayout_4);


        verticalLayout_3->addLayout(horizontalLayout_5);

        verticalSpacer_4 = new QSpacerItem(20, 143, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_4);

        stackedWidget->addWidget(jabberconnectpage);
        chatroomconnectpage = new QWidget();
        chatroomconnectpage->setObjectName(QStringLiteral("chatroomconnectpage"));
        verticalLayout_2 = new QVBoxLayout(chatroomconnectpage);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        label_9 = new QLabel(chatroomconnectpage);
        label_9->setObjectName(QStringLiteral("label_9"));
        label_9->setFont(font);

        verticalLayout_2->addWidget(label_9);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        label_3 = new QLabel(chatroomconnectpage);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout_2->addWidget(label_3, 1, 0, 1, 1);

        roomjid = new KLineEdit(chatroomconnectpage);
        roomjid->setObjectName(QStringLiteral("roomjid"));

        gridLayout_2->addWidget(roomjid, 1, 1, 1, 1);

        label_4 = new QLabel(chatroomconnectpage);
        label_4->setObjectName(QStringLiteral("label_4"));

        gridLayout_2->addWidget(label_4, 2, 0, 1, 1);

        nickname = new KLineEdit(chatroomconnectpage);
        nickname->setObjectName(QStringLiteral("nickname"));

        gridLayout_2->addWidget(nickname, 2, 1, 1, 1);

        label_5 = new QLabel(chatroomconnectpage);
        label_5->setObjectName(QStringLiteral("label_5"));

        gridLayout_2->addWidget(label_5, 1, 2, 1, 1);

        roompassword = new KLineEdit(chatroomconnectpage);
        roompassword->setObjectName(QStringLiteral("roompassword"));
        roompassword->setEchoMode(QLineEdit::Password);

        gridLayout_2->addWidget(roompassword, 1, 3, 1, 1);

        joinroombutton = new QPushButton(chatroomconnectpage);
        joinroombutton->setObjectName(QStringLiteral("joinroombutton"));

        gridLayout_2->addWidget(joinroombutton, 2, 2, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        label_10 = new QLabel(chatroomconnectpage);
        label_10->setObjectName(QStringLiteral("label_10"));

        horizontalLayout_3->addWidget(label_10);

        chatroomstateled = new KLed(chatroomconnectpage);
        chatroomstateled->setObjectName(QStringLiteral("chatroomstateled"));

        horizontalLayout_3->addWidget(chatroomstateled);


        gridLayout_2->addLayout(horizontalLayout_3, 2, 3, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        label_6 = new QLabel(chatroomconnectpage);
        label_6->setObjectName(QStringLiteral("label_6"));
        label_6->setFont(font);

        verticalLayout_2->addWidget(label_6);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        jabberTable = new QTableWidget(chatroomconnectpage);
        if (jabberTable->columnCount() < 3)
            jabberTable->setColumnCount(3);
        jabberTable->setObjectName(QStringLiteral("jabberTable"));
        jabberTable->setAlternatingRowColors(true);
        jabberTable->setSelectionMode(QAbstractItemView::SingleSelection);
        jabberTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        jabberTable->setSortingEnabled(true);
        jabberTable->setColumnCount(3);

        horizontalLayout->addWidget(jabberTable);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        startnewgamebutton = new QPushButton(chatroomconnectpage);
        startnewgamebutton->setObjectName(QStringLiteral("startnewgamebutton"));
        startnewgamebutton->setEnabled(false);

        verticalLayout->addWidget(startnewgamebutton);

        joingamebutton = new QPushButton(chatroomconnectpage);
        joingamebutton->setObjectName(QStringLiteral("joingamebutton"));
        joingamebutton->setEnabled(false);

        verticalLayout->addWidget(joingamebutton);

        loadsavedgamebutton = new QPushButton(chatroomconnectpage);
        loadsavedgamebutton->setObjectName(QStringLiteral("loadsavedgamebutton"));
        loadsavedgamebutton->setEnabled(false);

        verticalLayout->addWidget(loadsavedgamebutton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        stackedWidget->addWidget(chatroomconnectpage);

        gridLayout->addWidget(stackedWidget, 0, 0, 1, 1);

        label_11 = new QLabel(KsirkJabberGameWidget);
        label_11->setObjectName(QStringLiteral("label_11"));
        label_11->setWordWrap(true);

        gridLayout->addWidget(label_11, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        cancelbutton = new QPushButton(KsirkJabberGameWidget);
        cancelbutton->setObjectName(QStringLiteral("cancelbutton"));

        horizontalLayout_2->addWidget(cancelbutton);


        gridLayout->addLayout(horizontalLayout_2, 2, 0, 1, 1);


        retranslateUi(KsirkJabberGameWidget);

        stackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(KsirkJabberGameWidget);
    } // setupUi

    void retranslateUi(QWidget *KsirkJabberGameWidget)
    {
        label_7->setText(tr2i18n("Connection to the Jabber Network", Q_NULLPTR));
        label->setText(tr2i18n("Jabber ID:", Q_NULLPTR));
        jabberid->setText(tr2i18n("kleag@kdetalk.net", Q_NULLPTR));
        password->setText(tr2i18n("12345678", Q_NULLPTR));
        label_2->setText(tr2i18n("Password:", Q_NULLPTR));
        connectbutton->setText(tr2i18n("Connect", Q_NULLPTR));
        label_8->setText(tr2i18n("State:", Q_NULLPTR));
        label_9->setText(tr2i18n("Joining a KsirK Jabber Chatroom", Q_NULLPTR));
        label_3->setText(tr2i18n("Room JID:", Q_NULLPTR));
        label_4->setText(tr2i18n("Nickname:", Q_NULLPTR));
        label_5->setText(tr2i18n("Room Password:", Q_NULLPTR));
        joinroombutton->setText(tr2i18n("Join Room", Q_NULLPTR));
        label_10->setText(tr2i18n("State:", Q_NULLPTR));
        label_6->setText(tr2i18n("Games in the Room", Q_NULLPTR));
        startnewgamebutton->setText(tr2i18n("Start a New Game", Q_NULLPTR));
        joingamebutton->setText(tr2i18n("Join Selected Game", Q_NULLPTR));
        loadsavedgamebutton->setText(tr2i18n("Load a Saved Game", Q_NULLPTR));
        label_11->setText(tr2i18n("<b>Note:</b> Playing over the Jabber network is an experimental feature in KsirK.<br/>Particularly, the distribution of armies at game beginning is very slow (expect something like one minute).", Q_NULLPTR));
        cancelbutton->setText(tr2i18n("Cancel", Q_NULLPTR));
        Q_UNUSED(KsirkJabberGameWidget);
    } // retranslateUi

};

namespace Ui {
    class KsirkJabberGameWidget: public Ui_KsirkJabberGameWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JABBERGAMEUI_H

