#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'newGameSummary.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWGAMESUMMARY_H
#define UI_NEWGAMESUMMARY_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NewGameSummary
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QLabel *skinNameLabel;
    QSpacerItem *horizontalSpacer_2;
    QLabel *skinSnapshotPixmap;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_5;
    QLabel *goalTypeLabel;
    QTableWidget *playersTable;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *previousButton;
    QPushButton *finishButton;

    void setupUi(QWidget *NewGameSummary)
    {
        if (NewGameSummary->objectName().isEmpty())
            NewGameSummary->setObjectName(QStringLiteral("NewGameSummary"));
        NewGameSummary->resize(463, 432);
        verticalLayout_2 = new QVBoxLayout(NewGameSummary);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        label = new QLabel(NewGameSummary);
        label->setObjectName(QStringLiteral("label"));
        QFont font;
        font.setPointSize(14);
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);

        verticalLayout_2->addWidget(label);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label_3 = new QLabel(NewGameSummary);
        label_3->setObjectName(QStringLiteral("label_3"));
        QFont font1;
        font1.setBold(true);
        font1.setWeight(75);
        label_3->setFont(font1);

        horizontalLayout->addWidget(label_3);

        skinNameLabel = new QLabel(NewGameSummary);
        skinNameLabel->setObjectName(QStringLiteral("skinNameLabel"));

        horizontalLayout->addWidget(skinNameLabel);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        skinSnapshotPixmap = new QLabel(NewGameSummary);
        skinSnapshotPixmap->setObjectName(QStringLiteral("skinSnapshotPixmap"));
        QSizePolicy sizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skinSnapshotPixmap->sizePolicy().hasHeightForWidth());
        skinSnapshotPixmap->setSizePolicy(sizePolicy);
        skinSnapshotPixmap->setScaledContents(true);
        skinSnapshotPixmap->setWordWrap(false);

        verticalLayout->addWidget(skinSnapshotPixmap);

        verticalLayout->setStretch(1, 1);

        verticalLayout_2->addLayout(verticalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        label_2 = new QLabel(NewGameSummary);
        label_2->setObjectName(QStringLiteral("label_2"));
        label_2->setFont(font1);

        horizontalLayout_2->addWidget(label_2);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        label_5 = new QLabel(NewGameSummary);
        label_5->setObjectName(QStringLiteral("label_5"));
        label_5->setFont(font1);

        horizontalLayout_2->addWidget(label_5);

        goalTypeLabel = new QLabel(NewGameSummary);
        goalTypeLabel->setObjectName(QStringLiteral("goalTypeLabel"));

        horizontalLayout_2->addWidget(goalTypeLabel);


        verticalLayout_2->addLayout(horizontalLayout_2);

        playersTable = new QTableWidget(NewGameSummary);
        if (playersTable->columnCount() < 4)
            playersTable->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setFont(font1);
        playersTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        __qtablewidgetitem1->setFont(font1);
        playersTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        __qtablewidgetitem2->setFont(font1);
        playersTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        __qtablewidgetitem3->setFont(font1);
        playersTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        playersTable->setObjectName(QStringLiteral("playersTable"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(playersTable->sizePolicy().hasHeightForWidth());
        playersTable->setSizePolicy(sizePolicy1);
        playersTable->horizontalHeader()->setCascadingSectionResizes(false);
        playersTable->verticalHeader()->setStretchLastSection(false);

        verticalLayout_2->addWidget(playersTable);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        cancelButton = new QPushButton(NewGameSummary);
        cancelButton->setObjectName(QStringLiteral("cancelButton"));

        horizontalLayout_3->addWidget(cancelButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        previousButton = new QPushButton(NewGameSummary);
        previousButton->setObjectName(QStringLiteral("previousButton"));

        horizontalLayout_3->addWidget(previousButton);

        finishButton = new QPushButton(NewGameSummary);
        finishButton->setObjectName(QStringLiteral("finishButton"));

        horizontalLayout_3->addWidget(finishButton);


        verticalLayout_2->addLayout(horizontalLayout_3);

        QWidget::setTabOrder(finishButton, previousButton);
        QWidget::setTabOrder(previousButton, cancelButton);
        QWidget::setTabOrder(cancelButton, playersTable);

        retranslateUi(NewGameSummary);

        QMetaObject::connectSlotsByName(NewGameSummary);
    } // setupUi

    void retranslateUi(QWidget *NewGameSummary)
    {
        NewGameSummary->setWindowTitle(tr2i18n("New Game Summary", Q_NULLPTR));
        label->setText(tr2i18n("New Game Summary", Q_NULLPTR));
        label_3->setText(tr2i18n("Skin:", Q_NULLPTR));
        skinNameLabel->setText(tr2i18n("skin name", Q_NULLPTR));
        skinSnapshotPixmap->setText(QString());
        label_2->setText(tr2i18n("Players", Q_NULLPTR));
        label_5->setText(tr2i18n("Goal type:", Q_NULLPTR));
        goalTypeLabel->setText(tr2i18n("goal type", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem = playersTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Name", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem1 = playersTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Nationality", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem2 = playersTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Computer", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem3 = playersTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Network", Q_NULLPTR));
        cancelButton->setText(tr2i18n("Cancel", Q_NULLPTR));
        previousButton->setText(tr2i18n("<< Previous", Q_NULLPTR));
        finishButton->setText(tr2i18n("Start", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class NewGameSummary: public Ui_NewGameSummary {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWGAMESUMMARY_H

