/****************************************************************************
** Meta object code from reading C++ file 'kplayersetupwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksirk-17.12.3/ksirk/Dialogs/kplayersetupwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kplayersetupwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Ksirk__KPlayerSetupWidget_t {
    QByteArrayData data[14];
    char stringdata0[156];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Ksirk__KPlayerSetupWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Ksirk__KPlayerSetupWidget_t qt_meta_stringdata_Ksirk__KPlayerSetupWidget = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Ksirk::KPlayerSetupWidget"
QT_MOC_LITERAL(1, 26, 4), // "next"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 8), // "previous"
QT_MOC_LITERAL(4, 41, 6), // "cancel"
QT_MOC_LITERAL(5, 48, 8), // "slotNext"
QT_MOC_LITERAL(6, 57, 12), // "slotPrevious"
QT_MOC_LITERAL(7, 70, 10), // "slotCancel"
QT_MOC_LITERAL(8, 81, 20), // "slotPlayerJoinedGame"
QT_MOC_LITERAL(9, 102, 8), // "KPlayer*"
QT_MOC_LITERAL(10, 111, 6), // "player"
QT_MOC_LITERAL(11, 118, 17), // "slotNationChanged"
QT_MOC_LITERAL(12, 136, 14), // "slotNameEdited"
QT_MOC_LITERAL(13, 151, 4) // "text"

    },
    "Ksirk::KPlayerSetupWidget\0next\0\0"
    "previous\0cancel\0slotNext\0slotPrevious\0"
    "slotCancel\0slotPlayerJoinedGame\0"
    "KPlayer*\0player\0slotNationChanged\0"
    "slotNameEdited\0text"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Ksirk__KPlayerSetupWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   62,    2, 0x0a /* Public */,
       6,    0,   63,    2, 0x0a /* Public */,
       7,    0,   64,    2, 0x0a /* Public */,
       8,    1,   65,    2, 0x0a /* Public */,
      11,    0,   68,    2, 0x0a /* Public */,
      12,    1,   69,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   13,

       0        // eod
};

void Ksirk::KPlayerSetupWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KPlayerSetupWidget *_t = static_cast<KPlayerSetupWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->next(); break;
        case 1: _t->previous(); break;
        case 2: _t->cancel(); break;
        case 3: _t->slotNext(); break;
        case 4: _t->slotPrevious(); break;
        case 5: _t->slotCancel(); break;
        case 6: _t->slotPlayerJoinedGame((*reinterpret_cast< KPlayer*(*)>(_a[1]))); break;
        case 7: _t->slotNationChanged(); break;
        case 8: _t->slotNameEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KPlayerSetupWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KPlayerSetupWidget::next)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KPlayerSetupWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KPlayerSetupWidget::previous)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KPlayerSetupWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KPlayerSetupWidget::cancel)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Ksirk::KPlayerSetupWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Ksirk__KPlayerSetupWidget.data,
      qt_meta_data_Ksirk__KPlayerSetupWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Ksirk::KPlayerSetupWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ksirk::KPlayerSetupWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Ksirk__KPlayerSetupWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::QPlayerSetupWidget"))
        return static_cast< Ui::QPlayerSetupWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int Ksirk::KPlayerSetupWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Ksirk::KPlayerSetupWidget::next()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Ksirk::KPlayerSetupWidget::previous()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ksirk::KPlayerSetupWidget::cancel()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
