/****************************************************************************
** Meta object code from reading C++ file 'irisnetplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/ksirk-17.12.3/ksirk/iris/src/irisnet/corelib/irisnetplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'irisnetplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XMPP__IrisNetProvider_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__IrisNetProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__IrisNetProvider_t qt_meta_stringdata_XMPP__IrisNetProvider = {
    {
QT_MOC_LITERAL(0, 0, 21) // "XMPP::IrisNetProvider"

    },
    "XMPP::IrisNetProvider"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__IrisNetProvider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XMPP::IrisNetProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XMPP::IrisNetProvider::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__IrisNetProvider.data,
      qt_meta_data_XMPP__IrisNetProvider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::IrisNetProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::IrisNetProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__IrisNetProvider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::IrisNetProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_XMPP__NetInterfaceProvider_t {
    QByteArrayData data[3];
    char stringdata0[36];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__NetInterfaceProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__NetInterfaceProvider_t qt_meta_stringdata_XMPP__NetInterfaceProvider = {
    {
QT_MOC_LITERAL(0, 0, 26), // "XMPP::NetInterfaceProvider"
QT_MOC_LITERAL(1, 27, 7), // "updated"
QT_MOC_LITERAL(2, 35, 0) // ""

    },
    "XMPP::NetInterfaceProvider\0updated\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__NetInterfaceProvider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void XMPP::NetInterfaceProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NetInterfaceProvider *_t = static_cast<NetInterfaceProvider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (NetInterfaceProvider::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetInterfaceProvider::updated)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject XMPP::NetInterfaceProvider::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__NetInterfaceProvider.data,
      qt_meta_data_XMPP__NetInterfaceProvider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::NetInterfaceProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::NetInterfaceProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__NetInterfaceProvider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::NetInterfaceProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void XMPP::NetInterfaceProvider::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_XMPP__NetAvailabilityProvider_t {
    QByteArrayData data[3];
    char stringdata0[39];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__NetAvailabilityProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__NetAvailabilityProvider_t qt_meta_stringdata_XMPP__NetAvailabilityProvider = {
    {
QT_MOC_LITERAL(0, 0, 29), // "XMPP::NetAvailabilityProvider"
QT_MOC_LITERAL(1, 30, 7), // "updated"
QT_MOC_LITERAL(2, 38, 0) // ""

    },
    "XMPP::NetAvailabilityProvider\0updated\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__NetAvailabilityProvider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void XMPP::NetAvailabilityProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NetAvailabilityProvider *_t = static_cast<NetAvailabilityProvider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (NetAvailabilityProvider::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetAvailabilityProvider::updated)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject XMPP::NetAvailabilityProvider::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__NetAvailabilityProvider.data,
      qt_meta_data_XMPP__NetAvailabilityProvider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::NetAvailabilityProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::NetAvailabilityProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__NetAvailabilityProvider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::NetAvailabilityProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void XMPP::NetAvailabilityProvider::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_XMPP__NameProvider_t {
    QByteArrayData data[11];
    char stringdata0[140];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__NameProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__NameProvider_t qt_meta_stringdata_XMPP__NameProvider = {
    {
QT_MOC_LITERAL(0, 0, 18), // "XMPP::NameProvider"
QT_MOC_LITERAL(1, 19, 20), // "resolve_resultsReady"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 2), // "id"
QT_MOC_LITERAL(4, 44, 23), // "QList<XMPP::NameRecord>"
QT_MOC_LITERAL(5, 68, 7), // "results"
QT_MOC_LITERAL(6, 76, 13), // "resolve_error"
QT_MOC_LITERAL(7, 90, 25), // "XMPP::NameResolver::Error"
QT_MOC_LITERAL(8, 116, 1), // "e"
QT_MOC_LITERAL(9, 118, 16), // "resolve_useLocal"
QT_MOC_LITERAL(10, 135, 4) // "name"

    },
    "XMPP::NameProvider\0resolve_resultsReady\0"
    "\0id\0QList<XMPP::NameRecord>\0results\0"
    "resolve_error\0XMPP::NameResolver::Error\0"
    "e\0resolve_useLocal\0name"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__NameProvider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x06 /* Public */,
       6,    2,   34,    2, 0x06 /* Public */,
       9,    2,   39,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 7,    3,    8,
    QMetaType::Void, QMetaType::Int, QMetaType::QByteArray,    3,   10,

       0        // eod
};

void XMPP::NameProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NameProvider *_t = static_cast<NameProvider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->resolve_resultsReady((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QList<XMPP::NameRecord>(*)>(_a[2]))); break;
        case 1: _t->resolve_error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< XMPP::NameResolver::Error(*)>(_a[2]))); break;
        case 2: _t->resolve_useLocal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (NameProvider::*_t)(int , const QList<XMPP::NameRecord> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NameProvider::resolve_resultsReady)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (NameProvider::*_t)(int , XMPP::NameResolver::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NameProvider::resolve_error)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (NameProvider::*_t)(int , const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NameProvider::resolve_useLocal)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject XMPP::NameProvider::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__NameProvider.data,
      qt_meta_data_XMPP__NameProvider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::NameProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::NameProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__NameProvider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::NameProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void XMPP::NameProvider::resolve_resultsReady(int _t1, const QList<XMPP::NameRecord> & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::NameProvider::resolve_error(int _t1, XMPP::NameResolver::Error _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void XMPP::NameProvider::resolve_useLocal(int _t1, const QByteArray & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
struct qt_meta_stringdata_XMPP__ServiceProvider_t {
    QByteArrayData data[20];
    char stringdata0[379];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XMPP__ServiceProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XMPP__ServiceProvider_t qt_meta_stringdata_XMPP__ServiceProvider = {
    {
QT_MOC_LITERAL(0, 0, 21), // "XMPP::ServiceProvider"
QT_MOC_LITERAL(1, 22, 24), // "browse_instanceAvailable"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 2), // "id"
QT_MOC_LITERAL(4, 51, 21), // "XMPP::ServiceInstance"
QT_MOC_LITERAL(5, 73, 8), // "instance"
QT_MOC_LITERAL(6, 82, 26), // "browse_instanceUnavailable"
QT_MOC_LITERAL(7, 109, 12), // "browse_error"
QT_MOC_LITERAL(8, 122, 27), // "XMPP::ServiceBrowser::Error"
QT_MOC_LITERAL(9, 150, 1), // "e"
QT_MOC_LITERAL(10, 152, 20), // "resolve_resultsReady"
QT_MOC_LITERAL(11, 173, 43), // "QList<XMPP::ServiceProvider::..."
QT_MOC_LITERAL(12, 217, 7), // "results"
QT_MOC_LITERAL(13, 225, 13), // "resolve_error"
QT_MOC_LITERAL(14, 239, 28), // "XMPP::ServiceResolver::Error"
QT_MOC_LITERAL(15, 268, 17), // "publish_published"
QT_MOC_LITERAL(16, 286, 13), // "publish_error"
QT_MOC_LITERAL(17, 300, 34), // "XMPP::ServiceLocalPublisher::..."
QT_MOC_LITERAL(18, 335, 23), // "publish_extra_published"
QT_MOC_LITERAL(19, 359, 19) // "publish_extra_error"

    },
    "XMPP::ServiceProvider\0browse_instanceAvailable\0"
    "\0id\0XMPP::ServiceInstance\0instance\0"
    "browse_instanceUnavailable\0browse_error\0"
    "XMPP::ServiceBrowser::Error\0e\0"
    "resolve_resultsReady\0"
    "QList<XMPP::ServiceProvider::ResolveResult>\0"
    "results\0resolve_error\0"
    "XMPP::ServiceResolver::Error\0"
    "publish_published\0publish_error\0"
    "XMPP::ServiceLocalPublisher::Error\0"
    "publish_extra_published\0publish_extra_error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XMPP__ServiceProvider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   59,    2, 0x06 /* Public */,
       6,    2,   64,    2, 0x06 /* Public */,
       7,    2,   69,    2, 0x06 /* Public */,
      10,    2,   74,    2, 0x06 /* Public */,
      13,    2,   79,    2, 0x06 /* Public */,
      15,    1,   84,    2, 0x06 /* Public */,
      16,    2,   87,    2, 0x06 /* Public */,
      18,    1,   92,    2, 0x06 /* Public */,
      19,    2,   95,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 8,    3,    9,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 11,    3,   12,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 14,    3,    9,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 17,    3,    9,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 17,    3,    9,

       0        // eod
};

void XMPP::ServiceProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServiceProvider *_t = static_cast<ServiceProvider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->browse_instanceAvailable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const XMPP::ServiceInstance(*)>(_a[2]))); break;
        case 1: _t->browse_instanceUnavailable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const XMPP::ServiceInstance(*)>(_a[2]))); break;
        case 2: _t->browse_error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< XMPP::ServiceBrowser::Error(*)>(_a[2]))); break;
        case 3: _t->resolve_resultsReady((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QList<XMPP::ServiceProvider::ResolveResult>(*)>(_a[2]))); break;
        case 4: _t->resolve_error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< XMPP::ServiceResolver::Error(*)>(_a[2]))); break;
        case 5: _t->publish_published((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->publish_error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< XMPP::ServiceLocalPublisher::Error(*)>(_a[2]))); break;
        case 7: _t->publish_extra_published((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->publish_extra_error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< XMPP::ServiceLocalPublisher::Error(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ServiceProvider::*_t)(int , const XMPP::ServiceInstance & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::browse_instanceAvailable)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int , const XMPP::ServiceInstance & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::browse_instanceUnavailable)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int , XMPP::ServiceBrowser::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::browse_error)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int , const QList<XMPP::ServiceProvider::ResolveResult> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::resolve_resultsReady)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int , XMPP::ServiceResolver::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::resolve_error)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::publish_published)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int , XMPP::ServiceLocalPublisher::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::publish_error)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::publish_extra_published)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (ServiceProvider::*_t)(int , XMPP::ServiceLocalPublisher::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServiceProvider::publish_extra_error)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject XMPP::ServiceProvider::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XMPP__ServiceProvider.data,
      qt_meta_data_XMPP__ServiceProvider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XMPP::ServiceProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XMPP::ServiceProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XMPP__ServiceProvider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XMPP::ServiceProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void XMPP::ServiceProvider::browse_instanceAvailable(int _t1, const XMPP::ServiceInstance & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XMPP::ServiceProvider::browse_instanceUnavailable(int _t1, const XMPP::ServiceInstance & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void XMPP::ServiceProvider::browse_error(int _t1, XMPP::ServiceBrowser::Error _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void XMPP::ServiceProvider::resolve_resultsReady(int _t1, const QList<XMPP::ServiceProvider::ResolveResult> & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void XMPP::ServiceProvider::resolve_error(int _t1, XMPP::ServiceResolver::Error _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void XMPP::ServiceProvider::publish_published(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void XMPP::ServiceProvider::publish_error(int _t1, XMPP::ServiceLocalPublisher::Error _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void XMPP::ServiceProvider::publish_extra_published(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void XMPP::ServiceProvider::publish_extra_error(int _t1, XMPP::ServiceLocalPublisher::Error _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
