#include <klocalizedstring.h>

/*
Enables to choose the number of players and the game skin used
*/

/********************************************************************************
** Form generated from reading UI file 'newGameDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWGAMEDIALOG_H
#define UI_NEWGAMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NewGameDialog
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *textLabel1;
    QSpinBox *playersNumberEntry;
    QVBoxLayout *verticalLayout;
    QLabel *localPlayersNumberLabel;
    QSpinBox *localPlayersNumberEntry;
    QVBoxLayout *verticalLayout_3;
    QLabel *tcpPortLabel;
    QSpinBox *tcpPortEntry;
    QFrame *line1;
    QHBoxLayout *horizontalLayout_4;
    QLabel *textLabel2;
    QComboBox *skinCombo;
    QPushButton *ghnsbutton;
    QLabel *skinDescLabel;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *goalGroup;
    QVBoxLayout *vboxLayout;
    QRadioButton *radioWorld;
    QRadioButton *radioGoal;
    QSpacerItem *spacerItem;
    QLabel *skinSnapshotPixmap;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *nextButton;

    void setupUi(QWidget *NewGameDialog)
    {
        if (NewGameDialog->objectName().isEmpty())
            NewGameDialog->setObjectName(QStringLiteral("NewGameDialog"));
        NewGameDialog->resize(615, 417);
        NewGameDialog->setProperty("sizeGripEnabled", QVariant(true));
        verticalLayout_4 = new QVBoxLayout(NewGameDialog);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        textLabel1 = new QLabel(NewGameDialog);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setWordWrap(false);

        verticalLayout_2->addWidget(textLabel1);

        playersNumberEntry = new QSpinBox(NewGameDialog);
        playersNumberEntry->setObjectName(QStringLiteral("playersNumberEntry"));

        verticalLayout_2->addWidget(playersNumberEntry);


        horizontalLayout->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        localPlayersNumberLabel = new QLabel(NewGameDialog);
        localPlayersNumberLabel->setObjectName(QStringLiteral("localPlayersNumberLabel"));

        verticalLayout->addWidget(localPlayersNumberLabel);

        localPlayersNumberEntry = new QSpinBox(NewGameDialog);
        localPlayersNumberEntry->setObjectName(QStringLiteral("localPlayersNumberEntry"));

        verticalLayout->addWidget(localPlayersNumberEntry);


        horizontalLayout->addLayout(verticalLayout);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        tcpPortLabel = new QLabel(NewGameDialog);
        tcpPortLabel->setObjectName(QStringLiteral("tcpPortLabel"));

        verticalLayout_3->addWidget(tcpPortLabel);

        tcpPortEntry = new QSpinBox(NewGameDialog);
        tcpPortEntry->setObjectName(QStringLiteral("tcpPortEntry"));
        tcpPortEntry->setMinimum(1);
        tcpPortEntry->setMaximum(32767);
        tcpPortEntry->setValue(20000);

        verticalLayout_3->addWidget(tcpPortEntry);


        horizontalLayout->addLayout(verticalLayout_3);


        verticalLayout_4->addLayout(horizontalLayout);

        line1 = new QFrame(NewGameDialog);
        line1->setObjectName(QStringLiteral("line1"));
        line1->setFrameShape(QFrame::HLine);
        line1->setFrameShadow(QFrame::Sunken);
        line1->setFrameShape(QFrame::HLine);

        verticalLayout_4->addWidget(line1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        textLabel2 = new QLabel(NewGameDialog);
        textLabel2->setObjectName(QStringLiteral("textLabel2"));
        textLabel2->setWordWrap(false);

        horizontalLayout_4->addWidget(textLabel2);

        skinCombo = new QComboBox(NewGameDialog);
        skinCombo->setObjectName(QStringLiteral("skinCombo"));

        horizontalLayout_4->addWidget(skinCombo);

        ghnsbutton = new QPushButton(NewGameDialog);
        ghnsbutton->setObjectName(QStringLiteral("ghnsbutton"));

        horizontalLayout_4->addWidget(ghnsbutton);


        verticalLayout_4->addLayout(horizontalLayout_4);

        skinDescLabel = new QLabel(NewGameDialog);
        skinDescLabel->setObjectName(QStringLiteral("skinDescLabel"));
        skinDescLabel->setAlignment(Qt::AlignVCenter);
        skinDescLabel->setWordWrap(false);

        verticalLayout_4->addWidget(skinDescLabel);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        goalGroup = new QGroupBox(NewGameDialog);
        goalGroup->setObjectName(QStringLiteral("goalGroup"));
        vboxLayout = new QVBoxLayout(goalGroup);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        radioWorld = new QRadioButton(goalGroup);
        radioWorld->setObjectName(QStringLiteral("radioWorld"));

        vboxLayout->addWidget(radioWorld);

        radioGoal = new QRadioButton(goalGroup);
        radioGoal->setObjectName(QStringLiteral("radioGoal"));
        radioGoal->setChecked(true);

        vboxLayout->addWidget(radioGoal);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);


        horizontalLayout_3->addWidget(goalGroup);

        skinSnapshotPixmap = new QLabel(NewGameDialog);
        skinSnapshotPixmap->setObjectName(QStringLiteral("skinSnapshotPixmap"));
        QSizePolicy sizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skinSnapshotPixmap->sizePolicy().hasHeightForWidth());
        skinSnapshotPixmap->setSizePolicy(sizePolicy);
        skinSnapshotPixmap->setScaledContents(true);
        skinSnapshotPixmap->setWordWrap(false);

        horizontalLayout_3->addWidget(skinSnapshotPixmap);


        verticalLayout_4->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        cancelButton = new QPushButton(NewGameDialog);
        cancelButton->setObjectName(QStringLiteral("cancelButton"));

        horizontalLayout_2->addWidget(cancelButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        nextButton = new QPushButton(NewGameDialog);
        nextButton->setObjectName(QStringLiteral("nextButton"));

        horizontalLayout_2->addWidget(nextButton);


        verticalLayout_4->addLayout(horizontalLayout_2);

        QWidget::setTabOrder(skinCombo, playersNumberEntry);
        QWidget::setTabOrder(playersNumberEntry, radioWorld);
        QWidget::setTabOrder(radioWorld, radioGoal);

        retranslateUi(NewGameDialog);

        QMetaObject::connectSlotsByName(NewGameDialog);
    } // setupUi

    void retranslateUi(QWidget *NewGameDialog)
    {
        NewGameDialog->setWindowTitle(tr2i18n("Ksirk - New game properties", Q_NULLPTR));
        textLabel1->setText(tr2i18n("Total number of players:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        playersNumberEntry->setToolTip(tr2i18n("Spin this to choose the number of players.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        playersNumberEntry->setWhatsThis(tr2i18n("A spin box to choose the number of players", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        localPlayersNumberLabel->setText(tr2i18n("Number of local players:", Q_NULLPTR));
        tcpPortLabel->setText(tr2i18n("TCP port on which to offer connections:", Q_NULLPTR));
        textLabel2->setText(tr2i18n("Skin:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        skinCombo->setToolTip(tr2i18n("Choose the skin (map, nationalities, etc.) to use for this game.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        skinCombo->setWhatsThis(tr2i18n("A combo listing all the available skins.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        ghnsbutton->setText(tr2i18n("Download New Skins", Q_NULLPTR));
        skinDescLabel->setText(tr2i18n("skinDescLabel", Q_NULLPTR));
        goalGroup->setTitle(tr2i18n("Goal Type", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioWorld->setToolTip(tr2i18n("Choose this for players to have to conquer all the world to win.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioWorld->setWhatsThis(tr2i18n("In this mode, a player will have to conquer all the world to win.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioWorld->setText(tr2i18n("World con&quest", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioGoal->setToolTip(tr2i18n("Choose this to have a goal assigned to each player.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioGoal->setWhatsThis(tr2i18n("In this mode, a goal will be assigned to each player, which he will have to reach in order to win.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioGoal->setText(tr2i18n("Reach a goa&l", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        radioGoal->setShortcut(QString());
#endif // QT_NO_SHORTCUT
        skinSnapshotPixmap->setText(QString());
        cancelButton->setText(tr2i18n("Cancel", Q_NULLPTR));
        nextButton->setText(tr2i18n("Next >>", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class NewGameDialog: public Ui_NewGameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWGAMEDIALOG_H

