// This file is generated by kconfig_compiler_kf5 from ksirksettings.kcfg.
// All changes you do to this file will be lost.

#include "ksirksettings.h"

#include <qglobal.h>
#include <QtCore/QFile>

using namespace Ksirk;

namespace Ksirk {

class KsirkSettingsHelper
{
  public:
    KsirkSettingsHelper() : q(nullptr) {}
    ~KsirkSettingsHelper() { delete q; }
    KsirkSettings *q;
};
}

Q_GLOBAL_STATIC(KsirkSettingsHelper, s_globalKsirkSettings)
KsirkSettings *KsirkSettings::self()
{
  if (!s_globalKsirkSettings()->q) {
    new KsirkSettings;
    s_globalKsirkSettings()->q->read();
  }

  return s_globalKsirkSettings()->q;
}

KsirkSettings::KsirkSettings(  )
  : KConfigSkeleton( QStringLiteral( "ksirkrc" ) )
{
  Q_ASSERT(!s_globalKsirkSettings()->q);
  s_globalKsirkSettings()->q = this;
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemInt  *itemSpritesSpeed;
  itemSpritesSpeed = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "spritesSpeed" ), mSpritesSpeed, 1 );
  addItem( itemSpritesSpeed, QStringLiteral( "spritesSpeed" ) );
  KConfigSkeleton::ItemBool  *itemSoundEnabled;
  itemSoundEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "soundEnabled" ), mSoundEnabled, true );
  addItem( itemSoundEnabled, QStringLiteral( "soundEnabled" ) );
  KConfigSkeleton::ItemBool  *itemHelpEnabled;
  itemHelpEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "helpEnabled" ), mHelpEnabled, true );
  addItem( itemHelpEnabled, QStringLiteral( "helpEnabled" ) );
  KConfigSkeleton::ItemBool  *itemShowArmiesNumbers;
  itemShowArmiesNumbers = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "showArmiesNumbers" ), mShowArmiesNumbers, false );
  addItem( itemShowArmiesNumbers, QStringLiteral( "showArmiesNumbers" ) );
  KConfigSkeleton::ItemString  *itemTheme;
  itemTheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Theme" ), mTheme );
  addItem( itemTheme, QStringLiteral( "Theme" ) );
  KConfigSkeleton::ItemString  *itemJabberId;
  itemJabberId = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "jabberId" ), mJabberId );
  addItem( itemJabberId, QStringLiteral( "jabberId" ) );
  KConfigSkeleton::ItemString  *itemJabberPassword;
  itemJabberPassword = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "jabberPassword" ), mJabberPassword );
  addItem( itemJabberPassword, QStringLiteral( "jabberPassword" ) );
  KConfigSkeleton::ItemString  *itemRoomJid;
  itemRoomJid = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "roomJid" ), mRoomJid );
  addItem( itemRoomJid, QStringLiteral( "roomJid" ) );
  KConfigSkeleton::ItemString  *itemRoomPassword;
  itemRoomPassword = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "roomPassword" ), mRoomPassword );
  addItem( itemRoomPassword, QStringLiteral( "roomPassword" ) );
  KConfigSkeleton::ItemString  *itemNickname;
  itemNickname = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "nickname" ), mNickname );
  addItem( itemNickname, QStringLiteral( "nickname" ) );
}

KsirkSettings::~KsirkSettings()
{
  s_globalKsirkSettings()->q = nullptr;
}

